@@ -34,6 +34,8 @@
 #include "rclaspell.h"
 #include "debuglog.h"
 
+#include "ptmutex.h"
+
 // Just a place where we keep the Aspell library entry points together
 class AspellApi {
 public:
@@ -61,6 +63,7 @@ public:
 
 };
 static AspellApi aapi;
+static PTMutexInit o_aapi_mutex;
 
 #define NMTOPTR(NM, TP)							\
     if ((aapi.NM = TP dlsym(m_data->m_handle, #NM)) == 0) {		\
@@ -111,6 +114,7 @@ Aspell::~Aspell()
 
 bool Aspell::init(string &reason)
 {
+    PTMutexLocker locker(o_aapi_mutex);
     deleteZ(m_data);
 
     // Language: we get this from the configuration, else from the NLS
@@ -227,7 +231,7 @@ bool Aspell::init(string &reason)
     return true;
 }
 
-bool Aspell::ok()
+bool Aspell::ok() const
 {
     return m_data != 0 && m_data->m_handle != 0;
 }
@@ -254,14 +258,12 @@ public:
     {}
     void newData() {
 	while (m_db.termWalkNext(m_tit, *m_input)) {
-	    // Filter out terms beginning with upper case (special stuff) and 
-	    // containing numbers, or too long. Note that the 50 limit is a
-	    // byte count, so not so high if there are multibyte chars.
-	    if (m_input->empty() || m_input->length() > 50)
+	    // Prefixed terms are also somewhere else without the suffix,
+	    // skip them
+	    if (m_input->empty() || 
+		('A' <= m_input->at(0) && m_input->at(0) <= 'Z'))
 		continue;
-	    if ('A' <= m_input->at(0) && m_input->at(0) <= 'Z')
-		continue;
-	    if (m_input->find_first_of(" !\"#$%&()*+,-./0123456789:;<=>?@[\\]^_`{|}~") != string::npos)
+	    if (!Rcl::Db::isSpellingCandidate(*m_input))
 		continue;
 	    // Got a non-empty sort-of appropriate term, let's send it to
 	    // aspell
