@@ -35,6 +35,7 @@
 #include <cstdlib>
 #include <cstring>
 
+#include "cstr.h"
 #include "pathut.h"
 #include "rclconfig.h"
 #include "conftree.h"
@@ -42,6 +43,7 @@
 #include "smallut.h"
 #include "textsplit.h"
 #include "readfile.h"
+#include "fstreewalk.h"
 
 #ifndef NO_NAMESPACES
 using namespace std;
@@ -98,6 +100,14 @@ void RclConfig::zeroMe() {
     m_rmtstate.init(this, 0, "indexedmimetypes");
 }
 
+bool RclConfig::isDefaultConfig()
+{
+    string defaultconf = path_cat(path_canon(path_home()), ".recoll/");
+    string specifiedconf = path_canon(m_confdir);
+    path_catslash(specifiedconf);
+    return !defaultconf.compare(specifiedconf);
+}
+
 RclConfig::RclConfig(const string *argcnf)
 {
     zeroMe();
@@ -128,18 +138,18 @@ RclConfig::RclConfig(const string *argcnf)
 	    m_confdir = cp;
 	} else {
 	    autoconfdir = true;
-	    m_confdir = path_home();
-	    m_confdir += ".recoll/";
+	    m_confdir = path_cat(path_home(), ".recoll/");
 	}
     }
 
-    if (!autoconfdir) {
-	// We want a recoll.conf file to exist in this case to avoid
-	// creating indexes all over the place
-	string conffile = path_cat(m_confdir, "recoll.conf");
-	if (access(conffile.c_str(), 0) < 0) {
-	    m_reason = "Explicitly specified configuration must exist"
-		" (won't be automatically created)";
+    // Note: autoconfdir and isDefaultConfig() are normally the same. We just 
+    // want to avoid the imperfect test in isDefaultConfig() if we actually know
+    // this is the default conf
+    if (!autoconfdir && !isDefaultConfig()) {
+	if (access(m_confdir.c_str(), 0) < 0) {
+	    m_reason = "Explicitly specified configuration "
+		"directory must exist"
+		" (won't be automatically created). Use mkdir first";
 	    return;
 	}
     }
@@ -176,7 +186,7 @@ RclConfig::RclConfig(const string *argcnf)
 	return;
 
     m_ok = true;
-    setKeyDir("");
+    setKeyDir(cstr_null);
 
     m_stpsuffstate.init(this, mimemap, "recoll_noindex");
     m_skpnstate.init(this, m_conf, "skippedNames");
@@ -199,7 +209,13 @@ bool RclConfig::updateMainConfig()
         m_rmtstate.init(this, 0, "indexedmimetypes");
 	return false;
     }
-    setKeyDir("");
+    delete m_conf;
+    m_conf = newconf;
+    m_skpnstate.init(this, m_conf, "skippedNames");
+    m_rmtstate.init(this, m_conf, "indexedmimetypes");
+
+
+    setKeyDir(cstr_null);
     bool nocjk = false;
     if (getConfParam("nocjk", &nocjk) && nocjk == true) {
 	TextSplit::cjkProcessing(false);
@@ -217,10 +233,12 @@ bool RclConfig::updateMainConfig()
 	TextSplit::noNumbers();
     }
 
-    delete m_conf;
-    m_conf = newconf;
-    m_skpnstate.init(this, m_conf, "skippedNames");
-    m_rmtstate.init(this, m_conf, "indexedmimetypes");
+    bool fnmpathname = true;
+    if (getConfParam("skippedPathsFnmPathname", &fnmpathname)
+	&& fnmpathname == false) {
+	FsTreeWalker::setNoFnmPathname();
+    }
+
     return true;
 }
 
@@ -348,7 +366,7 @@ const string& RclConfig::getDefCharset(bool filename)
 	} else {
 	    // Note: it seems that all versions of iconv will take
 	    // iso-8859. Some won't take iso8859
-	    localecharset = string("ISO-8859-1");
+	    localecharset = string(cstr_iso_8859_1);
 	}
 	LOGDEB1(("RclConfig::getDefCharset: localecharset [%s]\n",
 		localecharset.c_str()));
@@ -377,7 +395,7 @@ bool RclConfig::addLocalFields(map<string, string> *tgt)
             sfields[i] = '\n';
     // Parse the result with a confsimple and add the results to the metadata
     ConfSimple conf(sfields, 1, true);
-    list<string> nmlst = conf.getNames("");
+    list<string> nmlst = conf.getNames(cstr_null);
     for (list<string>::const_iterator it = nmlst.begin();
          it != nmlst.end(); it++) {
         conf.get(*it, (*tgt)[*it]);
@@ -387,10 +405,15 @@ bool RclConfig::addLocalFields(map<string, string> *tgt)
     return true;
 }
 
-
-// Get all known document mime values (for indexing). We get them from
-// the mimeconf 'index' submap: values not in there (ie from mimemap
-// or idfile) can't possibly belong to documents in the database.
+// Get all known document mime values. We get them from the mimeconf
+// 'index' submap.
+// It's quite possible that there are other mime types in the index
+// (defined in mimemap and not mimeconf, or output by "file -i"). We
+// just ignore them, because there may be myriads, and their contents
+// are not indexed. 
+//
+// This unfortunately means that searches by file names and mime type
+// filtering don't work well together.
 list<string> RclConfig::getAllMimeTypes()
 {
     list<string> lst;
@@ -488,15 +511,15 @@ string RclConfig::getMimeTypeFromSuffix(const string& suff)
 string RclConfig::getSuffixFromMimeType(const string &mt)
 {
     string suffix;
-    list<string>sfs = mimemap->getNames("");
+    list<string>sfs = mimemap->getNames(cstr_null);
     string mt1;
     for (list<string>::const_iterator it = sfs.begin(); 
 	 it != sfs.end(); it++) {
-	if (mimemap->get(*it, mt1, ""))
+	if (mimemap->get(*it, mt1, cstr_null))
 	    if (!stringicmp(mt, mt1))
 		return *it;
     }
-    return "";
+    return cstr_null;
 }
 
 /** Get list of file categories from mimeconf */
@@ -553,6 +576,24 @@ string RclConfig::getMimeHandlerDef(const string &mtype, bool filtertypes)
     return hs;
 }
 
+bool RclConfig::getGuiFilterNames(list<string>& cats) 
+{
+    if (!mimeconf)
+	return false;
+    cats = mimeconf->getNamesShallow("guifilters");
+    return true;
+}
+
+bool RclConfig::getGuiFilter(const string& catfiltername, string& frag)
+{
+    frag.clear();
+    if (!mimeconf)
+	return false;
+    if (!mimeconf->get(catfiltername, frag, "guifilters"))
+	return false;
+    return true;
+}
+
 bool RclConfig::valueSplitAttributes(const string& whole, string& value, 
 				     ConfSimple& attrs)
 {
@@ -693,7 +734,7 @@ bool RclConfig::getFieldTraits(const string& _fld, const FieldTraits **ftpp)
     map<string, FieldTraits>::const_iterator pit = m_fldtotraits.find(fld);
     if (pit != m_fldtotraits.end()) {
 	*ftpp = &pit->second;
-	LOGDEB1(("RclConfig::getFieldPrefix: [%s]->[%s]\n", 
+	LOGDEB1(("RclConfig::getFieldTraits: [%s]->[%s]\n", 
 		 _fld.c_str(), ft.pfx.c_str()));
 	return true;
     } else {
@@ -772,7 +813,7 @@ bool RclConfig::setMimeViewerDef(const string& mt, const string& def)
 {
     if (mimeview == 0)
         return false;
-    string pconfname = path_cat(m_confdir, "mimeview");
+    string pconfname = path_cat(getConfDir(), "mimeview");
     // Make sure this exists 
     close(open(pconfname.c_str(), O_CREAT|O_WRONLY, 0600));
     ConfTree tree(pconfname.c_str());
@@ -845,13 +886,28 @@ string RclConfig::getDbDir()
 	// If not an absolute path, compute relative to config dir
 	if (dbdir.at(0) != '/') {
 	    LOGDEB1(("Dbdir not abs, catting with confdir\n"));
-	    dbdir = path_cat(m_confdir, dbdir);
+	    dbdir = path_cat(getConfDir(), dbdir);
 	}
     }
     LOGDEB1(("RclConfig::getDbDir: dbdir: [%s]\n", dbdir.c_str()));
     return path_canon(dbdir);
 }
 
+bool RclConfig::sourceChanged()
+{
+    if (m_conf && m_conf->sourceChanged())
+	return true;
+    if (mimemap && mimemap->sourceChanged())
+	return true;
+    if (mimeconf && mimeconf->sourceChanged())
+	return true;
+    if (mimeview && mimeview->sourceChanged())
+	return true;
+    if (m_fields && m_fields->sourceChanged())
+	return true;
+    return false;
+}
+
 string RclConfig::getStopfile()
 {
     return path_cat(getConfDir(), "stoplist.txt");
@@ -861,6 +917,23 @@ string RclConfig::getPidfile()
     return path_cat(getConfDir(), "index.pid");
 }
 
+// The index status file is fast changing, so it's possible to put it outside
+// of the config directory (for ssds, not sure this is really useful).
+string RclConfig::getIdxStatusFile()
+{
+    string path;
+    if (!getConfParam("idxstatusfile", path)) {
+	return path_cat(getConfDir(), "idxstatus.txt");
+    } else {
+	path = path_tildexpand(path);
+	// If not an absolute path, compute relative to config dir
+	if (path.at(0) != '/') {
+	    path = path_cat(getConfDir(), path);
+	}
+	return path_canon(path);
+    }
+}
+
 list<string>& RclConfig::getSkippedNames()
 {
     if (m_skpnstate.needrecompute()) {
@@ -955,7 +1028,7 @@ bool RclConfig::getUncompressor(const string &mtype, list<string>& cmd)
 {
     string hs;
 
-    mimeconf->get(mtype, hs, "");
+    mimeconf->get(mtype, hs, cstr_null);
     if (hs.empty())
 	return false;
     list<string> tokens;
@@ -1083,6 +1156,7 @@ using namespace std;
 #include "debuglog.h"
 #include "rclinit.h"
 #include "rclconfig.h"
+#include "cstr.h"
 
 static char *thisprog;
 
@@ -1166,9 +1240,13 @@ int main(int argc, char **argv)
 	cout << "Indexed fields: ";
         for (set<string>::const_iterator it = indexed.begin(); 
              it != indexed.end(); it++) {
-	    string prefix;
-	    config->getFieldPrefix(*it, prefix);
-            cout << "[" << *it << "]" << " -> [" << prefix << "] ";
+	    const FieldTraits *ftp;
+	    config->getFieldTraits(*it, &ftp);
+	    if (ftp)
+		cout << "[" << *it << "]" << " -> [" << ftp->pfx << "] ";
+	    else 
+		cout << "[" << *it << "]" << " -> [" << "(none)" << "] ";
+
         }
 	cout << endl;	
     } else if (op_flags & OPT_c) {
@@ -1205,7 +1283,7 @@ int main(int argc, char **argv)
             }
         }
     } else {
-        config->setKeyDir("");
+        config->setKeyDir(cstr_null);
 	list<string> names = config->getConfNames();
 	names.sort();
 	names.unique();
