@@ -83,8 +83,17 @@ class RclConfig {
     bool ok() {return m_ok;}
     const string &getReason() {return m_reason;}
 
-    /** Return the directory where this configuration is stored */
+    /** Return the directory where this configuration is stored. 
+     *  This was possibly silently created by the rclconfig
+     *  constructor it it is the default one (~/.recoll) and it did 
+     *  not exist yet. */
     string getConfDir() {return m_confdir;}
+
+    /** Check if the config files were modified since we read them */
+    bool sourceChanged();
+
+    /** Returns true if this is ~/.recoll */
+    bool isDefaultConfig(); 
     /** Get the local value for /usr/local/share/recoll/ */
     const string& getDatadir() {return m_datadir;}
 
@@ -136,8 +145,10 @@ class RclConfig {
     string getDbDir();
     /** Get stoplist file name */
     string getStopfile();
-    /** Get indexing pid file */
+    /** Get indexing pid file name */
     string getPidfile();
+    /** Get indexing status file name */
+    string getIdxStatusFile();
 
     /** Get list of skipped file names for current keydir */
     list<string>& getSkippedNames();
@@ -195,6 +206,11 @@ class RclConfig {
     /** mimeconf: get list of mime types for category */
     bool getMimeCatTypes(const string& cat, list<string>&);
 
+    /** mimeconf: get list of gui filters (doc cats by default */
+    bool getGuiFilterNames(list<string>&);
+    /** mimeconf: get query lang frag for named filter */
+    bool getGuiFilter(const string& filtername, string& frag);
+
     /** fields: get field prefix from field name */
     bool getFieldTraits(const string& fldname, const FieldTraits **);
     const set<string>& getStoredFields() {return m_storedFields;}
