@@ -50,9 +50,16 @@ RclConfig *recollinit(RclInitFlags flags,
 
     // Install signal handler
     if (sigcleanup) {
+	struct sigaction action;
+	action.sa_handler = sigcleanup;
+	action.sa_flags = 0;
+	sigemptyset(&action.sa_mask);
 	for (unsigned int i = 0; i < sizeof(catchedSigs) / sizeof(int); i++)
-	    if (signal(catchedSigs[i], SIG_IGN) != SIG_IGN)
-		signal(catchedSigs[i], sigcleanup);
+	    if (signal(catchedSigs[i], SIG_IGN) != SIG_IGN) {
+		if (sigaction(catchedSigs[i], &action, 0) < 0) {
+		    perror("Sigaction failed");
+		}
+	    }
     }
 
     DebugLog::getdbl()->setloglevel(DEBDEB1);
@@ -100,9 +107,15 @@ RclConfig *recollinit(RclInitFlags flags,
     // Make sure the locale charset is initialized (so that multiple
     // threads don't try to do it at once).
     config->getDefCharset();
+
     // Init unac locking
     unac_init_mt();
 
+    // Init Unac translation exceptions
+    string unacex;
+    if (config->getConfParam("unac_except_trans", unacex) && !unacex.empty()) 
+	unac_set_except_translations(unacex.c_str());
+
     int flushmb;
     if (config->getConfParam("idxflushmb", &flushmb) && flushmb > 0) {
 	LOGDEB1(("rclinit: idxflushmb=%d, set XAPIAN_FLUSH_THRESHOLD to 10E6\n",
