@@ -164,7 +164,7 @@ bool          TextSplit::o_noNumbers = false;
 // Do some checking (the kind which is simpler to do here than in the
 // main loop), then send term to our client.
 inline bool TextSplit::emitterm(bool isspan, string &w, int pos, 
-			 int btstart, int btend)
+				int btstart, int btend)
 {
     LOGDEB3(("TextSplit::emitterm: [%s] pos %d\n", w.c_str(), pos));
 
@@ -208,10 +208,10 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
  */
 inline bool TextSplit::doemit(bool spanerase, int bp, bool spanemit)
 {
-    LOGDEB3(("TextSplit::doemit: sper %d bp %d spem %d. spp %d wS %d wL %d "
-	    "inn %d span [%s]\n",
-	    spanerase, bp, spanemit, m_spanpos, m_wordStart, m_wordLen,
-	    m_inNumber, m_span.c_str()));
+    LOGDEB2(("TextSplit::doemit: sper %d bp %d spem %d. spp %d wS %d wL %d "
+	     "inn %d span [%s]\n",
+	     spanerase, bp, spanemit, m_spanpos, m_wordStart, m_wordLen,
+	     m_inNumber, m_span.c_str()));
 
     // Emit span? When splitting for query, we only emit final spans
     // (spanerase)
@@ -220,6 +220,28 @@ inline bool TextSplit::doemit(bool spanerase, int bp, bool spanemit)
         !((m_wordLen == m_span.length()) && 
           (o_noNumbers) && m_inNumber) &&
 	((spanemit && !(m_flags & TXTS_ONLYSPANS)) || spanerase) ) {
+
+	// Check for an acronym/abbreviation ie I.B.M.
+	if (spanerase && m_wordLen != m_span.length() && m_span.length() > 2
+	    && m_span.length() <= 20) {
+	    bool acron = true;
+	    for (unsigned int i = 1 ; i < m_span.length(); i += 2) {
+		if (m_span[i] != '.') {
+		    acron = false;
+		    break;
+		}
+	    }
+	    if (acron) {
+		string acronym;
+		for (unsigned int i = 0; i < m_span.length(); i += 2) {
+		    acronym += m_span[i];
+		}
+		if (!emitterm(false, acronym, m_spanpos, bp - m_span.length(), 
+			      bp))
+		    return false;
+	    }
+	} 
+
 	// Maybe trim at end. These are chars that we would keep inside 
 	// a span, but not at the end
 	while (m_span.length() > 0) {
@@ -348,12 +370,14 @@ bool TextSplit::text_to_words(const string &in)
 		m_inNumber = false;
 	    }
 	    break;
+
 	case WILD:
 	    if (m_flags & TXTS_KEEPWILD)
 		goto NORMALCHAR;
 	    else
 		goto SPACE;
 	    break;
+
 	case '-':
 	case '+':
 	    curspanglue = cc;
@@ -381,12 +405,16 @@ bool TextSplit::text_to_words(const string &in)
 		m_wordStart += it.appendchartostring(m_span);
 	    }
 	    break;
+
 	case '.':
 	case ',':
+	{
+	    // Need a little lookahead here. At worse this gets the end null
+	    int nextc = it[it.getCpos()+1];
+	    int nextwhat = whatcc(nextc);
 	    if (m_inNumber) {
-		// 132.jpg ?
-                int wn = it[it.getCpos()+1];
-		if (whatcc(wn) != DIGIT && wn != 'e' && wn != 'E')
+		// we're eliminating 132.jpg here. Good idea ?
+		if (nextwhat != DIGIT && nextc != 'e' && nextc != 'E')
 		    goto SPACE;
 		m_wordLen += it.appendchartostring(m_span);
 		curspanglue = cc;
@@ -398,10 +426,15 @@ bool TextSplit::text_to_words(const string &in)
                 // Another problem is that something like .x-errs 
 		// will be split as .x-errs, x, errs but not x-errs
 		// A final comma in a word will be removed by doemit
-		if (cc == '.' && it[it.getCpos()+1] != '.') {
+
+		// Only letters and digits make sense after
+		if (nextwhat != A_LLETTER && nextwhat != A_ULETTER && 
+		    nextwhat != DIGIT && nextwhat != LETTER)
+		    goto SPACE;
+
+		if (cc == '.') {
                     // Check for number like .1
-                    if (m_span.length() == 0 &&
-                        whatcc(it[it.getCpos()+1]) == DIGIT) {
+                    if (m_span.length() == 0 && nextwhat == DIGIT) {
                         m_inNumber = true;
                         m_wordLen += it.appendchartostring(m_span);
                         curspanglue = cc;
@@ -430,7 +463,9 @@ bool TextSplit::text_to_words(const string &in)
 		}
 	    }
 	    goto SPACE;
+	}
 	    break;
+
 	case '@':
 	    if (m_wordLen) {
 		if (!doemit(false, it.getBpos()))
@@ -623,8 +658,7 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
     // first
     if ((m_flags & TXTS_ONLYSPANS) && nchars > 0 && nchars != o_CJKNgramLen)  {
 	unsigned int btend = it.getBpos(); // Current char is out
-	if (!takeword(it.buffer().substr(boffs[0], 
-					       btend-boffs[0]),
+	if (!takeword(it.buffer().substr(boffs[0], btend-boffs[0]),
 			    m_wordpos - nchars,
 			    boffs[0], btend)) {
 	    return false;
@@ -764,18 +798,19 @@ bool TextSplit::stringToStrings(const string &s, list<string> &tokens)
 #include "readfile.h"
 #include "debuglog.h"
 #include "transcode.h"
+#include "unacpp.h"
+#include "termproc.h"
 
 using namespace std;
 
-class myTextSplit : public TextSplit {
+class myTermProc : public Rcl::TermProc {
     int first;
     bool nooutput;
- public:
-    myTextSplit(Flags flags = Flags(TXTS_NONE)) : 
-        TextSplit(flags),first(1), nooutput(false) 
-    {}
+public:
+    myTermProc() : TermProc(0), first(1), nooutput(false)  {}
     void setNoOut(bool val) {nooutput = val;}
-    bool takeword(const string &term, int pos, int bs, int be) {
+    virtual bool takeword(const string &term, int pos, int bs, int be)
+    {
 	if (nooutput)
 	    return true;
 	FILE *fp = stdout;
@@ -812,13 +847,15 @@ static string thisprog;
 
 static string usage =
     " textsplit [opts] [filename]\n"
-    "   -S: no output\n"
-    "   -s:  only spans\n"
-    "   -w:  only words\n"
-    "   -n:  no numbers\n"
-    "   -k:  preserve wildcards (?*)\n"
-    "   -c: just count words\n"
+    "   -q : no output\n"
+    "   -s :  only spans\n"
+    "   -w :  only words\n"
+    "   -n :  no numbers\n"
+    "   -k :  preserve wildcards (?*)\n"
+    "   -c : just count words\n"
+    "   -u : use unac\n"
     "   -C [charset] : input charset\n"
+    "   -S [stopfile] : stopfile to use for commongrams\n"
     " if filename is 'stdin', will read stdin for data (end with ^D)\n"
     "  \n\n"
     ;
@@ -833,15 +870,18 @@ Usage(void)
 static int        op_flags;
 #define OPT_s	  0x1 
 #define OPT_w	  0x2
-#define OPT_S	  0x4
+#define OPT_q	  0x4
 #define OPT_c     0x8
 #define OPT_k     0x10
 #define OPT_C     0x20
 #define OPT_n     0x40
+#define OPT_S     0x80
+#define OPT_u     0x100
 
 int main(int argc, char **argv)
 {
-    string charset;
+    string charset, stopfile;
+
     thisprog = argv[0];
     argc--; argv++;
 
@@ -858,8 +898,12 @@ int main(int argc, char **argv)
                 goto b1;
 	    case 'k':	op_flags |= OPT_k; break;
 	    case 'n':	op_flags |= OPT_n; break;
+	    case 'q':	op_flags |= OPT_q; break;
 	    case 's':	op_flags |= OPT_s; break;
-	    case 'S':	op_flags |= OPT_S; break;
+            case 'S':	op_flags |= OPT_S; if (argc < 2)  Usage();
+                stopfile = *(++argv); argc--; 
+                goto b1;
+	    case 'u':	op_flags |= OPT_u; break;
 	    case 'w':	op_flags |= OPT_w; break;
 	    default: Usage();	break;
 	    }
@@ -879,6 +923,13 @@ int main(int argc, char **argv)
     if (op_flags & OPT_n)
 	TextSplit::noNumbers();
 
+    Rcl::StopList stoplist;
+    if (op_flags & OPT_S) {
+	if (!stoplist.setFile(stopfile)) {
+	    cerr << "Can't read stopfile: " << stopfile << endl;
+	    exit(1);
+	}
+    }
     string odata, reason;
     if (argc == 1) {
 	const char *filename = *argv++;	argc--;
@@ -912,10 +963,25 @@ int main(int argc, char **argv)
 	int n = TextSplit::countWords(data, flags);
 	cout << n << " words" << endl;
     } else {
-	myTextSplit splitter(flags);
-        if (op_flags&OPT_S)
-            splitter.setNoOut(true);
+	myTermProc printproc;
+
+	Rcl::TermProc *nxt = &printproc;
+
+	Rcl::TermProcCommongrams commonproc(nxt, stoplist);
+	if (op_flags & OPT_S)
+	    nxt = &commonproc;
+
+	Rcl::TermProcPrep preproc(nxt);
+	if (op_flags & OPT_u) 
+	    nxt = &preproc;
+
+	Rcl::TextSplitP splitter(nxt, flags);
+
+        if (op_flags & OPT_q)
+            printproc.setNoOut(true);
+
 	splitter.text_to_words(data);
+
     }    
 }
 #endif // TEST
