@@ -24,10 +24,26 @@ using std::list;
 
 #include "indexer.h"
 #include "fstreewalk.h"
-#include "rcldb.h"
+#ifdef IDX_THREADS
+#include "workqueue.h"
+#endif // IDX_THREADS
 
 class DbIxStatusUpdater;
 class FIMissingStore;
+struct stat;
+
+#ifdef IDX_THREADS
+class IndexingTask {
+public:
+    IndexingTask(const string& u, const string& p, const Rcl::Doc& d)
+	:udi(u), parent_udi(p), doc(d)
+    {}
+    string udi;
+    string parent_udi;
+    Rcl::Doc doc;
+};
+extern void *FsIndexerIndexWorker(void*);
+#endif // IDX_THREADS
 
 /** Index selected parts of the file system
  
@@ -69,6 +85,9 @@ class FsIndexer : public FsTreeWalkerCB {
     FsTreeWalker::Status 
     processone(const string &fn, const struct stat *, FsTreeWalker::CbFlag);
 
+    /** Make signature for file up to date checks */
+    static void makesig(const struct stat *stp, string& out);
+
  private:
     FsTreeWalker m_walker;
     RclConfig   *m_config;
@@ -86,6 +105,11 @@ class FsIndexer : public FsTreeWalkerCB {
     bool         m_havelocalfields;
     map<string, string> m_localfields;
 
+#ifdef IDX_THREADS
+    friend void *FsIndexerIndexWorker(void*);
+    WorkQueue<IndexingTask*> m_wqueue;
+#endif // IDX_THREADS
+
     bool init();
     void localfieldsfromconf();
     void setlocalfields(Rcl::Doc& doc);
