@@ -20,27 +20,39 @@
 #include <string>
 #include <list>
 #include <map>
+#include <vector>
 
 #ifndef NO_NAMESPACES
 using std::string;
 using std::list;
 using std::map;
+using std::vector;
 #endif
 
 #include "rclconfig.h"
 #include "rcldb.h"
+#include "rcldoc.h"
 
 class FsIndexer;
 class BeagleQueueIndexer;
 
 class DbIxStatus {
  public:
-    enum Phase {DBIXS_FILES, DBIXS_PURGE, DBIXS_STEMDB, DBIXS_CLOSING};
+    enum Phase {DBIXS_NONE,
+		DBIXS_FILES, DBIXS_PURGE, DBIXS_STEMDB, DBIXS_CLOSING, 
+		DBIXS_MONITOR,
+		DBIXS_DONE};
     Phase phase;
     string fn;   // Last file processed
-    int docsdone;  // Documents processed
+    int docsdone;  // Documents actually updated
+    int filesdone; // Files tested (updated or not)
     int dbtotdocs;  // Doc count in index at start
-    void reset() {phase = DBIXS_FILES;fn.erase();docsdone=dbtotdocs=0;}
+    void reset() 
+    {
+	phase = DBIXS_FILES;
+	fn.erase();
+	docsdone = filesdone = dbtotdocs = 0;
+    }
     DbIxStatus() {reset();}
 };
 
@@ -50,13 +62,17 @@ class DbIxStatusUpdater {
  public:
     DbIxStatus status;
     virtual ~DbIxStatusUpdater(){}
-    virtual bool update() = 0;
+
+    // Convenience: change phase/fn and update
     virtual bool update(DbIxStatus::Phase phase, const string& fn)
     {
         status.phase = phase;
         status.fn = fn;
         return update();
     }
+
+    // To be implemented by user for sending info somewhere
+    virtual bool update() = 0;
 };
 
 /**
@@ -94,10 +110,14 @@ class ConfIndexer {
     static list<string> getStemmerNames();
 
     /** Index a list of files. No db cleaning or stemdb updating */
-    bool indexFiles(std::list<string> &files, IxFlag f = IxFNone);
+    bool indexFiles(list<string> &files, IxFlag f = IxFNone);
 
+    /** Update index for list of documents given as list of docs (out of query)
+     */
+    bool updateDocs(vector<Rcl::Doc> &docs, IxFlag f = IxFNone);
+    static bool docsToPaths(vector<Rcl::Doc> &docs, vector<string> &paths);
     /** Purge a list of files. */
-    bool purgeFiles(std::list<string> &files);
+    bool purgeFiles(list<string> &files);
 
  private:
     RclConfig *m_config;
