@@ -69,8 +69,9 @@ static string mimetypefromdata(const string &fn, bool usfc)
 	    LOGERR(("mimetypefromdata: doexec: status 0x%x\n", status));
 	    return string();
 	}
-	// LOGDEB(("mimetypefromdata: %s [%s]\n", result.c_str(), fn.c_str()));
-
+	LOGDEB2(("mimetype: [%s] \"file\" output [%s]\n", 
+		 result.c_str(), fn.c_str()));
+	
 	// The normal output from "file -i" looks like the following:
 	//   thefilename.xxx: text/plain; charset=us-ascii
 	// Sometimes the semi-colon is missing like in:
@@ -97,7 +98,7 @@ static string mimetypefromdata(const string &fn, bool usfc)
 	}
 	result = result.substr(fn.size());
 
-	// Now looks like ": text/plain; charset=us-ascii"
+	// Now should look like ": text/plain; charset=us-ascii"
 	// Split it, and take second field
 	list<string> res;
 	stringToStrings(result, res);
@@ -105,10 +106,9 @@ static string mimetypefromdata(const string &fn, bool usfc)
 	    return string();
 	list<string>::iterator it = res.begin();
 	mime = *++it;
-	// Remove possible punctuation at the end. Note that this mangles 
-	// text/x-c++ if there is no semi-colon... handled in mimeconf :(
-	if (mime.length() > 0 && !isalpha(mime[mime.length() - 1]))
-	    mime.erase(mime.length() -1);
+	// Remove possible semi-colon at the end
+	trimstring(mime, " \t;");
+
 	// File -i will sometimes return strange stuff (ie: "very small file")
 	if(mime.find("/") == string::npos) 
 	    mime.clear();
