@@ -40,20 +40,24 @@ public:
     RclMonitor(){}
     virtual ~RclMonitor() {}
     virtual bool addWatch(const string& path, bool isDir) = 0;
-    virtual bool getEvent(RclMonEvent& ev, int secs = -1) = 0;
-    virtual bool ok() = 0;
+    virtual bool getEvent(RclMonEvent& ev, int msecs = -1) = 0;
+    virtual bool ok() const = 0;
     // Does this monitor generate 'exist' events at startup?
-    virtual bool generatesExist() = 0; 
+    virtual bool generatesExist() const = 0; 
 };
 
 // Monitor factory. We only have one compiled-in kind at a time, no
 // need for a 'kind' parameter
 static RclMonitor *makeMonitor();
 
-/** This class is a callback for the file system tree walker
-    class. The callback method alternatively creates the directory
-    watches and flushes the event queue (to avoid a possible overflow
-    while we create the watches)*/
+/** 
+ * Create directory watches during the initial file system tree walk.
+ *
+ * This class is a callback for the file system tree walker
+ * class. The callback method alternatively creates the directory
+ * watches and flushes the event queue (to avoid a possible overflow
+ * while we create the watches)
+ */
 class WalkCB : public FsTreeWalkerCB {
 public:
     WalkCB(RclConfig *conf, RclMonitor *mon, RclMonEventQueue *queue,
@@ -96,6 +100,16 @@ public:
 		   flg == FsTreeWalker::FtwRegular) {
 	    // Have to synthetize events for regular files existence
 	    // at startup because the monitor does not do it
+	    // Note 2011-09-29: no sure this is actually needed. We just ran
+	    //  an incremental indexing pass (before starting the
+	    //  monitor). Why go over the files once more ? The only
+	    //  reason I can see would be to catch modifications that
+	    //  happen between the incremental and the start of
+	    //  monitoring ? There should be another way: maybe start
+	    //  monitoring without actually handling events (just
+	    //  queue), then run incremental then start handling
+	    //  events ? But we also have to do it on a directory
+	    //  move! So keep it
 	    RclMonEvent ev;
 	    ev.m_path = fn;
 	    ev.m_etyp = RclMonEvent::RCLEVT_MODIFY;
@@ -118,7 +132,19 @@ void *rclMonRcvRun(void *q)
 
     LOGDEB(("rclMonRcvRun: running\n"));
     recoll_threadinit();
+    // Make a local copy of the configuration as it doesn't like
+    // concurrent accesses. It's ok to copy it here as the other
+    // thread will not work before we have sent events.
+    RclConfig lconfig(*queue->getConfig());
 
+    string loglevel;
+    lconfig.getConfParam(string("daemloglevel"), loglevel);
+    if (loglevel.empty())
+	lconfig.getConfParam(string("loglevel"), loglevel);
+    if (!loglevel.empty()) {
+	int lev = atoi(loglevel.c_str());
+	DebugLog::getdbl()->setloglevel(lev);
+    }
 
     // Create the fam/whatever interface object
     RclMonitor *mon;
@@ -128,10 +154,6 @@ void *rclMonRcvRun(void *q)
 	return 0;
     }
 
-    // Make a local copy of the configuration as it doesn't like
-    // concurrent accesses. It's ok to copy it here as the other
-    // thread will not work before we have sent events.
-    RclConfig lconfig(*queue->getConfig());
 
     // Get top directories from config 
     list<string> tdl = lconfig.getTopdirs();
@@ -157,16 +179,28 @@ void *rclMonRcvRun(void *q)
 	    walker.setOpts(FsTreeWalker::FtwOptNone);
 	}
 	LOGDEB(("rclMonRcvRun: walking %s\n", it->c_str()));
-	walker.walk(*it, walkcb);
+	if (walker.walk(*it, walkcb) != FsTreeWalker::FtwOk) {
+	    LOGERR(("rclMonRcvRun: tree walk failed\n"));
+	    goto terminate;
+	}
+	if (walker.getErrCnt() > 0) {
+	    LOGINFO(("rclMonRcvRun: fs walker errors: %s\n", 
+		     walker.getReason().c_str()));
+	}
     }
 
-    bool dobeagle = false;
-    lconfig.getConfParam("processbeaglequeue", &dobeagle);
-    if (dobeagle) {
-        string beaglequeuedir;
-        if (!lconfig.getConfParam("beaglequeuedir", beaglequeuedir))
-            beaglequeuedir = path_tildexpand("~/.beagle/ToIndex/");
-        mon->addWatch(beaglequeuedir, true);
+    {
+	bool dobeagle = false;
+	lconfig.getConfParam("processbeaglequeue", &dobeagle);
+	if (dobeagle) {
+	    string beaglequeuedir;
+	    if (!lconfig.getConfParam("beaglequeuedir", beaglequeuedir))
+		beaglequeuedir = path_tildexpand("~/.beagle/ToIndex/");
+	    if (!mon->addWatch(beaglequeuedir, true)) {
+		LOGERR(("rclMonRcvRun: addwatch (beaglequeuedit) failed\n"));
+		goto terminate;
+	    }
+	}
     }
 
     // Forever wait for monitoring events and add them to queue:
@@ -178,25 +212,66 @@ void *rclMonRcvRun(void *q)
 	// (it goes to the main thread, from which I tried to close or
 	// write to the select fd, with no effect). So set a 
 	// timeout so that an intr will be detected
-	if (mon->getEvent(ev, 2)) {
+	if (mon->getEvent(ev, 2000)) {
+	    // Don't push events for skipped files. This would get
+	    // filtered on the processing side anyway, but causes
+	    // unnecessary wakeups and messages
+	    lconfig.setKeyDir(path_getfather(ev.m_path));
+	    walker.setSkippedNames(lconfig.getSkippedNames());
+	    if (walker.inSkippedNames(path_getsimple(ev.m_path)) || 
+		walker.inSkippedPaths(ev.m_path))
+		continue;
+
 	    if (ev.m_etyp == RclMonEvent::RCLEVT_DIRCREATE) {
-		// Add watch after checking that this doesn't match
-		// ignored files or paths
-		string name = path_getsimple(ev.m_path);
-		if (!walker.inSkippedNames(name) && 
-		    !walker.inSkippedPaths(ev.m_path))
-		    mon->addWatch(ev.m_path, true);
+		// Recursive addwatch: there may already be stuff
+		// inside this directory. Ie: files were quickly
+		// created, or this is actually the target of a
+		// directory move. This is necessary for inotify, but
+		// it seems that fam/gamin is doing the job for us so
+		// that we are generating double events here (no big
+		// deal as prc will sort/merge).
+		LOGDEB(("rclMonRcvRun: walking new dir %s\n", 
+			ev.m_path.c_str()));
+		if (walker.walk(ev.m_path, walkcb) != FsTreeWalker::FtwOk) {
+		    LOGERR(("rclMonRcvRun: walking new dir %s: %s\n", 
+			    ev.m_path.c_str(), walker.getReason().c_str()));
+		    goto terminate;
+		}
+		if (walker.getErrCnt() > 0) {
+		    LOGINFO(("rclMonRcvRun: fs walker errors: %s\n", 
+			     walker.getReason().c_str()));
+		}
 	    }
+
 	    if (ev.m_etyp !=  RclMonEvent::RCLEVT_NONE)
 		queue->pushEvent(ev);
 	}
     }
 
+terminate:
     queue->setTerminate();
     LOGINFO(("rclMonRcvRun: monrcv thread routine returning\n"));
     return 0;
 }
 
+// Utility routine used by both the fam/gamin and inotify versions to get 
+// rid of the id-path translation for a moved dir
+bool eraseWatchSubTree(map<int, string>& idtopath, const string& top)
+{
+    bool found = false;
+    MONDEB(("Clearing map for [%s]\n", top.c_str()));
+    map<int,string>::iterator it = idtopath.begin();
+    while (it != idtopath.end()) {
+	if (it->second.find(top) == 0) {
+	    found = true;
+	    idtopath.erase(it++);
+	} else {
+	    it++;
+	}
+    }
+    return found;
+}
+
 // We dont compile both the inotify and the fam interface and inotify
 // has preference
 #ifndef RCL_USE_INOTIFY
@@ -205,6 +280,9 @@ void *rclMonRcvRun(void *q)
 /** Fam/gamin -based monitor class */
 #include <fam.h>
 #include <sys/select.h>
+#include <setjmp.h>
+#include <unistd.h>
+#include <signal.h>
 
 /** FAM based monitor class. We have to keep a record of FAM watch
     request numbers to directory names as the event only contain the
@@ -214,9 +292,9 @@ public:
     RclFAM();
     virtual ~RclFAM();
     virtual bool addWatch(const string& path, bool isdir);
-    virtual bool getEvent(RclMonEvent& ev, int secs = -1);
-    bool ok() {return m_ok;}
-    virtual bool generatesExist() {return true;}
+    virtual bool getEvent(RclMonEvent& ev, int msecs = -1);
+    bool ok() const {return m_ok;}
+    virtual bool generatesExist() const {return true;}
 
 private:
     bool m_ok;
@@ -225,7 +303,7 @@ private:
 	FAMClose(&m_conn);
 	m_ok = false;
     }
-    map<int,string> m_reqtopath;
+    map<int,string> m_idtopath;
     const char *event_name(int code);
 };
 
@@ -269,30 +347,53 @@ RclFAM::~RclFAM()
 	FAMClose(&m_conn);
 }
 
+static jmp_buf jbuf;
+static void onalrm(int sig)
+{
+    longjmp(jbuf, 1);
+}
 bool RclFAM::addWatch(const string& path, bool isdir)
 {
     if (!ok())
 	return false;
+    bool ret = false;
+
     MONDEB(("RclFAM::addWatch: adding %s\n", path.c_str()));
+
+    // It happens that the following call block forever. 
+    // We'd like to be able to at least terminate on a signal here, but
+    // gamin forever retries its write call on EINTR, so it's not even useful
+    // to unblock signals. SIGALRM is not used by the main thread, so at least
+    // ensure that we exit after gamin gets stuck.
+    if (setjmp(jbuf)) {
+	LOGERR(("RclFAM::addWatch: timeout talking to FAM\n"));
+	return false;
+    }
+    signal(SIGALRM, onalrm);
+    alarm(20);
     FAMRequest req;
     if (isdir) {
 	if (FAMMonitorDirectory(&m_conn, path.c_str(), &req, 0) != 0) {
 	    LOGERR(("RclFAM::addWatch: FAMMonitorDirectory failed\n"));
-	    return false;
+	    goto out;
 	}
     } else {
 	if (FAMMonitorFile(&m_conn, path.c_str(), &req, 0) != 0) {
 	    LOGERR(("RclFAM::addWatch: FAMMonitorFile failed\n"));
-	    return false;
+	    goto out;
 	}
     }
-    m_reqtopath[req.reqnum] = path;
-    return true;
+    m_idtopath[req.reqnum] = path;
+    ret = true;
+
+out:
+    alarm(0);
+    return ret;
 }
 
 // Note: return false only for queue empty or error 
 // Return EVT_NONE for bad event to keep queue processing going
-bool RclFAM::getEvent(RclMonEvent& ev, int secs)
+bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
 {
     if (!ok())
 	return false;
@@ -304,13 +405,18 @@ bool RclFAM::getEvent(RclMonEvent& ev, int secs)
     FD_SET(fam_fd, &readfds);
 
     MONDEB(("RclFAM::getEvent: select. fam_fd is %d\n", fam_fd));
+    // Fam / gamin is sometimes a bit slow to send events. Always add
+    // a little timeout, because if we fail to retrieve enough events,
+    // we risk deadlocking in addwatch()
+    if (msecs == 0)
+	msecs = 2;
     struct timeval timeout;
-    if (secs >= 0) {
-	memset(&timeout, 0, sizeof(timeout));
-	timeout.tv_sec = secs;
+    if (msecs >= 0) {
+	timeout.tv_sec = msecs / 1000;
+	timeout.tv_usec = (msecs % 1000) * 1000;
     }
     int ret;
-    if ((ret=select(fam_fd+1, &readfds, 0, 0, secs >= 0 ? &timeout : 0)) < 0) {
+    if ((ret=select(fam_fd+1, &readfds, 0, 0, msecs >= 0 ? &timeout : 0)) < 0) {
 	LOGERR(("RclFAM::getEvent: select failed, errno %d\n", errno));
 	close();
 	return false;
@@ -346,7 +452,7 @@ bool RclFAM::getEvent(RclMonEvent& ev, int secs)
     
     map<int,string>::const_iterator it;
     if ((fe.filename[0] != '/') && 
-	(it = m_reqtopath.find(fe.fr.reqnum)) != m_reqtopath.end()) {
+	(it = m_idtopath.find(fe.fr.reqnum)) != m_idtopath.end()) {
 	ev.m_path = path_cat(it->second, fe.filename);
     } else {
 	ev.m_path = fe.filename;
@@ -368,13 +474,15 @@ bool RclFAM::getEvent(RclMonEvent& ev, int secs)
 	ev.m_etyp = RclMonEvent::RCLEVT_MODIFY;
 	break;
 
+    case FAMMoved: 
     case FAMDeleted:
 	ev.m_etyp = RclMonEvent::RCLEVT_DELETE;
-	break;
-
-    case FAMMoved: /* Never generated it seems */
-	LOGINFO(("RclFAM::getEvent: got move event !\n"));
-	ev.m_etyp = RclMonEvent::RCLEVT_MODIFY;
+	// We would like to signal a directory here to enable cleaning
+	// the subtree (on a dir move), but can't test the actual file
+	// which is gone, and fam doesn't tell us if it's a dir or reg. 
+	// Let's rely on the fact that a directory should be watched
+	if (eraseWatchSubTree(m_idtopath, ev.m_path)) 
+	    ev.m_etyp |= RclMonEvent::RCLEVT_ISDIR;
 	break;
 
     case FAMStartExecuting:
@@ -402,17 +510,29 @@ bool RclFAM::getEvent(RclMonEvent& ev, int secs)
 
 class RclIntf : public RclMonitor {
 public:
-    RclIntf();
-    virtual ~RclIntf();
+    RclIntf()
+	: m_ok(false), m_fd(-1), m_evp(0), m_ep(0)
+    {
+	if ((m_fd = inotify_init()) < 0) {
+	    LOGERR(("RclIntf:: inotify_init failed, errno %d\n", errno));
+	    return;
+	}
+	m_ok = true;
+    }
+    virtual ~RclIntf()
+    {
+	close();
+    }
+
     virtual bool addWatch(const string& path, bool isdir);
-    virtual bool getEvent(RclMonEvent& ev, int secs = -1);
-    bool ok() {return m_ok;}
-    virtual bool generatesExist() {return false;}
+    virtual bool getEvent(RclMonEvent& ev, int msecs = -1);
+    bool ok() const {return m_ok;}
+    virtual bool generatesExist() const {return false;}
 
 private:
     bool m_ok;
     int m_fd;
-    map<int,string> m_wdtopath; // Watch descriptor to name
+    map<int,string> m_idtopath; // Watch descriptor to name
 #define EVBUFSIZE (32*1024)
     char m_evbuf[EVBUFSIZE]; // Event buffer
     char *m_evp; // Pointer to next event or 0
@@ -456,46 +576,33 @@ const char *RclIntf::event_name(int code)
     };
 }
 
-RclIntf::RclIntf()
-    : m_ok(false), m_fd(-1), m_evp(0), m_ep(0)
-{
-    if ((m_fd = inotify_init()) < 0) {
-	LOGERR(("RclIntf::RclIntf: inotify_init failed, errno %d\n", errno));
-	return;
-    }
-    m_ok = true;
-}
-
-RclIntf::~RclIntf()
-{
-    close();
-}
-
 bool RclIntf::addWatch(const string& path, bool)
 {
    if (!ok())
-        return false;
+       return false;
    MONDEB(("RclIntf::addWatch: adding %s\n", path.c_str()));
     // CLOSE_WRITE is covered through MODIFY. CREATE is needed for mkdirs
     uint32_t mask = IN_MODIFY | IN_CREATE
-        | IN_MOVED_FROM | IN_MOVED_TO
-	| IN_DELETE
+        | IN_MOVED_FROM | IN_MOVED_TO | IN_DELETE
 #ifdef IN_DONT_FOLLOW
 	| IN_DONT_FOLLOW
 #endif
-;
+#ifdef IN_EXCL_UNLINK
+	| IN_EXCL_UNLINK
+#endif
+	;
     int wd;
     if ((wd = inotify_add_watch(m_fd, path.c_str(), mask)) < 0) {
         LOGERR(("RclIntf::addWatch: inotify_add_watch failed\n"));
 	return false;
     }
-    m_wdtopath[wd] = path;
+    m_idtopath[wd] = path;
     return true;
 }
 
 // Note: return false only for queue empty or error 
 // Return EVT_NONE for bad event to keep queue processing going
-bool RclIntf::getEvent(RclMonEvent& ev, int secs)
+bool RclIntf::getEvent(RclMonEvent& ev, int msecs)
 {
     if (!ok())
 	return false;
@@ -507,13 +614,13 @@ bool RclIntf::getEvent(RclMonEvent& ev, int secs)
 	FD_ZERO(&readfds);
 	FD_SET(m_fd, &readfds);
 	struct timeval timeout;
-	if (secs >= 0) {
-	    memset(&timeout, 0, sizeof(timeout));
-	    timeout.tv_sec = secs;
+	if (msecs >= 0) {
+	    timeout.tv_sec = msecs / 1000;
+	    timeout.tv_usec = (msecs % 1000) * 1000;
 	}
 	int ret;
 	MONDEB(("RclIntf::getEvent: select\n"));
-	if ((ret=select(m_fd + 1, &readfds, 0, 0, secs >= 0 ? &timeout : 0)) < 0) {
+	if ((ret=select(m_fd + 1, &readfds, 0, 0, msecs >= 0 ? &timeout : 0)) < 0) {
 	    LOGERR(("RclIntf::getEvent: select failed, errno %d\n", errno));
 	    close();
 	    return false;
@@ -545,8 +652,8 @@ bool RclIntf::getEvent(RclMonEvent& ev, int secs)
 	m_evp = m_ep = 0;
     
     map<int,string>::const_iterator it;
-    if ((it = m_wdtopath.find(evp->wd)) == m_wdtopath.end()) {
-	LOGERR(("RclIntf::getEvent: unknown wd\n"));
+    if ((it = m_idtopath.find(evp->wd)) == m_idtopath.end()) {
+	LOGERR(("RclIntf::getEvent: unknown wd %d\n", evp->wd));
 	return true;
     }
     ev.m_path = it->second;
@@ -558,16 +665,37 @@ bool RclIntf::getEvent(RclMonEvent& ev, int secs)
     MONDEB(("RclIntf::getEvent: %-12s %s\n", 
 	    event_name(evp->mask), ev.m_path.c_str()));
 
-    if (evp->mask & (IN_MODIFY | IN_MOVED_TO)) {
+    if ((evp->mask & IN_MOVED_FROM) && (evp->mask & IN_ISDIR)) {
+	// We get this when a directory is renamed. Erase the subtree
+	// entries in the map. The subsequent MOVED_TO will recreate
+	// them. This is probably not needed because the watches
+	// actually still exist in the kernel, so that the wds
+	// returned by future addwatches will be the old ones, and the
+	// map will be updated in place. But still, this feels safer
+	eraseWatchSubTree(m_idtopath, ev.m_path);
+    }
+
+
+    if (evp->mask & (IN_MODIFY)) {
 	ev.m_etyp = RclMonEvent::RCLEVT_MODIFY;
     } else if (evp->mask & (IN_DELETE | IN_MOVED_FROM)) {
 	ev.m_etyp = RclMonEvent::RCLEVT_DELETE;
-    } else if (evp->mask & (IN_CREATE)) {
-	if (path_isdir(ev.m_path)) {
+	if (evp->mask & IN_ISDIR)
+	    ev.m_etyp |= RclMonEvent::RCLEVT_ISDIR;
+    } else if (evp->mask & (IN_CREATE | IN_MOVED_TO)) {
+	if (evp->mask & IN_ISDIR) {
 	    ev.m_etyp = RclMonEvent::RCLEVT_DIRCREATE;
 	} else {
-	    // Return null event. Will get modify event later
-	    return true;
+	    // We used to return null event because we would get a
+	    // modify event later, but it seems not to be the case any
+	    // more (10-2011). So generate MODIFY event
+	    ev.m_etyp = RclMonEvent::RCLEVT_MODIFY;
+	}
+    } else if (evp->mask & (IN_IGNORED)) {
+	if (!m_idtopath.erase(evp->wd)) {
+	    LOGDEB0(("Got IGNORE event for unknown watch\n"));
+	} else {
+	    eraseWatchSubTree(m_idtopath, ev.m_path);
 	}
     } else {
 	LOGDEB(("RclIntf::getEvent: unhandled event %s 0x%x %s\n", 
