@@ -32,6 +32,7 @@
 using namespace std;
 #endif /* NO_NAMESPACES */
 
+#include "cstr.h"
 #include "internfile.h"
 #include "rcldoc.h"
 #include "mimetype.h"
@@ -51,7 +52,6 @@ using namespace std;
 #include "pxattr.h"
 #endif // RCL_USE_XATTR
 
-static const string cstr_stxtplain("text/plain");
 
 // The internal path element separator. This can't be the same as the rcldb 
 // file to ipath separator : "|"
@@ -206,7 +206,7 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
     // Indexing by udi makes things easier (because they sometimes get a temp 
     // as input
     string udi;
-    make_udi(f, "", udi);
+    make_udi(f, cstr_null, udi);
 
     cnf->setKeyDir(path_getfather(m_fn));
 
@@ -239,6 +239,8 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
             l_mime = *imime;
     }
 
+    size_t docsize = stp->st_size;
+
     if (!l_mime.empty()) {
 	// Has mime: check for a compressed file. If so, create a
 	// temporary uncompressed file, and rerun the mime type
@@ -255,8 +257,16 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
 		LOGDEB1(("FileInterner:: after ucomp: m_tdir %s, tfile %s\n", 
 			 m_tdir.dirname(), m_tfile.c_str()));
 		m_fn = m_tfile;
-		// Note: still using the original file's stat. right ?
-		l_mime = mimetype(m_fn, stp, m_cfg, usfci);
+		// Stat the uncompressed file, mainly to get the size
+		struct stat ucstat;
+		if (stat(m_fn.c_str(), &ucstat) != 0) {
+		    LOGERR(("FileInterner: can't stat the uncompressed file"
+			    "[%s] errno %d\n", m_fn.c_str(), errno));
+		    return;
+		} else {
+		    docsize = ucstat.st_size;
+		}
+		l_mime = mimetype(m_fn, &ucstat, m_cfg, usfci);
 		if (l_mime.empty() && imime)
 		    l_mime = *imime;
 	    } else {
@@ -294,6 +304,7 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
     reapXAttrs(f);
 #endif //RCL_USE_XATTR
 
+    df->set_docsize(docsize);
     if (!df->set_document_file(m_fn)) {
 	LOGERR(("FileInterner:: error converting %s\n", m_fn.c_str()));
 	return;
@@ -335,6 +346,7 @@ void FileInterner::init(const string &data, RclConfig *cnf,
 			    m_forPreview ? "view" : "index");
 
     bool setres = false;
+    df->set_docsize(data.length());
     if (df->is_data_input_ok(Dijon::Filter::DOCUMENT_STRING)) {
 	setres = df->set_document_string(data);
     } else if (df->is_data_input_ok(Dijon::Filter::DOCUMENT_DATA)) {
@@ -366,10 +378,10 @@ void FileInterner::initcommon(RclConfig *cnf, int flags)
     m_handlers.reserve(MAXHANDLERS);
     for (unsigned int i = 0; i < MAXHANDLERS; i++)
 	m_tmpflgs[i] = false;
-    m_targetMType = cstr_stxtplain;
+    m_targetMType = cstr_textplain;
 }
 
-// We used a single beagle cache object to access beagle data. We protect it 
+// We use a single beagle cache object to access beagle data. We protect it 
 // against multiple thread access.
 static PTMutexInit o_beagler_mutex;
 
@@ -391,14 +403,12 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
     // and use some kind of backstore object factory next time we add a 
     // backend (if ever). 
     string backend;
-    map<string, string>::const_iterator it;
-    if ((it = idoc.meta.find(Rcl::Doc::keybcknd)) != idoc.meta.end())
-        backend = it->second;
+    idoc.getmeta(Rcl::Doc::keybcknd, &backend);
     
     if (backend.empty() || !backend.compare("FS")) {
         // Filesystem document. Intern from file.
         // The url has to be like file://
-        if (idoc.url.find("file://") != 0) {
+        if (idoc.url.find(cstr_fileu) != 0) {
             LOGERR(("FileInterner: FS backend and non fs url: [%s]\n",
                     idoc.url.c_str()));
             return;
@@ -412,16 +422,14 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
         }
         init(fn, &st, cnf, flags, &idoc.mimetype);
     } else if (!backend.compare("BGL")) {
-        string data;
-        Rcl::Doc dotdoc;
-        map<string,string>::const_iterator it = 
-            idoc.meta.find(Rcl::Doc::keyudi);
-        if (it == idoc.meta.end() || it->second.empty()) {
+        string udi;
+        if (!idoc.getmeta(Rcl::Doc::keyudi, &udi) || udi.empty()) {
             LOGERR(("FileInterner:: no udi in idoc\n"));
             return;
         }
-        string udi = it->second;
 
+        string data;
+        Rcl::Doc dotdoc;
 	{
 	    PTMutexLocker locker(o_beagler_mutex);
 	    // Retrieve from our webcache (beagle data). The beagler
@@ -445,6 +453,42 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
     }
 }
 
+#include "fsindexer.h"
+bool FileInterner::makesig(const Rcl::Doc& idoc, string& sig)
+{
+    if (idoc.url.empty()) {
+        LOGERR(("FileInterner::makesig:: no url!\n"));
+        return false;
+    }
+    string backend;
+    idoc.getmeta(Rcl::Doc::keybcknd, &backend);
+    
+    if (backend.empty() || !backend.compare("FS")) {
+        if (idoc.url.find(cstr_fileu) != 0) {
+            LOGERR(("FileInterner: FS backend and non fs url: [%s]\n",
+                    idoc.url.c_str()));
+            return false;
+        }
+        string fn = idoc.url.substr(7, string::npos);
+        struct stat st;
+        if (stat(fn.c_str(), &st) < 0) {
+            LOGERR(("FileInterner:: cannot access document file: [%s]\n",
+                    fn.c_str()));
+            return false;
+        }
+	FsIndexer::makesig(&st, sig);
+	return true;
+    } else if (!backend.compare("BGL")) {
+	// Bgl sigs are empty
+	sig.clear();
+	return true;
+    } else {
+        LOGERR(("FileInterner:: unknown backend: [%s]\n", backend.c_str()));
+        return false;
+    }
+    return false;
+}
+
 FileInterner::~FileInterner()
 {
     tmpcleanup();
@@ -547,6 +591,50 @@ void FileInterner::getMissingDescription(FIMissingStore *st, string& out)
     }
 }
 
+void FileInterner::getMissingFromDescription(FIMissingStore *st, const string& in)
+{
+    if (st == 0)
+	return;
+
+    // The "missing" file is text. Each line defines a missing filter
+    // and the list of mime types actually encountered that needed it (see method
+    // getMissingDescription())
+
+    vector<string> lines;
+    stringToTokens(in, lines, "\n");
+
+    for (vector<string>::const_iterator it = lines.begin();
+	 it != lines.end(); it++) {
+	// Lines from the file are like: 
+	//
+	// filter name string (mime1 mime2) 
+	//
+	// We can't be too sure that there will never be a parenthesis
+	// inside the filter string as this comes from the filter
+	// itself. The list part is safer, so we start from the end.
+	const string& line = *it;
+	string::size_type lastopen = line.find_last_of("(");
+	if (lastopen == string::npos)
+	    continue;
+	string::size_type lastclose = line.find_last_of(")");
+	if (lastclose == string::npos || lastclose <= lastopen + 1)
+	    continue;
+	string smtypes = line.substr(lastopen+1, lastclose - lastopen - 1);
+	vector<string> mtypes;
+	stringToTokens(smtypes, mtypes);
+	string filter = line.substr(0, lastopen);
+	trimstring(filter);
+	if (filter.empty())
+	    continue;
+
+	st->m_missingExternal.insert(filter);
+	for (vector<string>::const_iterator itt = mtypes.begin(); 
+	     itt != mtypes.end(); itt++) {
+	    st->m_typesForMissing[filter].insert(*itt);
+	}
+    }
+}
+
 // Helper for extracting a value from a map.
 static inline bool getKeyValue(const map<string, string>& docdata, 
 			       const string& key, string& value)
@@ -562,18 +650,6 @@ static inline bool getKeyValue(const map<string, string>& docdata,
     return false;
 }
 
-// These defs are for the Dijon meta array. Rcl::Doc predefined field
-// names are used where appropriate. In some cases, Rcl::Doc names are
-// used inside the Dijon metadata (ex: origcharset)
-static const string cstr_keyau("author");
-static const string cstr_keycs("charset");
-static const string cstr_keyct("content");
-static const string cstr_keyds("description");
-static const string cstr_keyfn("filename");
-static const string cstr_keymd("modificationdate");
-static const string cstr_keymt("mimetype");
-static const string cstr_keytt("title");
-
 bool FileInterner::dijontorcl(Rcl::Doc& doc)
 {
     Dijon::Filter *df = m_handlers.back();
@@ -586,31 +662,53 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 
     for (map<string,string>::const_iterator it = docdata.begin(); 
 	 it != docdata.end(); it++) {
-	if (it->first == cstr_keyct) {
+	if (it->first == cstr_dj_keycontent) {
 	    doc.text = it->second;
-	} else if (it->first == cstr_keymd) {
+	    if (doc.fbytes.empty()) {
+		// It's normally set by walking the filter stack, in
+		// collectIpathAndMt, which was called before us.  It
+		// can happen that the doc size is still empty at this
+		// point if the last container filter is directly
+		// returning text/plain content, so that there is no
+		// ipath-less filter at the top
+		char cbuf[30];
+		sprintf(cbuf, "%d", int(doc.text.length()));
+		doc.fbytes = cbuf;
+	    }
+	} else if (it->first == cstr_dj_keymd) {
 	    doc.dmtime = it->second;
-	} else if (it->first == Rcl::Doc::keyoc) {
+	} else if (it->first == cstr_dj_keyorigcharset) {
 	    doc.origcharset = it->second;
-	} else if (it->first == cstr_keymt || it->first == cstr_keycs) {
+	} else if (it->first == cstr_dj_keymt || 
+		   it->first == cstr_dj_keycharset) {
 	    // don't need/want these.
 	} else {
 	    doc.meta[it->first] = it->second;
 	}
     }
-    if (doc.meta[Rcl::Doc::keyabs].empty() && !doc.meta[cstr_keyds].empty()) {
-	doc.meta[Rcl::Doc::keyabs] = doc.meta[cstr_keyds];
-	doc.meta.erase(cstr_keyds);
+    if (doc.meta[Rcl::Doc::keyabs].empty() && 
+	!doc.meta[cstr_dj_keyds].empty()) {
+	doc.meta[Rcl::Doc::keyabs] = doc.meta[cstr_dj_keyds];
+	doc.meta.erase(cstr_dj_keyds);
     }
     return true;
 }
 
 // Collect the ipath from the current path in the document tree.
-// While we're at it, we also set the mimetype and filename, which are special 
-// properties: we want to get them from the topmost doc
-// with an ipath, not the last one which is usually text/plain
-// We also set the author and modification time from the last doc
-// which has them.
+// While we're at it, we also set the mimetype and filename,
+// which are special properties: we want to get them from the topmost
+// doc with an ipath, not the last one which is usually text/plain We
+// also set the author and modification time from the last doc which
+// has them.
+//
+// The docsize is fetched from the first element without an ipath
+// (first non container). If the last element directly returns
+// text/plain so that there is no ipath-less element, the value will
+// be set in dijontorcl(). 
+// 
+// The whole thing is a bit messy but it's not obvious how it should
+// be cleaned up as the "inheritance" rules inside the stack are
+// actually complicated.
 void FileInterner::collectIpathAndMT(Rcl::Doc& doc) const
 {
     LOGDEB2(("FileInterner::collectIpathAndMT\n"));
@@ -632,19 +730,24 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc) const
     for (vector<Dijon::Filter*>::const_iterator hit = m_handlers.begin();
 	 hit != m_handlers.end(); hit++) {
 	const map<string, string>& docdata = (*hit)->get_meta_data();
-	if (getKeyValue(docdata, "ipath", ipathel)) {
+	if (getKeyValue(docdata, cstr_dj_keyipath, ipathel)) {
 	    if (!ipathel.empty()) {
 		// We have a non-empty ipath
 		hasipath = true;
-		getKeyValue(docdata, cstr_keymt, doc.mimetype);
-		getKeyValue(docdata, cstr_keyfn, doc.utf8fn);
+		getKeyValue(docdata, cstr_dj_keymt, doc.mimetype);
+		getKeyValue(docdata, cstr_dj_keyfn, doc.utf8fn);
+	    } else {
+		if (doc.fbytes.empty())
+		    getKeyValue(docdata, cstr_dj_keydocsize, doc.fbytes);
 	    }
 	    doc.ipath += colon_hide(ipathel) + cstr_isep;
 	} else {
+	    if (doc.fbytes.empty())
+		getKeyValue(docdata, cstr_dj_keydocsize, doc.fbytes);
 	    doc.ipath += cstr_isep;
 	}
-	getKeyValue(docdata, cstr_keyau, doc.meta[Rcl::Doc::keyau]);
-	getKeyValue(docdata, cstr_keymd, doc.dmtime);
+	getKeyValue(docdata, cstr_dj_keyauthor, doc.meta[Rcl::Doc::keyau]);
+	getKeyValue(docdata, cstr_dj_keymd, doc.dmtime);
     }
 
     // Trim empty tail elements in ipath.
@@ -682,8 +785,8 @@ int FileInterner::addHandler()
 {
     const map<string, string>& docdata = m_handlers.back()->get_meta_data();
     string charset, mimetype;
-    getKeyValue(docdata, cstr_keycs, charset);
-    getKeyValue(docdata, cstr_keymt, mimetype);
+    getKeyValue(docdata, cstr_dj_keycharset, charset);
+    getKeyValue(docdata, cstr_dj_keymt, mimetype);
 
     LOGDEB(("FileInterner::addHandler: next_doc is %s\n", mimetype.c_str()));
 
@@ -691,7 +794,7 @@ int FileInterner::addHandler()
     // general), we're done decoding. If we hit text/plain, we're done
     // in any case
     if (!stringicmp(mimetype, m_targetMType) || 
-	!stringicmp(mimetype, cstr_stxtplain)) {
+	!stringicmp(mimetype, cstr_textplain)) {
 	m_reachedMType = mimetype;
 	LOGDEB1(("FileInterner::addHandler: target reached\n"));
 	return ADD_BREAK;
@@ -724,11 +827,12 @@ int FileInterner::addHandler()
     const string *txt = &ns;
     {
 	map<string,string>::const_iterator it;
-	it = docdata.find(cstr_keyct);
+	it = docdata.find(cstr_dj_keycontent);
 	if (it != docdata.end())
 	    txt = &it->second;
     }
     bool setres = false;
+    newflt->set_docsize(txt->length());
     if (newflt->is_data_input_ok(Dijon::Filter::DOCUMENT_STRING)) {
 	setres = newflt->set_document_string(*txt);
     } else if (newflt->is_data_input_ok(Dijon::Filter::DOCUMENT_DATA)) {
