@@ -121,6 +121,11 @@ class FileInterner {
     FileInterner(const Rcl::Doc& idoc, RclConfig *cnf, TempDir &td, 
                  int flags);
 
+    /** 
+     * Build sig for doc coming from rcldb. This is here because we know how
+     * to query the right backend */
+    static bool makesig(const Rcl::Doc& idoc, string& sig);
+
     ~FileInterner();
 
     void setMissingStore(FIMissingStore *st)
@@ -193,6 +198,8 @@ class FileInterner {
     const string& getReason() const {return m_reason;}
     static void getMissingExternal(FIMissingStore *st, string& missing);
     static void getMissingDescription(FIMissingStore *st, string& desc);
+    // Parse "missing" file contents into memory struct
+    static void getMissingFromDescription(FIMissingStore *st, const string& desc);
     bool ok() {return m_ok;}
 
  private:
