@@ -14,14 +14,13 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-
+#include "cstr.h"
 #include "execmd.h"
 #include "mh_exec.h"
 #include "mh_html.h"
 #include "debuglog.h"
 #include "cancelcheck.h"
 #include "smallut.h"
-#include "transcode.h"
 #include "md5.h"
 #include "rclconfig.h"
 
@@ -95,7 +94,7 @@ bool MimeHandlerExec::next_document()
 	myparams.push_back(m_ipath);
 
     // Execute command, store the output
-    string& output = m_metaData["content"];
+    string& output = m_metaData[cstr_dj_keycontent];
     output.erase();
     ExecCmd mexec;
     MEAdv adv(filtermaxseconds);
@@ -146,56 +145,27 @@ bool MimeHandlerExec::next_document()
 
 void MimeHandlerExec::finaldetails()
 {
-    string& output = m_metaData["content"];
+    m_metaData[cstr_dj_keyorigcharset] = m_dfltInputCharset;
 
-    // If output is text/plain (not text/html), we may have to convert
-    // it to utf-8, because this is the last point where it can be done.
     // cfgFilterOutputCharset comes from the mimeconf filter definition line
-    string charset = cfgFilterOutputCharset.empty() ? "utf-8" : 
-	cfgFilterOutputCharset;
-    bool trustcharset = true;
+    string& charset = m_metaData[cstr_dj_keycharset];
+    charset = cfgFilterOutputCharset.empty() ? "UTF-8" : cfgFilterOutputCharset;
     if (!stringlowercmp("default", charset)) {
 	charset = m_dfltInputCharset;
-	trustcharset = false;
     }
-    string mt = cfgFilterOutputMtype.empty() ? "text/html" : 
+
+    string& mt = m_metaData[cstr_dj_keymt];
+    mt = cfgFilterOutputMtype.empty() ? "text/html" : 
 	cfgFilterOutputMtype;
 
-    // If this is text/plain and not utf-8 or untrusted, transcode to utf-8.
-    if (!mt.compare("text/plain") && 
-	(!trustcharset || stringlowercmp("utf-8", charset))) {
-	string transcoded;
-	int ecnt;
-	if (!transcode(output, transcoded, charset, "UTF-8", &ecnt)) {
-	    LOGERR(("mh_exec: transcode failed from [%s] to UTF-8\n",
-		    charset.c_str()));
-	    // Erase text in this case: it's garbage
-	    output.clear();
-	} else {
-	    if (ecnt) {
-		LOGDEB(("mh_exec: %d transcoding errors  from [%s] to UTF-8\n",
-			ecnt, charset.c_str()));
-	    }
-	    output = transcoded;
-	    charset = "utf-8";
-	}
+    // If this is text/plain transcode_to/check utf-8
+    if (!mt.compare(cstr_textplain)) {
+	(void)txtdcode("mh_exec");
     }
 
-    // Success. Store some external metadata
-
-    // Original charset. Can't be too sure about this actually. It's
-    // just a hint anyway
-    m_metaData["origcharset"] = m_dfltInputCharset;
-
-    // Supposed contents charset encoding. This could still be
-    // overridden by the content-type meta tag for html, but this is
-    // wasteful so we hope it's correct
-    m_metaData["charset"] = charset;
-    m_metaData["mimetype"] = mt;
-
     string md5, xmd5, reason;
     if (MD5File(m_fn, md5, &reason)) {
-	m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+	m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
     } else {
 	LOGERR(("MimeHandlerExec: cant compute md5 for [%s]: %s\n", 
 		m_fn.c_str(), reason.c_str()));
