@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,6 @@
  */
 #ifndef _MH_EXEC_H_INCLUDED_
 #define _MH_EXEC_H_INCLUDED_
-/* @(#$Id: mh_exec.h,v 1.8 2008-10-06 06:22:46 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <string>
 #include <list>
@@ -68,10 +67,7 @@ class MimeHandlerExec : public RecollFilter {
 	return true;
     }
     virtual bool next_document();
-    virtual bool skip_to_document(const string& ipath) {
-	m_ipath = ipath;
-	return true;
-    }
+    virtual bool skip_to_document(const string& ipath); 
     virtual void clear() {
 	m_fn.erase(); 
 	m_ipath.erase();
