@@ -19,12 +19,12 @@
 #include <iostream>
 #include <sstream>
 
+#include "cstr.h"
 #include "mh_execm.h"
 #include "mh_html.h"
 #include "debuglog.h"
 #include "cancelcheck.h"
 #include "smallut.h"
-#include "transcode.h"
 #include "md5.h"
 #include "rclconfig.h"
 #include "mimetype.h"
@@ -66,7 +66,7 @@ bool MimeHandlerExecMultiple::startCmd()
 }
 
 // Note: data is not used if this is the "document:" field: it goes
-// directly to m_metaData["content"] to avoid an extra copy
+// directly to m_metaData[cstr_dj_keycontent] to avoid an extra copy
 // 
 // Messages are made of data elements. Each element is like:
 // name: len\ndata
@@ -85,7 +85,7 @@ bool MimeHandlerExecMultiple::readDataElement(string& name, string &data)
     // Empty line (end of message) ?
     if (!ibuf.compare("\n")) {
         LOGDEB(("MHExecMultiple: Got empty line\n"));
-        name = "";
+        name.clear();
         return true;
     }
 
@@ -118,11 +118,11 @@ bool MimeHandlerExecMultiple::readDataElement(string& name, string &data)
     LOGDEB1(("MHExecMultiple: got name [%s] len: %d\n", name.c_str(), len));
 
     // Hack: check for 'Document:' and read directly the document data
-    // to m_metaData["content"] to avoid an extra copy of the bulky
+    // to m_metaData[cstr_dj_keycontent] to avoid an extra copy of the bulky
     // piece
     string *datap = &data;
     if (!stringlowercmp("document:", name)) {
-        datap = &m_metaData["content"];
+        datap = &m_metaData[cstr_dj_keycontent];
     } else {
         datap = &data;
     }
@@ -163,7 +163,7 @@ bool MimeHandlerExecMultiple::next_document()
     } else {
         obuf << "Filename: " << 0 << "\n";
     }
-    if (m_ipath.length()) {
+    if (!m_ipath.empty()) {
 	LOGDEB(("next_doc: sending len %d val [%s]\n", m_ipath.length(),
 		m_ipath.c_str()));
         obuf << "Ipath: " << m_ipath.length() << "\n" << m_ipath;
@@ -238,7 +238,7 @@ bool MimeHandlerExecMultiple::next_document()
     // It used to be that eof could be signalled just by an empty document, but
     // this was wrong. Empty documents can be found ie in zip files and should 
     // not be interpreted as eof.
-    if (m_metaData["content"].length() == 0) {
+    if (m_metaData[cstr_dj_keycontent].empty()) {
         LOGDEB0(("MHExecMultiple: got empty document inside [%s]: [%s]\n", 
                 m_fn.c_str(), ipath.c_str()));
     }
@@ -248,14 +248,14 @@ bool MimeHandlerExecMultiple::next_document()
     // mimetype, or the ipath MUST be a filename-like string which we can use
     // to compute a mime type
     if (!ipath.empty()) {
-        m_metaData["ipath"] = ipath;
+        m_metaData[cstr_dj_keyipath] = ipath;
         if (mtype.empty()) {
 	    LOGDEB0(("MHExecMultiple: no mime type from filter, "
 		    "using ipath for a guess\n"));
             mtype = mimetype(ipath, 0, m_config, false);
             if (mtype.empty()) {
                 // mimetype() won't call idFile when there is no file. Do it
-                mtype = idFileMem(m_metaData["content"]);
+                mtype = idFileMem(m_metaData[cstr_dj_keycontent]);
                 if (mtype.empty()) {
                     // Note this happens for example for directory zip members
                     // We could recognize them by the end /, but wouldn't know
@@ -265,16 +265,16 @@ bool MimeHandlerExecMultiple::next_document()
                 }
             }
         }
-        m_metaData["mimetype"] = mtype;
+        m_metaData[cstr_dj_keymt] = mtype;
         string md5, xmd5;
-        MD5String(m_metaData["content"], md5);
-        m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+        MD5String(m_metaData[cstr_dj_keycontent], md5);
+        m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
     } else {
-        m_metaData["mimetype"] = mtype.empty() ? "text/html" : mtype;
-        m_metaData.erase("ipath");
+        m_metaData[cstr_dj_keymt] = mtype.empty() ? "text/html" : mtype;
+        m_metaData.erase(cstr_dj_keyipath);
         string md5, xmd5, reason;
         if (MD5File(m_fn, md5, &reason)) {
-            m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+            m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
         } else {
             LOGERR(("MimeHandlerExecM: cant compute md5 for [%s]: %s\n",
                     m_fn.c_str(), reason.c_str()));
@@ -282,45 +282,27 @@ bool MimeHandlerExecMultiple::next_document()
     }
 
     // Charset. For many document types it doesn't matter. For text
-    // and html it does. We supply a default from the configuration.
-    bool trustcharset = true;
+    // and html it does. We supply a default from the configuration. 
     if (charset.empty()) {
 	charset = cfgFilterOutputCharset.empty() ? "utf-8" : 
 	    cfgFilterOutputCharset;
 	if (!stringlowercmp("default", charset)) {
-	    trustcharset = false;
 	    charset = m_dfltInputCharset;
 	}
     }
+    m_metaData[cstr_dj_keyorigcharset] = charset;
+    m_metaData[cstr_dj_keycharset] = charset;
 
-    string& output = m_metaData["content"];
-    if (!m_metaData["mimetype"].compare("text/plain") && 
-	(!trustcharset || stringlowercmp("utf-8", charset))) {
-	string transcoded;
-	int ecnt;
-	if (!transcode(output, transcoded, charset, "UTF-8", &ecnt)) {
-	    LOGERR(("mh_exec: transcode failed from [%s] to UTF-8\n",
-		    charset.c_str()));
-	    // Erase text in this case: it's garbage
-	    output.clear();
-	} else {
-	    if (ecnt) {
-		LOGDEB(("mh_exec: %d transcoding errors  from [%s] to UTF-8\n",
-			ecnt, charset.c_str()));
-	    }
-	    output = transcoded;
-	    charset = "utf-8";
-	}
+    if (!m_metaData[cstr_dj_keymt].compare(cstr_textplain)) {
+	(void)txtdcode("mh_execm");
     }
     
-    m_metaData["charset"] = charset;
-
+    
     if (eofnext_received)
         m_havedoc = false;
 
     LOGDEB0(("MHExecMultiple: returning %d bytes of content,"
-	    " mtype [%s] charset [%s]\n", 
-	    m_metaData["content"].size(), m_metaData["mimetype"].c_str(),
-	    m_metaData["charset"].c_str()));
+	    " mtype [%s] charset [%s]\n", m_metaData[cstr_dj_keycontent].size(), 
+     m_metaData[cstr_dj_keymt].c_str(), m_metaData[cstr_dj_keycharset].c_str()));
     return true;
 }
