@@ -25,6 +25,7 @@
 #include <map>
 #include <sstream>
 
+#include "cstr.h"
 #include "mimehandler.h"
 #include "readfile.h"
 #include "transcode.h"
@@ -43,16 +44,7 @@
 using namespace std;
 
 static const int maxdepth = 20;
-static const string cstr_mimetype = "mimetype";
-static const string cstr_content = "content";
-static const string cstr_author = "author";
-static const string cstr_recipient = "recipient";
-static const string cstr_modificationdate = "modificationdate";
-static const string cstr_title = "title";
-static const string cstr_msgid = "msgid";
-static const string cstr_abstract = "abstract";
-
-static const string cstr_newline = "\n";
+static const string cstr_mail_charset("charset");
 
 MimeHandlerMail::MimeHandlerMail(RclConfig *cnf, const string &mt) 
     : RecollFilter(cnf, mt), m_bincdoc(0), m_fd(-1), m_stream(0), m_idx(-1)
@@ -82,12 +74,14 @@ void MimeHandlerMail::clear()
     }
     delete m_stream; m_stream = 0;
     m_idx = -1;
+    m_startoftext = 0;
     m_subject.erase();
     for (vector<MHMailAttach*>::iterator it = m_attachments.begin(); 
 	 it != m_attachments.end(); it++) {
 	delete *it;
     }
     m_attachments.clear();
+    m_addProcdHdrs.clear();
     RecollFilter::clear();
 }
 
@@ -104,7 +98,7 @@ bool MimeHandlerMail::set_document_file(const string &fn)
     // the md5 computation to the mime analysis, but ...
     string md5, xmd5, reason;
     if (MD5File(fn, md5, &reason)) {
-	m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+	m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
     } else {
 	LOGERR(("MimeHandlerMail: cant compute md5 for [%s]: %s\n", fn.c_str(),
 		reason.c_str()));
@@ -136,11 +130,19 @@ bool MimeHandlerMail::set_document_string(const string &msgtxt)
 
     string md5, xmd5;
     MD5String(msgtxt, md5);
-    m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+    m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
 
-    m_stream = new stringstream(msgtxt);
+    if ((m_stream = new stringstream(msgtxt)) == 0 || !m_stream->good()) {
+	LOGERR(("MimeHandlerMail::set_document_string: stream create error."
+		"msgtxt.size() %d\n", int(msgtxt.size())));
+	return false;
+    }
     delete m_bincdoc;
-    m_bincdoc = new Binc::MimeDocument;
+    if ((m_bincdoc = new Binc::MimeDocument) == 0) {
+	LOGERR(("MimeHandlerMail::set_doc._string: new Binc:Document failed."
+		" Out of memory?"));
+	return false;
+    }
     m_bincdoc->parseFull(*m_stream);
     if (!m_bincdoc->isHeaderParsed() && !m_bincdoc->isAllParsed()) {
 	LOGERR(("MimeHandlerMail::set_document_string: mime parse error\n"));
@@ -176,16 +178,16 @@ bool MimeHandlerMail::next_document()
     bool res = false;
 
     if (m_idx == -1) {
-	m_metaData[cstr_mimetype] = "text/plain";
+	m_metaData[cstr_dj_keymt] = cstr_textplain;
 	res = processMsg(m_bincdoc, 0);
 	LOGDEB1(("MimeHandlerMail::next_document: mimetype %s\n",
-		m_metaData[cstr_mimetype].c_str()));
-        const string& txt = m_metaData[cstr_content];
+		m_metaData[cstr_dj_keymt].c_str()));
+        const string& txt = m_metaData[cstr_dj_keycontent];
         if (m_startoftext < txt.size())
-            m_metaData[cstr_abstract] = 
+            m_metaData[cstr_dj_keyabstract] = 
                 truncate_to_word(txt.substr(m_startoftext), 250);
     } else {
-        m_metaData[cstr_abstract] = "";
+        m_metaData[cstr_dj_keyabstract].clear();
 	res = processAttach();
     }
     m_idx++;
@@ -239,18 +241,18 @@ bool MimeHandlerMail::processAttach()
     }
     MHMailAttach *att = m_attachments[m_idx];
 
-    m_metaData[cstr_mimetype] = att->m_contentType;
-    m_metaData["charset"] = att->m_charset;
-    m_metaData["filename"] = att->m_filename;
+    m_metaData[cstr_dj_keymt] = att->m_contentType;
+    m_metaData[cstr_dj_keycharset] = att->m_charset;
+    m_metaData[cstr_dj_keyfn] = att->m_filename;
     // Change the title to something helpul
-    m_metaData[cstr_title] = att->m_filename + "  (" + m_subject + ")";
+    m_metaData[cstr_dj_keytitle] = att->m_filename + "  (" + m_subject + ")";
     LOGDEB1(("  processAttach:ct [%s] cs [%s] fn [%s]\n", 
 	    att->m_contentType.c_str(),
 	    att->m_charset.c_str(),
 	    att->m_filename.c_str()));
 
-    m_metaData[cstr_content] = string();
-    string& body = m_metaData[cstr_content];
+    m_metaData[cstr_dj_keycontent] = string();
+    string& body = m_metaData[cstr_dj_keycontent];
     att->m_part->getBody(body, 0, att->m_part->bodylength);
     string decoded;
     const string *bdp;
@@ -263,13 +265,13 @@ bool MimeHandlerMail::processAttach()
     // Special case for text/plain content. Internfile should deal
     // with this but it expects text/plain to be utf-8 already, so we
     // handle the transcoding if needed
-    if (m_metaData[cstr_mimetype] == "text/plain") {
+    if (m_metaData[cstr_dj_keymt] == cstr_textplain) {
 	string utf8;
-	if (!transcode(body, utf8, m_metaData["charset"], "UTF-8")) {
+	if (!transcode(body, utf8, m_metaData[cstr_dj_keycharset], "UTF-8")) {
 	    LOGERR(("  processAttach: transcode to utf-8 failed "
-		    "for charset [%s]\n", m_metaData["charset"].c_str()));
-	    // can't transcode at all -> data is garbage just erase it
-	    body.clear();
+		    "for charset [%s]\n", m_metaData[cstr_dj_keycharset].c_str()));
+ 	    // can't transcode at all -> data is garbage just erase it
+ 	    body.clear();
 	} else {
 	    body = utf8;
 	}
@@ -277,18 +279,18 @@ bool MimeHandlerMail::processAttach()
 
     // Special case for application/octet-stream: try to better
     // identify content, using file name if set
-    if (m_metaData[cstr_mimetype] == "application/octet-stream" &&
-	!m_metaData["filename"].empty()) {
-	string mt = mimetype(m_metaData["filename"], 0,	
+    if (m_metaData[cstr_dj_keymt] == "application/octet-stream" &&
+	!m_metaData[cstr_dj_keyfn].empty()) {
+	string mt = mimetype(m_metaData[cstr_dj_keyfn], 0,	
 			     m_config, false);
 	if (!mt.empty()) 
-	    m_metaData[cstr_mimetype] = mt;
+	    m_metaData[cstr_dj_keymt] = mt;
     }
 
     // Ipath
     char nbuf[20];
     sprintf(nbuf, "%d", m_idx);
-    m_metaData["ipath"] = nbuf;
+    m_metaData[cstr_dj_keyipath] = nbuf;
 
     return true;
 }
@@ -312,7 +314,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
     }
 	
     // Handle some headers. 
-    string& text = m_metaData[cstr_content];
+    string& text = m_metaData[cstr_dj_keycontent];
     Binc::HeaderItem hi;
     string transcoded;
     if (doc->h.getFirstHeader("From", hi)) {
@@ -321,7 +323,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	    text += string("From: ");
 	text += transcoded + cstr_newline;
 	if (depth == 1) {
-	    m_metaData[cstr_author] = transcoded;
+	    m_metaData[cstr_dj_keyauthor] = transcoded;
 	}
     }
     if (doc->h.getFirstHeader("To", hi)) {
@@ -330,7 +332,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	    text += string("To: ");
 	text += transcoded + cstr_newline;
 	if (depth == 1) {
-	    m_metaData[cstr_recipient] = transcoded;
+	    m_metaData[cstr_dj_keyrecipient] = transcoded;
 	}
     }
     if (doc->h.getFirstHeader("Cc", hi)) {
@@ -339,13 +341,13 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	    text += string("Cc: ");
 	text += transcoded + cstr_newline;
 	if (depth == 1) {
-	    m_metaData[cstr_recipient] += " " + transcoded;
+	    m_metaData[cstr_dj_keyrecipient] += " " + transcoded;
 	}
     }
     if (doc->h.getFirstHeader("Message-Id", hi)) {
 	if (depth == 1) {
-	    m_metaData[cstr_msgid] =  hi.getValue();
-            trimstring(m_metaData[cstr_msgid], "<>");
+	    m_metaData[cstr_dj_keymsgid] =  hi.getValue();
+            trimstring(m_metaData[cstr_dj_keymsgid], "<>");
 	}
     }
     if (doc->h.getFirstHeader("Date", hi)) {
@@ -355,7 +357,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	    if (t != (time_t)-1) {
 		char ascuxtime[100];
 		sprintf(ascuxtime, "%ld", (long)t);
-		m_metaData[cstr_modificationdate] = ascuxtime;
+		m_metaData[cstr_dj_keymd] = ascuxtime;
 	    } else {
 		// Leave mtime field alone, ftime will be used instead.
 		LOGDEB(("rfc2822Date...: failed: [%s]\n", transcoded.c_str()));
@@ -368,7 +370,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
     if (doc->h.getFirstHeader("Subject", hi)) {
 	rfc2047_decode(hi.getValue(), transcoded);
 	if (depth == 1) {
-	    m_metaData[cstr_title] = transcoded;
+	    m_metaData[cstr_dj_keytitle] = transcoded;
 	    m_subject = transcoded;
 	}
 	if (preview())
@@ -397,7 +399,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
     walkmime(doc, depth);
 
     LOGDEB2(("MimeHandlerMail::processMsg:text:[%s]\n", 
-	    m_metaData[cstr_content].c_str()));
+	    m_metaData[cstr_dj_keycontent].c_str()));
     return true;
 }
 
@@ -419,7 +421,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
 	return;
     }
 
-    string& out = m_metaData[cstr_content];
+    string& out = m_metaData[cstr_dj_keycontent];
 
     if (doc->isMultipart()) {
 	LOGDEB2(("walkmime: ismultipart %d subtype '%s'\n", 
@@ -452,7 +454,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
 		MimeHeaderValue content_type;
 		parseMimeHeaderValue(hi.getValue(), content_type);
 		LOGDEB2(("walkmime: C-type: %s\n",content_type.value.c_str()));
-		if (!stringlowercmp("text/plain", content_type.value))
+		if (!stringlowercmp(cstr_textplain, content_type.value))
 		    ittxt = it;
 		else if (!stringlowercmp("text/html", content_type.value)) 
 		    ithtml = it;
@@ -473,7 +475,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
 
     // Get and parse content-type header.
     Binc::HeaderItem hi;
-    string ctt = "text/plain";
+    string ctt = cstr_textplain;
     if (doc->h.getFirstHeader("Content-Type", hi)) {
 	ctt = hi.getValue();
     }
@@ -531,7 +533,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
     // to iso-8859 only if the transfer-encoding is 8 bit, or test for
     // actual 8 bit chars, but what the heck, le'ts use 8859-1 as default
     string charset;
-    it = content_type.params.find(string("charset"));
+    it = content_type.params.find(cstr_mail_charset);
     if (it != content_type.params.end())
 	charset = it->second;
     if (charset.empty() || 
@@ -554,8 +556,10 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
     // If the Content-Disposition is not inline, we treat it as
     // attachment, as per rfc2183. 
     // If it is inline but not text or html, same thing.
+    // Some early MIME msgs have "text" instead of "text/plain" as type
     if (stringlowercmp("inline", content_disposition.value) ||
-	(stringlowercmp("text/plain", content_type.value) && 
+	(stringlowercmp(cstr_textplain, content_type.value) && 
+	 stringlowercmp("text", content_type.value) && 
 	 stringlowercmp("text/html", content_type.value)) ) {
 	if (!filename.empty()) {
 	    out += "\n";
@@ -613,7 +617,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
 	mh.set_document_string(body);
 	mh.next_document();
 	map<string, string>::const_iterator it = 
-	    mh.get_meta_data().find(cstr_content);
+	    mh.get_meta_data().find(cstr_dj_keycontent);
 	if (it != mh.get_meta_data().end())
 	    out += it->second;
     } else {
