@@ -27,6 +27,7 @@
 #include <algorithm>
 #include <cstring>
 
+#include "cstr.h"
 #include "myhtmlparse.h"
 #include "indextext.h" // for lowercase_term()
 #include "mimeparse.h"
@@ -35,6 +36,9 @@
 #include "debuglog.h"
 #include "transcode.h"
 
+static const string cstr_html_charset("charset");
+static const string cstr_html_content("content");
+
 inline static bool
 p_notdigit(char c)
 {
@@ -352,7 +356,7 @@ MyHtmlParser::opening_tag(const string &tag)
 	case 'm':
 	    if (tag == "meta") {
 		string content;
-		if (get_parameter("content", content)) {
+		if (get_parameter(cstr_html_content, content)) {
 		    string name;
 		    if (get_parameter("name", name)) {
 			lowercase_term(name);
@@ -386,11 +390,11 @@ MyHtmlParser::opening_tag(const string &tag)
 			    MimeHeaderValue p;
 			    parseMimeHeaderValue(content, p);
 			    map<string, string>::const_iterator k;
-			    if ((k = p.params.find("charset")) != 
+			    if ((k = p.params.find(cstr_html_charset)) != 
 				p.params.end()) {
 				charset = k->second;
 				if (!samecharset(charset, fromcharset)) {
-				    LOGDEB1(("Doc specified charset '%s' "
+				    LOGDEB1(("Doc http-equiv charset '%s' "
 					    "differs from dir deflt '%s'\n",
 					    charset.c_str(), 
 					    fromcharset.c_str()));
@@ -400,6 +404,19 @@ MyHtmlParser::opening_tag(const string &tag)
 			}
 		    }
 		}
+		string newcharset;
+		if (get_parameter(cstr_html_charset, newcharset)) {
+		    // HTML5 added: <meta charset="...">
+		    lowercase_term(newcharset);
+		    charset = newcharset;
+		    if (!samecharset(charset, fromcharset)) {
+			LOGDEB1(("Doc html5 charset '%s' "
+				 "differs from dir deflt '%s'\n",
+				 charset.c_str(), 
+				 fromcharset.c_str()));
+			throw false;
+		    }
+		}
 		break;
 	    }
 	    if (tag == "marquee" || tag == "menu" || tag == "multicol")
@@ -517,7 +534,7 @@ MyHtmlParser::closing_tag(const string &tag)
 	    if (tag == "title") {
 		if (meta.find("title") == meta.end()|| meta["title"].empty()) {
 		    meta["title"] = dump;
-		    dump = "";
+		    dump.clear();
 		}
 		break;
 	    }
