@@ -48,6 +48,8 @@ public slots:
     virtual void addFiltypPB_clicked();
     virtual void addAFiltypPB_clicked();
     virtual void guiListsToIgnTypes();
+    virtual void filterDatesCB_toggled(bool);
+    virtual void filterSizesCB_toggled(bool);
     virtual void restrictFtCB_toggled(bool);
     virtual void restrictCtCB_toggled(bool);
     virtual void runSearch();
@@ -68,6 +70,7 @@ private:
     bool                       m_ignByCats;
     void saveCnf();
     void fillFileTypes();
+    size_t stringToSize(QString);
 };
 
 
