@@ -25,7 +25,6 @@
 #include "guiutils.h"
 #include "pathut.h"
 #include "base64.h"
-#include "transcode.h"
 
 #include <QSettings>
 #include <QStringList>
@@ -38,9 +37,9 @@ RclDynConf *g_dynconf;
 // introducing blank space.
 const char *PrefsPack::dfltResListFormat = 
 #if 1
-	"<table><tr><td><img src='%I'></td>"
+	"<table><tr><td><img src='%I' width='64'></td>"
 	"<td>%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
-	"%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i><br>"
+	"%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i>&nbsp;%i<br>"
 	"%A %K</td></tr></table>"
 #elif 0
 	"<img src='%I' align='left'>"
@@ -50,10 +49,10 @@ const char *PrefsPack::dfltResListFormat =
 #endif
     ;
 
-const char *v114reslistformat = "<img src=\"%I\" align=\"left\">"
-	"%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
-	"%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i>&nbsp;%i<br>"
-	"%A %K";
+const char* v162reslistformat="<table><tr><td><img src='%I'></td>"
+    "<td>%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
+    "%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i><br>"
+    "%A %K</td></tr></table>";
 
 
 // The global preferences structure
@@ -113,7 +112,9 @@ void rwSettings(bool writing)
 	       Bool, false);
     SETTING_RW(prefs.catgToolBar, "/Recoll/prefs/catgToolBar", Bool, false);
     SETTING_RW(prefs.ssearchAutoPhrase, 
-	       "/Recoll/prefs/ssearchAutoPhrase", Bool, false);
+	       "/Recoll/prefs/ssearchAutoPhrase", Bool, true);
+    SETTING_RW(prefs.ssearchAutoPhraseThreshPC, 
+	       "/Recoll/prefs/ssearchAutoPhraseThreshPC", Double, 2.0);
     SETTING_RW(prefs.respagesize, "/Recoll/prefs/reslist/pagelen", Int, 8);
     SETTING_RW(prefs.collapseDuplicates, 
 	       "/Recoll/prefs/reslist/collapseDuplicates", Bool, false);
@@ -133,6 +134,11 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.abssep, "/Recoll/prefs/reslist/abssep", String,"&hellip;");
     if (!writing && prefs.abssep == "")
 	prefs.abssep = "&hellip;";
+    SETTING_RW(prefs.reslistdateformat, "/Recoll/prefs/reslist/dateformat", 
+	       String,"&nbsp;%Y-%m-%d&nbsp;%H:%M:%S&nbsp;%z");
+    if (!writing && prefs.reslistdateformat == "")
+	prefs.reslistdateformat = "&nbsp;%Y-%m-%d&nbsp;%H:%M:%S&nbsp;%z";
+    prefs.creslistdateformat = (const char*)prefs.reslistdateformat.toUtf8();
 
     SETTING_RW(prefs.reslistfontfamily, "/Recoll/prefs/reslist/fontFamily", String,
 	       "");
@@ -145,12 +151,14 @@ void rwSettings(bool writing)
 	// If the current value of the format is the default for the
 	// previous version, replace it with the new default. We
 	// should have a flag to say if it was changed instead
-	if (!prefs.creslistformat.compare(v114reslistformat)) {
+	if (!prefs.creslistformat.compare(v162reslistformat)) {
 	    LOGDEB(("Replacing old default format\n"));
 	    prefs.reslistformat = rlfDflt;
 	    prefs.creslistformat = (const char*)prefs.reslistformat.toUtf8();
 	}
     }
+    SETTING_RW(prefs.reslistheadertext, "/Recoll/prefs/reslist/headertext", String, "");
+    SETTING_RW(prefs.stylesheetFile, "/Recoll/prefs/stylesheet", String, "");
     SETTING_RW(prefs.queryStemLang, "/Recoll/prefs/query/stemLang", String,
 	       "english");
     SETTING_RW(prefs.useDesktopOpen, 
@@ -197,8 +205,6 @@ void rwSettings(bool writing)
 	prefs.ssearchHistory = 
 	    settings.value("/Recoll/prefs/query/ssearchHistory").toStringList();
     }
-    SETTING_RW(prefs.ssearchAutoPhrase, 
-	       "/Recoll/prefs/query/ssearchAutoPhrase", Bool, false);
 
     // Ignored file types (advanced search)
     if (writing) {
@@ -296,8 +302,45 @@ void rwSettings(bool writing)
 		prefs.allExtraDbs.push_back(dbdir);
 	    }
 	}
-	prefs.activeExtraDbs = g_dynconf->getStringList(actEdbsSk);
+
+        // Get the remembered "active external indexes":
+        prefs.activeExtraDbs = g_dynconf->getStringList(actEdbsSk);
+
+	// Clean up the list: remove directories which are not
+	// actually there: useful for removable volumes.
+	for (list<string>::iterator it = prefs.activeExtraDbs.begin();
+	     it != prefs.activeExtraDbs.end();) {
+	    if (!Rcl::Db::testDbDir(*it)) {
+		LOGINFO(("Not a xapian index: [%s]\n", it->c_str()));
+		it = prefs.activeExtraDbs.erase(it);
+	    } else {
+		it++;
+	    }
+	}
+
+	// Get active db directives from the environment. This can only add to
+	// the remembered and cleaned up list
+        const char *cp4Act;
+        if ((cp4Act = getenv("RECOLL_ACTIVE_EXTRA_DBS")) != 0) {
+            vector<string> dbl;
+            stringToTokens(cp4Act, dbl, ":");
+            for (vector<string>::iterator dit = dbl.begin(); dit != dbl.end();
+                 dit++) {
+                string dbdir = path_canon(*dit);
+                path_catslash(dbdir);
+                if (std::find(prefs.activeExtraDbs.begin(),
+                              prefs.activeExtraDbs.end(), dbdir) !=
+                    prefs.activeExtraDbs.end())
+                    continue;
+                if (!Rcl::Db::testDbDir(dbdir)) {
+                    LOGERR(("Not a xapian index: [%s]\n", dbdir.c_str()));
+                    continue;
+                }
+                prefs.activeExtraDbs.push_back(dbdir);
+            } //for
+        } //if
     }
+
 #if 0
     {
 	list<string>::const_iterator it;
@@ -331,7 +374,7 @@ void rwSettings(bool writing)
     }
 }
 
-QString myGetFileName(bool isdir, QString caption)
+QString myGetFileName(bool isdir, QString caption, bool filenosave)
 {
     LOGDEB1(("myFileDialog: isdir %d\n", isdir));
     QFileDialog dialog(0, caption);
@@ -341,7 +384,10 @@ QString myGetFileName(bool isdir, QString caption)
 	dialog.setOptions(QFileDialog::ShowDirsOnly);
     } else {
 	dialog.setFileMode(QFileDialog::AnyFile);
-	dialog.setAcceptMode(QFileDialog::AcceptSave);
+	if (filenosave)
+	    dialog.setAcceptMode(QFileDialog::AcceptOpen);
+	else
+	    dialog.setAcceptMode(QFileDialog::AcceptSave);
     }
     dialog.setViewMode(QFileDialog::List);
     QFlags<QDir::Filter> flags = QDir::NoDotAndDotDot | QDir::Hidden; 
@@ -351,7 +397,6 @@ QString myGetFileName(bool isdir, QString caption)
 	flags |= QDir::Dirs | QDir::Files;
     dialog.setFilter(flags);
 
-
     if (dialog.exec() == QDialog::Accepted) {
         return dialog.selectedFiles().value(0);
     }
