@@ -48,8 +48,13 @@ class PrefsPack {
     // Result list format string
     QString reslistformat;
     string  creslistformat;
+    QString reslistheadertext;
     // Abstract snippet separator
     QString abssep;
+    // Date strftime format
+    QString reslistdateformat;
+    string creslistdateformat;
+    QString stylesheetFile;
     QString queryStemLang;
     int mainwidth;
     int mainheight;
@@ -85,6 +90,7 @@ class PrefsPack {
     QStringList ssearchHistory;
     // Make phrase out of search terms and add to search in simple search
     bool ssearchAutoPhrase;
+    double ssearchAutoPhraseThreshPC;
     // Ignored file types in adv search (startup default)
     QStringList asearchIgnFilTyps;
     bool        fileTypesByCats;
@@ -135,6 +141,7 @@ extern QString g_stringAllStem, g_stringNoStem;
 
 /** Specialized version of the qt file dialog. Can't use getOpenFile()
    etc. cause they hide dot files... */
-extern QString myGetFileName(bool isdir, QString caption = QString());
+extern QString myGetFileName(bool isdir, QString caption = QString(),
+			     bool filenosave = false);
 
 #endif /* _GUIUTILS_H_INCLUDED_ */
