@@ -45,12 +45,19 @@
 #include "rclaspell.h"
 #endif
 #include "smallut.h"
+#include "readfile.h"
+
 #include "recollq.h"
 
 RclConfig *theconfig;
 RclConfig *thestableconfig;
 PTMutexInit thestableconfiglock;
 
+// To avoid writing settings if we stopped before reading them (else
+// some kinds of errors would reset the qt/recoll settings to
+// defaults)
+static bool havereadsettings;
+
 void snapshotConfig()
 {
     PTMutexLocker locker(thestableconfiglock);
@@ -90,7 +97,6 @@ Aspell *aspell;
 #endif
 
 int recollNeedsExit;
-int startIndexingAfterConfig;
 RclMain *mainWindow;
 
 void startManual(const string& helpindex)
@@ -140,8 +146,10 @@ bool getStemLangs(list<string>& langs)
 
 static void recollCleanup()
 {
-    LOGDEB(("recollCleanup: writing settings\n"));
-    rwSettings(true);
+    if (havereadsettings) {
+	LOGDEB(("recollCleanup: writing settings\n"));
+	rwSettings(true);
+    }
     LOGDEB2(("recollCleanup: closing database\n"));
     deleteZ(rcldb);
     deleteZ(theconfig);
@@ -159,11 +167,23 @@ static void recollCleanup()
 
 static void sigcleanup(int)
 {
-    fprintf(stderr, "sigcleanup called\n");
-    // Cant call exit from here, because the atexit cleanup does some
-    // thread stuff that we can't do from signal context.
-    // Just set a flag and let the watchdog timer do the work
+    // We used to not call exit from here, because of the idxthread, but
+    // this is now gone, so...
     recollNeedsExit = 1;
+    exit(1);
+}
+
+void applyStyleSheet(const QString& ssfname)
+{
+    const char *cfname = (const char *)ssfname.toLocal8Bit();
+    LOGDEB0(("Applying style sheet: [%s]\n", cfname));
+    if (cfname && *cfname) {
+	string stylesheet;
+	file_to_string(cfname, stylesheet);
+	qApp->setStyleSheet(QString::fromAscii(stylesheet.c_str()));
+    } else {
+	qApp->setStyleSheet(QString());
+    }
 }
 
 extern void qInitImages_recoll();
@@ -183,7 +203,7 @@ static int    op_flags;
 
 static const char usage [] =
 "\n"
-"recoll [-h] [-c <configdir>] [-q options]\n"
+"recoll [-h] [-c <configdir>] [-q query]\n"
 "  -h : Print help and exit\n"
 "  -c <configdir> : specify config directory, overriding $RECOLL_CONFDIR\n"
 "  [-o|l|f|a] [-t] -q 'query' : search query to be executed as if entered\n"
@@ -195,9 +215,13 @@ static const char usage [] =
 "     -o : the query will be interpreted as an OR query.\n"
 "     -f : the query will be interpreted as a filename search\n"
 "     -l : the query will be interpreted as a query language string (default)\n"
-"     -t : terminal display: no gui. Results go to stdout. MUST be given\n"
-"          explicitly as -t (not ie, -at), and -q <query> MUST\n"
-"          be last on the command line if this is used.\n"
+"  -t : terminal display: no gui. Results go to stdout. MUST be given\n"
+"       explicitly as -t (not ie, -at), and -q <query> MUST\n"
+"       be last on the command line if this is used.\n"
+"       Use -t -h to see the additional non-gui options\n"
+"recoll <url>\n"
+"   This is used to open a recoll url (including an ipath), and called\n"
+"   typically from another search interface like the Unity Dash\n"
 ;
 static void
 Usage(void)
@@ -209,6 +233,8 @@ Usage(void)
 
 int main(int argc, char **argv)
 {
+    // If "-t" is present at all, we don't do the GUI thing and pass the 
+    // whole to recollq for command line / pipe usage.
     for (int i = 0; i < argc; i++) {
 	if (!strcmp(argv[i], "-t")) {
 	    exit(recollq(&theconfig, argc, argv));
@@ -222,6 +248,7 @@ int main(int argc, char **argv)
 
     string a_config;
     string question;
+    string urltoview;
 
     thisprog = argv[0];
     argc--; argv++;
@@ -244,6 +271,7 @@ int main(int argc, char **argv)
 		question = *(++argv);
 		argc--; goto b1;
 	    case 't': op_flags |= OPT_t; break;
+	    default: Usage();
 	    }
     b1: argc--; argv++;
     }
@@ -252,11 +280,22 @@ int main(int argc, char **argv)
     // to the query. This is for the common case recoll -q x y z to
     // avoid needing quoting "x y z"
     if (op_flags & OPT_q)
-	while (argc--) {
+	while (argc > 0) {
 	    question += " ";
 	    question += *argv++;
+	    argc--;
 	}
 
+    // Else the remaining argument should be an URL to be opened
+    if (argc == 1) {
+	urltoview = *argv++;argc--;
+	if (urltoview.compare(0, 7, cstr_fileu)) {
+	    Usage();
+	}
+    } else if (argc > 0)
+	Usage();
+
+
     // Translation file for Qt
     QString slang = QLocale::system().name().left(2);
     QTranslator qt(0);
@@ -301,8 +340,12 @@ int main(int argc, char **argv)
 
     //    fprintf(stderr, "History done\n");
     rwSettings(false);
+    havereadsettings = true;
     //    fprintf(stderr, "Settings done\n");
 
+    if (!prefs.stylesheetFile.isEmpty()) {
+	applyStyleSheet(prefs.stylesheetFile);
+    }
 
     // Create main window and set its size to previous session's
     RclMain w;
@@ -331,10 +374,6 @@ int main(int argc, char **argv)
     app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
     app.connect(&app, SIGNAL(aboutToQuit()), mainWindow, SLOT(close()));
 
-    // Start the indexing thread. It will immediately go to sleep waiting for 
-    // something to do.
-    start_idxthread();
-
     mainWindow->sSearch->searchTypCMB->setCurrentIndex(prefs.ssearchTyp);
     mainWindow->sSearch->searchTypeChanged(prefs.ssearchTyp);
     if (op_flags & OPT_q) {
@@ -351,6 +390,9 @@ int main(int argc, char **argv)
 	mainWindow->sSearch->searchTypCMB->setCurrentIndex(int(stype));
 	mainWindow->
 	    sSearch->setSearchString(QString::fromLocal8Bit(question.c_str()));
+    } else if (!urltoview.empty()) {
+	LOGDEB(("MAIN: got urltoview [%s]\n", urltoview.c_str()));
+	mainWindow->setUrlToView(QString::fromLocal8Bit(urltoview.c_str()));
     }
     return app.exec();
 }
