@@ -80,7 +80,12 @@ public:
 	} else {
 	    if (prefs.previewPlainPre) {
 		m_eolbr = false;
-		return string("<qt><head><title></title></head><body><pre>");
+		return string("<qt><head><title></title></head><body>"
+			      "<pre>");
+// Note we could also use the following for line-folding instead of <br>s
+// This would be possible without recomputing the whole text, much better perfs
+// for toggling wrap/no-wrap
+//			      "<pre style=\"white-space: pre-wrap\">");
 	    } else {
 		m_eolbr = true;
 		return string("<qt><head><title></title></head><body>");
@@ -504,11 +509,9 @@ void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
 {
     LOGDEB1(("PreviewTextEdit::setCurTabProps\n"));
     QString title;
-    map<string,string>::const_iterator meta_it;
-    if ((meta_it = doc.meta.find(Rcl::Doc::keytt)) != doc.meta.end()
-        && !meta_it->second.empty()) {
-	    title = QString::fromUtf8(meta_it->second.c_str(), 
-				      meta_it->second.length());
+    string ctitle;
+    if (doc.getmeta(Rcl::Doc::keytt, &ctitle) && !ctitle.empty()) {
+	title = QString::fromUtf8(ctitle.c_str(), ctitle.length());
     } else {
         title = QString::fromLocal8Bit(path_getsimple(doc.url).c_str());
     }
@@ -531,8 +534,8 @@ void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
     printableUrl(theconfig->getDefCharset(), doc.url, url);
     string tiptxt = url + string("\n");
     tiptxt += doc.mimetype + " " + string(datebuf) + "\n";
-    if (meta_it != doc.meta.end() && !meta_it->second.empty())
-	tiptxt += meta_it->second + "\n";
+    if (!ctitle.empty())
+	tiptxt += ctitle + "\n";
     pvTab->setTabToolTip(curidx,
 			 QString::fromUtf8(tiptxt.c_str(), tiptxt.length()));
 
@@ -579,6 +582,14 @@ bool Preview::makeDocCurrent(const Rcl::Doc& doc, int docnum, bool sametab)
     raise();
     return true;
 }
+void Preview::togglePlainPre()
+{
+    prefs.previewPlainPre = !prefs.previewPlainPre;
+    
+    PreviewTextEdit *editor = currentEditor();
+    if (editor)
+	loadDocInCurrentTab(editor->m_dbdoc, editor->m_docnum);
+}
 
 void Preview::emitWordSelect(QString word)
 {
@@ -705,7 +716,7 @@ public:
 
 bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 {
-    LOGDEB1(("PreviewTextEdit::loadDocInCurrentTab()\n"));
+    LOGDEB1(("Preview::loadDocInCurrentTab()\n"));
 
     LoadGuard guard(&m_loading);
     CancelCheck::instance().setCancel(false);
@@ -938,7 +949,8 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 
 	if (!fn.empty()) {
 	    editor->m_image = QImage(fn.c_str());
-	    editor->displayImage();
+	    if (!editor->m_image.isNull())
+		editor->displayImage();
 	}
      }
 
@@ -966,9 +978,10 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 
 
     // Enter document in document history
-    map<string,string>::const_iterator udit = idoc.meta.find(Rcl::Doc::keyudi);
-    if (udit != idoc.meta.end())
-        historyEnterDoc(g_dynconf, udit->second);
+    string udi;
+    if (idoc.getmeta(Rcl::Doc::keyudi, &udi)) {
+        historyEnterDoc(g_dynconf, udi);
+    }
 
     editor->setFocus();
     emit(previewExposed(this, m_searchId, docnum));
@@ -1015,6 +1028,12 @@ void PreviewTextEdit::createPopupMenu(const QPoint& pos)
     popup->addAction(tr("Select All"), this, SLOT(selectAll()));
     popup->addAction(tr("Copy"), this, SLOT(copy()));
     popup->addAction(tr("Print"), this, SLOT(print()));
+    if (prefs.previewPlainPre) {
+	popup->addAction(tr("Fold lines"), m_preview, SLOT(togglePlainPre()));
+    } else {
+	popup->addAction(tr("Preserve indentation"), 
+			 m_preview, SLOT(togglePlainPre()));
+    }
     // Need to check ipath until we fix the internfile bug that always
     // has it convert to html for top level docs
     if (!m_dbdoc.url.empty() && !m_dbdoc.ipath.empty())
