@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <regex.h>
@@ -48,6 +49,9 @@ using std::pair;
 #include <qapplication.h>
 #include <qcursor.h>
 #include <qevent.h>
+#include <QFileSystemWatcher>
+#include <QThread>
+#include <QProgressDialog>
 
 #include "recoll.h"
 #include "debuglog.h"
@@ -68,6 +72,14 @@ using std::pair;
 #include "docseqhist.h"
 #include "confguiindex.h"
 #include "restable.h"
+#include "listdialog.h"
+#include "firstidx.h"
+#include "idxsched.h"
+#include "crontool.h"
+#include "rtitool.h"
+#include "indexer.h"
+#include "rclzg.h"
+#include "fileudi.h"
 
 using namespace confgui;
 
@@ -90,15 +102,15 @@ void RclMain::init()
     };
     DocSequence::set_translations((const char *)tr("sorted").toUtf8(), 
 				(const char *)tr("filtered").toUtf8());
-    curPreview = 0;
-    asearchform = 0;
-    uiprefs = 0;
-    indexConfig = 0;
-    spellform = 0;
-    m_idxStatusAck = false;
-    periodictimer = new QTimer(this);
-    m_periodicToggle = 0;
 
+    periodictimer = new QTimer(this);
+
+    // idxstatus file. Make sure it exists before trying to watch it
+    // (case where we're started on an older index, or if the status
+    // file was deleted since indexing
+    ::close(::open(theconfig->getIdxStatusFile().c_str(), O_CREAT, 0600));
+    m_watcher.addPath(QString::fromLocal8Bit(
+			  theconfig->getIdxStatusFile().c_str()));
     // At least some versions of qt4 don't display the status bar if
     // it's not created here.
     (void)statusBar();
@@ -167,7 +179,7 @@ void RclMain::init()
     connect(bgrp, SIGNAL(buttonClicked(int)), this, SLOT(catgFilter(int)));
     allRDB->setChecked(true);
     list<string> cats;
-    theconfig->getMimeCategories(cats);
+    theconfig->getGuiFilterNames(cats);
     // Text for button 0 is not used. Next statement just avoids unused
     // variable compiler warning for catg_strings
     m_catgbutvec.push_back(catg_strings[0]);
@@ -176,7 +188,15 @@ void RclMain::init()
 	QRadioButton *but = new QRadioButton(catgBGRP);
 	QString catgnm = QString::fromUtf8(it->c_str(), it->length());
 	m_catgbutvec.push_back(*it);
-	but->setText(tr(catgnm.toUtf8()));
+	// We strip text before the first colon before setting the button name.
+	// This is so that the user can decide the order of buttons by naming 
+	// the filter,ie, a:media b:messages etc.
+	QString but_txt = catgnm;
+	int colon = catgnm.indexOf(':');
+	if (colon != -1) {
+	    but_txt = catgnm.right(catgnm.size()-(colon+1));
+	}
+	but->setText(tr(but_txt.toUtf8()));
 	if (prefs.catgToolBar && catgCMB)
 	    catgCMB->addItem(tr(catgnm.toUtf8()));
         bgrphbox->addWidget(but);
@@ -204,6 +224,8 @@ void RclMain::init()
     connect(sc, SIGNAL (activated()), 
 	    this, SLOT (focusToSearch()));
 
+    connect(&m_watcher, SIGNAL(fileChanged(QString)), 
+	    this, SLOT(idxStatus()));
     connect(sSearch, SIGNAL(startSearch(RefCntr<Rcl::SearchData>)), 
 	    this, SLOT(startSearch(RefCntr<Rcl::SearchData>)));
     connect(sSearch, SIGNAL(clearSearch()), 
@@ -217,6 +239,8 @@ void RclMain::init()
 	    this, SLOT(fileExit() ) );
     connect(fileToggleIndexingAction, SIGNAL(activated()), 
 	    this, SLOT(toggleIndexing()));
+    connect(fileRebuildIndexAction, SIGNAL(activated()), 
+	    this, SLOT(rebuildIndex()));
     connect(fileEraseDocHistoryAction, SIGNAL(activated()), 
 	    this, SLOT(eraseDocHistory()));
     connect(fileEraseSearchHistoryAction, SIGNAL(activated()), 
@@ -225,6 +249,8 @@ void RclMain::init()
 	    this, SLOT(showAboutDialog()));
     connect(showMissingHelpers_Action, SIGNAL(activated()), 
 	    this, SLOT(showMissingHelpers()));
+    connect(showActiveTypes_Action, SIGNAL(activated()), 
+	    this, SLOT(showActiveTypes()));
     connect(userManualAction, SIGNAL(activated()), 
 	    this, SLOT(startManual()));
     connect(toolsDoc_HistoryAction, SIGNAL(activated()), 
@@ -235,12 +261,12 @@ void RclMain::init()
 	    this, SLOT(showSpellDialog()));
     connect(indexConfigAction, SIGNAL(activated()), 
 	    this, SLOT(showIndexConfig()));
+    connect(indexScheduleAction, SIGNAL(activated()), 
+	    this, SLOT(showIndexSched()));
     connect(queryPrefsAction, SIGNAL(activated()), 
 	    this, SLOT(showUIPrefs()));
     connect(extIdxAction, SIGNAL(activated()), 
 	    this, SLOT(showExtIdxDialog()));
-    connect(this, SIGNAL(applyFiltSortData()), 
-	    this, SLOT(onResultsChanged()));
 
     if (prefs.catgToolBar && catgCMB)
 	connect(catgCMB, SIGNAL(activated(int)), 
@@ -255,7 +281,7 @@ void RclMain::init()
 	    restable, SLOT(setDocSource(RefCntr<DocSequence>)));
     connect(this, SIGNAL(searchReset()), 
 	    restable, SLOT(resetSource()));
-    connect(this, SIGNAL(applyFiltSortData()), 
+    connect(this, SIGNAL(resultsReady()), 
 	    restable, SLOT(readDocSource()));
     connect(this, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
 	    restable, SLOT(onSortDataChanged(DocSeqSortSpec)));
@@ -285,11 +311,7 @@ void RclMain::init()
 	    reslist, SLOT(resPageDownOrNext()));
     connect(this, SIGNAL(searchReset()), 
 	    reslist, SLOT(resetList()));
-    connect(this, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
-	    reslist, SLOT(setSortParams(DocSeqSortSpec)));
-    connect(this, SIGNAL(filtDataChanged(DocSeqFiltSpec)), 
-	    reslist, SLOT(setFilterParams(DocSeqFiltSpec)));
-    connect(this, SIGNAL(applyFiltSortData()), 
+    connect(this, SIGNAL(resultsReady()), 
 	    reslist, SLOT(readDocSource()));
 
     connect(reslist, SIGNAL(hasResults(int)), 
@@ -298,6 +320,8 @@ void RclMain::init()
 	    this, SLOT(docExpand(Rcl::Doc)));
     connect(reslist, SIGNAL(wordSelect(QString)),
 	    sSearch, SLOT(addTerm(QString)));
+    connect(reslist, SIGNAL(wordReplace(const QString&, const QString&)),
+	    sSearch, SLOT(onWordReplace(const QString&, const QString&)));
     connect(reslist, SIGNAL(nextPageAvailable(bool)), 
 	    this, SLOT(enableNextPage(bool)));
     connect(reslist, SIGNAL(prevPageAvailable(bool)), 
@@ -322,6 +346,8 @@ void RclMain::init()
 	emit sortDataChanged(m_sortspec);
     }
 
+    fileRebuildIndexAction->setEnabled(FALSE);
+    fileToggleIndexingAction->setEnabled(FALSE);
     // Start timer on a slow period (used for checking ^C). Will be
     // speeded up during indexing
     periodictimer->start(1000);
@@ -337,47 +363,86 @@ void RclMain::resultCount(int n)
 // the database and talk to the user if we can't
 void RclMain::initDbOpen()
 {
-    bool needindexconfig = false;
     bool nodb = false;
     string reason;
     bool maindberror;
     if (!maybeOpenDb(reason, true, &maindberror)) {
         nodb = true;
 	if (maindberror) {
-	    switch (QMessageBox::
-		    question
-		    (this, "Recoll",
-		     qApp->translate("Main", "Could not open database in ") +
-		     QString::fromLocal8Bit(theconfig->getDbDir().c_str()) +
-		     qApp->translate("Main", 
-				     ".\n"
-				     "Click Cancel if you want to edit the configuration file before indexing starts, or Ok to let it proceed."),
-		     "Ok", "Cancel", 0,   0)) {
-
-	    case 0: // Ok: indexing is going to start.
-		start_indexing(true);
-		break;
-
-	    case 1: // Cancel
-		needindexconfig = true;
-		break;
-	    }
+	    FirstIdxDialog fidia(this);
+	    connect(fidia.idxconfCLB, SIGNAL(clicked()), 
+		    this, SLOT(execIndexConfig()));
+	    connect(fidia.idxschedCLB, SIGNAL(clicked()), 
+		    this, SLOT(execIndexSched()));
+	    connect(fidia.runidxPB, SIGNAL(clicked()), 
+		    this, SLOT(toggleIndexing()));
+	    fidia.exec();
+	    // Don't open adv search or run cmd line search in this case.
+	    return;
 	} else {
 	    QMessageBox::warning(0, "Recoll", 
 				 tr("Could not open external index. Db not open. Check external indexes list."));
 	}
     }
 
-    if (needindexconfig) {
-	startIndexingAfterConfig = 1;
-	showIndexConfig();
+    if (prefs.startWithAdvSearchOpen)
+	showAdvSearchDialog();
+    // If we have something in the search entry, it comes from a
+    // command line argument
+    if (!nodb && sSearch->hasSearchString())
+	QTimer::singleShot(0, sSearch, SLOT(startSimpleSearch()));
+
+    if (!m_urltoview.isEmpty()) 
+	viewUrl();
+}
+
+// Start native viewer or preview for input Doc. This is used allow
+// the using Recoll result docs with an ipath in another app.  We act
+// as a proxy to extract the data and start a viewer.
+// The Url are encoded as file://path#ipath
+void RclMain::viewUrl()
+{
+    if (m_urltoview.isEmpty() || !rcldb)
+	return;
+
+    QUrl qurl(m_urltoview);
+    LOGDEB(("RclMain::viewUrl: Path [%s] fragment [%s]\n", 
+	    (const char *)qurl.path().toLocal8Bit(),
+	    (const char *)qurl.fragment().toLocal8Bit()));
+
+    /* In theory, the url might not be for a file managed by the fs
+       indexer so that the make_udi() call here would be
+       wrong(). When/if this happens we'll have to hide this part
+       inside internfile and have some url magic to indicate the
+       appropriate indexer/identification scheme */
+    string udi;
+    make_udi((const char *)qurl.path().toLocal8Bit(),
+	     (const char *)qurl.fragment().toLocal8Bit(), udi);
+    
+    Rcl::Doc doc;
+    if (!rcldb->getDoc(udi, doc) || doc.pc == -1)
+	return;
+
+    // Start a native viewer if the mimetype has one defined, else a
+    // preview.
+    string apptag;
+    doc.getmeta(Rcl::Doc::keyapptg, &apptag);
+    string viewer = theconfig->getMimeViewerDef(doc.mimetype, apptag);
+    if (viewer.empty()) {
+	startPreview(doc);
     } else {
-	if (prefs.startWithAdvSearchOpen)
-	    showAdvSearchDialog();
-        // If we have something in the search entry, it comes from a
-        // command line argument
-        if (!nodb && sSearch->hasSearchString())
-            QTimer::singleShot(0, sSearch, SLOT(startSimpleSearch()));
+	hide();
+	startNativeViewer(doc);
+	// We have a problem here because xdg-open will exit
+	// immediately after starting the command instead of waiting
+	// for it, so we can't wait either and we don't know when we
+	// can exit (deleting the temp file). As a bad workaround we
+	// sleep some time then exit. The alternative would be to just
+	// prevent the temp file deletion completely, leaving it
+	// around forever. Better to let the user save a copy if he
+	// wants I think.
+	sleep(10);
+	fileExit();
     }
 }
 
@@ -481,125 +546,216 @@ void RclMain::fileExit()
     prefs.ssearchTyp = sSearch->searchTypCMB->currentIndex();
     if (asearchform)
 	delete asearchform;
-    // We'd prefer to do this in the exit handler, but it's apparently to late
-    // and some of the qt stuff is already dead at this point?
-    LOGDEB2(("RclMain::fileExit() : stopping idx thread\n"));
-    stop_idxthread();
+
     // Let the exit handler clean up the rest (internal recoll stuff).
     exit(0);
 }
 
-// This is called by a periodic timer to check the status of the
-// indexing thread and a possible need to exit
+void RclMain::idxStatus()
+{
+    ConfSimple cs(theconfig->getIdxStatusFile().c_str(), 1);
+    QString msg = tr("Indexing in progress: ");
+    DbIxStatus status;
+    string val;
+    cs.get("phase", val);
+    status.phase = DbIxStatus::Phase(atoi(val.c_str()));
+    cs.get("fn", status.fn);
+    cs.get("docsdone", val);
+    status.docsdone = atoi(val.c_str());
+    cs.get("filesdone", val);
+    status.filesdone = atoi(val.c_str());
+    cs.get("dbtotdocs", val);
+    status.dbtotdocs = atoi(val.c_str());
+
+    QString phs;
+    switch (status.phase) {
+    case DbIxStatus::DBIXS_NONE:phs=tr("None");break;
+    case DbIxStatus::DBIXS_FILES: phs=tr("Updating");break;
+    case DbIxStatus::DBIXS_PURGE: phs=tr("Purge");break;
+    case DbIxStatus::DBIXS_STEMDB: phs=tr("Stemdb");break;
+    case DbIxStatus::DBIXS_CLOSING:phs=tr("Closing");break;
+    case DbIxStatus::DBIXS_DONE:phs=tr("Done");break;
+    case DbIxStatus::DBIXS_MONITOR:phs=tr("Monitor");break;
+    default: phs=tr("Unknown");break;
+    }
+    msg += phs + " ";
+    if (status.phase == DbIxStatus::DBIXS_FILES) {
+	char cnts[100];
+	if (status.dbtotdocs > 0)
+	    sprintf(cnts,"(%d/%d/%d) ", status.docsdone, status.filesdone, 
+		    status.dbtotdocs);
+	else
+	    sprintf(cnts, "(%d/%d) ", status.docsdone, status.filesdone);
+	msg += QString::fromAscii(cnts) + " ";
+    }
+    string mf;int ecnt = 0;
+    string fcharset = theconfig->getDefCharset(true);
+    if (!transcode(status.fn, mf, fcharset, "UTF-8", &ecnt) || ecnt) {
+	mf = url_encode(status.fn, 0);
+    }
+    msg += QString::fromUtf8(mf.c_str());
+    statusBar()->showMessage(msg, 4000);
+}
+
+// This is called by a periodic timer to check the status of 
+// indexing, a possible need to exit, and cleanup exited viewers
 void RclMain::periodic100()
 {
-    // Check if indexing thread done
-    if (idxthread_getStatus() != IDXTS_NULL) {
-	// Indexing is stopped
-	fileToggleIndexingAction->setText(tr("Update &Index"));
-	fileToggleIndexingAction->setEnabled(TRUE);
-	if (m_idxStatusAck == false) {
-	    m_idxStatusAck = true;
-	    if (idxthread_getStatus() != IDXTS_OK) {
-		if (idxthread_idxInterrupted()) {
-		    QMessageBox::warning(0, "Recoll", 
-					 tr("Indexing interrupted"));
-		} else {
-		    QMessageBox::warning(0, "Recoll", 
-		       QString::fromAscii(idxthread_getReason().c_str()));
-		}
+    LOGDEB2(("Periodic100\n"));
+    if (m_idxproc) {
+	// An indexing process was launched. If its' done, see status.
+	int status;
+	bool exited = m_idxproc->maybereap(&status);
+	if (exited) {
+	    deleteZ(m_idxproc);
+	    if (status) {
+		QMessageBox::warning(0, "Recoll", 
+				     tr("Indexing failed"));
 	    }
-	    // Make sure we reopen the db to get the results. If there
-	    // is current search data, we should reset it else things
-	    // are inconsistent (ie: applying sort will fail. But we
-	    // don't like erasing results while the user may be
-	    // looking at them either). Fixing this would be
-	    // relatively complicated (keep an open/close gen number
-	    // and check this / restart query in DocSeqDb() ?)
 	    string reason;
 	    maybeOpenDb(reason, 1);
-            periodictimer->setInterval(1000);
+	} else {
+	    // update/show status even if the status file did not
+	    // change (else the status line goes blank during
+	    // lengthy operations).
+	    idxStatus();
 	}
-    } else {
-	// Indexing is running
-	m_idxStatusAck = false;
+    }
+    // Update the "start/stop indexing" menu entry, can't be done from
+    // the "start/stop indexing" slot itself
+    if (m_idxproc) {
+	m_indexerState = IXST_RUNNINGMINE;
 	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
 	fileToggleIndexingAction->setEnabled(TRUE);
-        periodictimer->setInterval(100);
-	// The toggle thing is for the status to flash
-	if (m_periodicToggle < 9) {
-	    QString msg = tr("Indexing in progress: ");
-	    DbIxStatus status = idxthread_idxStatus();
-	    QString phs;
-	    switch (status.phase) {
-	    case DbIxStatus::DBIXS_FILES: phs=tr("Files");break;
-	    case DbIxStatus::DBIXS_PURGE: phs=tr("Purge");break;
-	    case DbIxStatus::DBIXS_STEMDB: phs=tr("Stemdb");break;
-	    case DbIxStatus::DBIXS_CLOSING:phs=tr("Closing");break;
-	    default: phs=tr("Unknown");break;
-	    }
-	    msg += phs + " ";
-	    if (status.phase == DbIxStatus::DBIXS_FILES) {
-		char cnts[100];
-		if (status.dbtotdocs>0)
-		    sprintf(cnts,"(%d/%d) ",status.docsdone, status.dbtotdocs);
-		else
-		    sprintf(cnts, "(%d) ", status.docsdone);
-		msg += QString::fromAscii(cnts) + " ";
-	    }
-	    string mf;int ecnt = 0;
-	    string fcharset = theconfig->getDefCharset(true);
-	    if (!transcode(status.fn, mf, fcharset, "UTF-8", &ecnt) || ecnt) {
-		mf = url_encode(status.fn, 0);
-	    }
-	    msg += QString::fromUtf8(mf.c_str());
-	    statusBar()->showMessage(msg, 4000);
-	} else if (m_periodicToggle == 9) {
-	    statusBar()->showMessage("");
-	}
-	if (++m_periodicToggle >= 10)
-	    m_periodicToggle = 0;
+	fileRebuildIndexAction->setEnabled(FALSE);
+	periodictimer->setInterval(200);
+    } else {
+	Pidfile pidfile(theconfig->getPidfile());
+	if (pidfile.open() == 0) {
+	    m_indexerState = IXST_NOTRUNNING;
+	    fileToggleIndexingAction->setText(tr("Update &Index"));
+	    fileToggleIndexingAction->setEnabled(TRUE);
+	    fileRebuildIndexAction->setEnabled(TRUE);
+	    periodictimer->setInterval(1000);
+	} else {
+	    // Real time or externally started batch indexer running
+	    m_indexerState = IXST_RUNNINGNOTMINE;
+	    fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+	    fileToggleIndexingAction->setEnabled(TRUE);
+	    fileRebuildIndexAction->setEnabled(FALSE);
+	    periodictimer->setInterval(200);
+	}	    
     }
+
+    // Possibly cleanup the dead viewers
+    for (vector<ExecCmd*>::iterator it = m_viewers.begin();
+	 it != m_viewers.end(); it++) {
+	int status;
+	if ((*it)->maybereap(&status)) {
+	    deleteZ(*it);
+	}
+    }
+    vector<ExecCmd*> v;
+    for (vector<ExecCmd*>::iterator it = m_viewers.begin();
+	 it != m_viewers.end(); it++) {
+	if (*it)
+	    v.push_back(*it);
+    }
+    m_viewers = v;
+
     if (recollNeedsExit)
 	fileExit();
 }
 
-// This gets called when the indexing action is activated. It starts
+// This gets called when the "update iindex" action is activated. It executes
 // the requested action, and disables the menu entry. This will be
 // re-enabled by the indexing status check
 void RclMain::toggleIndexing()
 {
-    if (idxthread_getStatus() == IDXTS_NULL) {
-	// Indexing was in progress, stop it
-	stop_indexing();
-        periodictimer->setInterval(1000);
-	fileToggleIndexingAction->setText(tr("Update &Index"));
-    } else {
-	start_indexing(false);
-        periodictimer->setInterval(100);
-	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+    switch (m_indexerState) {
+    case IXST_RUNNINGMINE:
+	if (m_idxproc) {
+	    // Indexing was in progress, request stop. Let the periodic
+	    // routine check for the results.
+	    int pid = m_idxproc->getChildPid();
+	    if (pid > 0)
+		kill(pid, SIGTERM);
+	}
+	break;
+    case IXST_RUNNINGNOTMINE:
+    {
+	int rep = 
+	    QMessageBox::information(0, tr("Warning"), 
+				     tr("The current indexing process "
+					"was not started from this "
+					"interface. Click Ok to kill it "
+					"anyway, or Cancel to leave it alone"),
+					 QMessageBox::Ok,
+					 QMessageBox::Cancel,
+					 QMessageBox::NoButton);
+	if (rep == QMessageBox::Ok) {
+	    Pidfile pidfile(theconfig->getPidfile());
+	    pid_t pid = pidfile.open();
+	    if (pid > 0)
+		kill(pid, SIGTERM);
+	}
+    }		
+    break;
+    case IXST_NOTRUNNING:
+    {
+	list<string> args;
+	args.push_back("-c");
+	args.push_back(theconfig->getConfDir());
+	m_idxproc = new ExecCmd;
+	m_idxproc->startExec("recollindex", args, false, false);
+    }
+    break;
+    }
+}
+
+void RclMain::rebuildIndex()
+{
+    switch (m_indexerState) {
+    case IXST_RUNNINGMINE:
+    case IXST_RUNNINGNOTMINE:
+	return; //?? Should not have been called
+    case IXST_NOTRUNNING:
+    {
+	int rep = 
+	    QMessageBox::warning(0, tr("Erasing index"), 
+				     tr("Reset the index and start "
+					"from scratch ?"),
+					 QMessageBox::Ok,
+					 QMessageBox::Cancel,
+					 QMessageBox::NoButton);
+	if (rep == QMessageBox::Ok) {
+	    list<string> args;
+	    args.push_back("-c");
+	    args.push_back(theconfig->getConfDir());
+	    args.push_back("-z");
+	    m_idxproc = new ExecCmd;
+	    m_idxproc->startExec("recollindex", args, false, false);
+	}
+    }
+    break;
     }
-    fileToggleIndexingAction->setEnabled(FALSE);
 }
 
 // Start a db query and set the reslist docsource
 void RclMain::startSearch(RefCntr<Rcl::SearchData> sdata)
 {
-    LOGDEB(("RclMain::startSearch. Indexing %s\n", 
-	    idxthread_getStatus() == IDXTS_NULL?"on":"off"));
+    LOGDEB(("RclMain::startSearch. Indexing %s\n", m_idxproc?"on":"off"));
     emit searchReset();
     m_source = RefCntr<DocSequence>();
 
     // The db may have been closed at the end of indexing
     string reason;
     // If indexing is being performed, we reopen the db at each query.
-    if (!maybeOpenDb(reason, idxthread_getStatus() == IDXTS_NULL)) {
+    if (!maybeOpenDb(reason, m_idxproc != 0)) {
 	QMessageBox::critical(0, "Recoll", QString(reason.c_str()));
 	return;
     }
 
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
     string stemLang = (const char *)prefs.queryStemLang.toAscii();
     if (stemLang == "ALL") {
 	theconfig->getConfParam("indexstemminglanguages", stemLang);
@@ -621,25 +777,78 @@ void RclMain::startSearch(RefCntr<Rcl::SearchData> sdata)
 
     emit docSourceChanged(m_source);
     emit sortDataChanged(m_sortspec);
-    emit filtDataChanged(m_filtspec);
-    emit applyFiltSortData();
-    QApplication::restoreOverrideCursor();
+    initiateQuery();
 }
 
-void RclMain::onResultsChanged()
-{
-    if (m_source.isNotNull()) {
-	int cnt = m_source->getResCnt();
-	QString msg;
-	if (cnt > 0) {
-	    QString str;
-	    msg = tr("Result count (est.)") + ": " + 
-		str.setNum(cnt);
-	} else {
-	    msg = tr("No results found");
-	}
-	statusBar()->showMessage(msg, 0);
+class QueryThread : public QThread {
+    int loglevel;
+    RefCntr<DocSequence> m_source;
+ public: 
+    QueryThread(RefCntr<DocSequence> source)
+	: m_source(source)
+    {
+	loglevel = DebugLog::getdbl()->getlevel();
     }
+    ~QueryThread() { }
+    virtual void run() 
+    {
+	DebugLog::getdbl()->setloglevel(loglevel);
+	cnt = m_source->getResCnt();
+    }
+    int cnt;
+};
+
+void RclMain::initiateQuery()
+{
+    if (m_queryActive || m_source.isNull())
+	return;
+    m_queryActive = true;
+
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    QueryThread qthr(m_source);
+    qthr.start();
+
+    QProgressDialog progress(this);
+    progress.setLabelText(tr("Query in progress.<br>"
+			     "Due to limitations of the indexing library,<br>"
+			     "cancelling will exit the program"));
+    progress.setWindowModality(Qt::WindowModal);
+    progress.setRange(0,0);
+
+    // For some reason setMinimumDuration() does not seem to work with
+    // a busy dialog (range 0,0) Have to call progress.show() inside
+    // the loop.
+    // progress.setMinimumDuration(2000);
+    // Also the multiple processEvents() seem to improve the responsiveness??
+    for (int i = 0;;i++) {
+	qApp->processEvents();
+	if (qthr.wait(100)) {
+	    break;
+	}
+	if (i == 20)
+	    progress.show();
+	qApp->processEvents();
+	if (progress.wasCanceled()) {
+	    fileExit();
+	}
+
+	qApp->processEvents();
+    }
+
+    int cnt = qthr.cnt;
+    QString msg;
+    if (cnt > 0) {
+	QString str;
+	msg = tr("Result count (est.)") + ": " + 
+	    str.setNum(cnt);
+    } else {
+	msg = tr("No results found");
+    }
+
+    statusBar()->showMessage(msg, 0);
+    QApplication::restoreOverrideCursor();
+    m_queryActive = false;
+    emit(resultsReady());
 }
 
 void RclMain::resetSearch()
@@ -683,6 +892,14 @@ void RclMain::showSpellDialog()
 }
 
 void RclMain::showIndexConfig()
+{
+    showIndexConfig(false);
+}
+void RclMain::execIndexConfig()
+{
+    showIndexConfig(true);
+}
+void RclMain::showIndexConfig(bool modal)
 {
     LOGDEB(("showIndexConfig()\n"));
     if (indexConfig == 0) {
@@ -694,13 +911,107 @@ void RclMain::showIndexConfig()
 	indexConfig->close();
 	indexConfig->reloadPanels();
     }
-    indexConfig->show();
+    if (modal) {
+	indexConfig->exec();
+	indexConfig->setModal(false);
+    } else {
+	indexConfig->show();
+    }
+}
+
+void RclMain::showIndexSched()
+{
+    showIndexSched(false);
+}
+void RclMain::execIndexSched()
+{
+    showIndexSched(true);
+}
+void RclMain::showIndexSched(bool modal)
+{
+    LOGDEB(("showIndexSched()\n"));
+    if (indexSched == 0) {
+	indexSched = new IdxSchedW(this);
+	connect(new QShortcut(quitKeySeq, indexSched), SIGNAL (activated()), 
+		this, SLOT (fileExit()));
+	connect(indexSched->cronCLB, SIGNAL(clicked()), 
+		this, SLOT(execCronTool()));
+	if (theconfig && theconfig->isDefaultConfig()) {
+	    connect(indexSched->rtidxCLB, SIGNAL(clicked()), 
+		    this, SLOT(execRTITool()));
+	} else {
+	    indexSched->rtidxCLB->setEnabled(false);
+	}
+    } else {
+	// Close and reopen, in hope that makes us visible...
+	indexSched->close();
+    }
+    if (modal) {
+	indexSched->exec();
+	indexSched->setModal(false);
+    } else {
+	indexSched->show();
+    }
+}
+
+void RclMain::showCronTool()
+{
+    showCronTool(false);
+}
+void RclMain::execCronTool()
+{
+    showCronTool(true);
+}
+void RclMain::showCronTool(bool modal)
+{
+    LOGDEB(("showCronTool()\n"));
+    if (cronTool == 0) {
+	cronTool = new CronToolW(0);
+	connect(new QShortcut(quitKeySeq, cronTool), SIGNAL (activated()), 
+		this, SLOT (fileExit()));
+    } else {
+	// Close and reopen, in hope that makes us visible...
+	cronTool->close();
+    }
+    if (modal) {
+	cronTool->exec();
+	cronTool->setModal(false);
+    } else {
+	cronTool->show();
+    }
+}
+
+void RclMain::showRTITool()
+{
+    showRTITool(false);
+}
+void RclMain::execRTITool()
+{
+    showRTITool(true);
+}
+void RclMain::showRTITool(bool modal)
+{
+    LOGDEB(("showRTITool()\n"));
+    if (rtiTool == 0) {
+	rtiTool = new RTIToolW(0);
+	connect(new QShortcut(quitKeySeq, rtiTool), SIGNAL (activated()), 
+		this, SLOT (fileExit()));
+    } else {
+	// Close and reopen, in hope that makes us visible...
+	rtiTool->close();
+    }
+    if (modal) {
+	rtiTool->exec();
+	rtiTool->setModal(false);
+    } else {
+	rtiTool->show();
+    }
 }
 
 void RclMain::showUIPrefs()
 {
     if (uiprefs == 0) {
-	uiprefs = new UIPrefsDialog(0);
+	uiprefs = new UIPrefsDialog(this);
 	connect(new QShortcut(quitKeySeq, uiprefs), SIGNAL (activated()), 
 		this, SLOT (fileExit()));
 	connect(uiprefs, SIGNAL(uiprefsDone()), this, SLOT(setUIPrefs()));
@@ -716,7 +1027,7 @@ void RclMain::showUIPrefs()
 void RclMain::showExtIdxDialog()
 {
     if (uiprefs == 0) {
-	uiprefs = new UIPrefsDialog(0);
+	uiprefs = new UIPrefsDialog(this);
 	connect(new QShortcut(quitKeySeq, uiprefs), SIGNAL (activated()), 
 		this, SLOT (fileExit()));
 	connect(uiprefs, SIGNAL(uiprefsDone()), this, SLOT(setUIPrefs()));
@@ -724,7 +1035,7 @@ void RclMain::showExtIdxDialog()
 	// Close and reopen, in hope that makes us visible...
 	uiprefs->close();
     }
-    uiprefs->tabWidget->setCurrentIndex(2);
+    uiprefs->tabWidget->setCurrentIndex(3);
     uiprefs->show();
 }
 
@@ -749,6 +1060,86 @@ void RclMain::showMissingHelpers()
     QMessageBox::information(this, tr("Missing helper programs"), msg);
 }
 
+void RclMain::showActiveTypes()
+{
+    if (rcldb == 0) {
+	QMessageBox::warning(0, tr("Error"), 
+			     tr("Index not open"),
+			     QMessageBox::Ok, 
+			     QMessageBox::NoButton);
+	return;
+    }
+
+    // Get list of all mime types in index. For this, we use a
+    // wildcard field search on mtype
+    Rcl::TermMatchResult matches;
+    string prefix;
+    if (!rcldb->termMatch(Rcl::Db::ET_WILD, "", "*", matches, -1, "mtype", 
+			  &prefix)) {
+	QMessageBox::warning(0, tr("Error"), 
+			     tr("Index query error"),
+			     QMessageBox::Ok, 
+			     QMessageBox::NoButton);
+	return;
+    }
+
+    // Build the set of mtypes, stripping the prefix
+    set<string> mtypesfromdb;
+    for (list<Rcl::TermMatchEntry>::const_iterator it = matches.entries.begin(); 
+	 it != matches.entries.end(); it++) {
+	mtypesfromdb.insert(it->term.substr(prefix.size()));
+    }
+
+    // All types listed in mimeconf:
+    list<string> mtypesfromconfig = theconfig->getAllMimeTypes();
+
+    // Intersect file system types with config types (those not in the
+    // config can be indexed by name, not by content)
+    set<string> mtypesfromdbconf;
+    for (list<string>::const_iterator it = mtypesfromconfig.begin();
+	 it != mtypesfromconfig.end(); it++) {
+	if (mtypesfromdb.find(*it) != mtypesfromdb.end())
+	    mtypesfromdbconf.insert(*it);
+    }
+
+    // Substract the types for missing helpers (the docs are indexed by name only):
+    string miss = theconfig->getMissingHelperDesc();
+    if (!miss.empty()) {
+	FIMissingStore st;
+	FileInterner::getMissingFromDescription(&st, miss);
+	map<string, set<string> >::const_iterator it;
+	for (it = st.m_typesForMissing.begin(); 
+	     it != st.m_typesForMissing.end(); it++) {
+	    set<string>::const_iterator it1;
+	    for (it1 = it->second.begin(); 
+		 it1 != it->second.end(); it1++) {
+		set<string>::iterator it2 = mtypesfromdbconf.find(*it1);
+		if (it2 != mtypesfromdbconf.end())
+		    mtypesfromdbconf.erase(it2);
+	    }
+	}	
+    }
+    ListDialog dialog;
+    dialog.setWindowTitle(tr("Indexed MIME Types"));
+
+    // Turn the result into a string and display
+    dialog.groupBox->setTitle(tr("Content has been indexed for these mime types:"));
+
+    // We replace the list with an editor so that the user can copy/paste
+    delete dialog.listWidget;
+    QTextEdit *editor = new QTextEdit(dialog.groupBox);
+    editor->setReadOnly(TRUE);
+    dialog.horizontalLayout->addWidget(editor);
+
+    for (set<string>::const_iterator it = mtypesfromdbconf.begin(); 
+	 it != mtypesfromdbconf.end(); it++) {
+	editor->append(QString::fromAscii(it->c_str()));
+    }
+    editor->moveCursor(QTextCursor::Start);
+    editor->ensureCursorVisible();
+    dialog.exec();
+}
+
 // If a preview (toplevel) window gets closed by the user, we need to
 // clean up because there is no way to reopen it. And check the case
 // where the current one is closed
@@ -774,6 +1165,51 @@ void RclMain::previewClosed(Preview *w)
 void RclMain::startPreview(int docnum, Rcl::Doc doc, int mod)
 {
     LOGDEB(("startPreview(%d, doc, %d)\n", docnum, mod));
+
+    // Document up to date check. We do this only if ipath is not
+    // empty as this does not appear to be a serious issue for single
+    // docs (the main actual problem is displaying the wrong message
+    // from a compacted mail folder)
+    //
+    // !! NOTE: there is one case where doing a partial index update
+    // will not worl: if the search result does not exist in the new
+    // version of the file, it won't be purged from the index because
+    // a partial index pass does no purge, so its ref date will stay
+    // the same and you keep getting the message about the index being
+    // out of date. The only way to fix this is to run a normal
+    // indexing pass. 
+    // Also we should re-run the query after updating the index
+    // because the ipaths may be wrong in the current result list
+    if (!doc.ipath.empty()) {
+	string udi, sig;
+	doc.getmeta(Rcl::Doc::keyudi, &udi);
+	FileInterner::makesig(doc, sig);
+	if (rcldb && !udi.empty()) {
+	    if (rcldb->needUpdate(udi, sig)) {
+		int rep = 
+		    QMessageBox::warning(0, tr("Warning"), 
+				       tr("Index not up to date for this file. "
+					"Refusing to risk showing the wrong "
+					"entry. Click Ok to update the "
+					"index for this file, then re-run the "
+					"query when indexing is done. "
+					"Else, Cancel."),
+					 QMessageBox::Ok,
+					 QMessageBox::Cancel,
+					 QMessageBox::NoButton);
+		if (rep == QMessageBox::Ok) {
+		    LOGDEB(("Requesting index update for %s\n", 
+			    doc.url.c_str()));
+		    vector<Rcl::Doc> docs(1, doc);
+		    updateIdxForDocs(docs);
+		}
+		return;
+	    }
+	}
+    }
+    // Do the zeitgeist thing
+    zg_send_event(ZGSEND_PREVIEW, doc);
+
     if (mod & Qt::ShiftModifier) {
 	// User wants new preview window
 	curPreview = 0;
@@ -810,6 +1246,30 @@ void RclMain::startPreview(int docnum, Rcl::Doc doc, int mod)
     curPreview->makeDocCurrent(doc, docnum);
 }
 
+void RclMain::updateIdxForDocs(vector<Rcl::Doc>& docs)
+{
+    if (m_idxproc) {
+	QMessageBox::warning(0, tr("Warning"), 
+			     tr("Can't update index: indexer running"),
+			     QMessageBox::Ok, 
+			     QMessageBox::NoButton);
+	return;
+    }
+	
+    vector<string> paths;
+    if (ConfIndexer::docsToPaths(docs, paths)) {
+	list<string> args;
+	args.push_back("-c");
+	args.push_back(theconfig->getConfDir());
+	args.push_back("-i");
+	args.insert(args.end(), paths.begin(), paths.end());
+	m_idxproc = new ExecCmd;
+	m_idxproc->startExec("recollindex", args, false, false);
+	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+    }
+    fileToggleIndexingAction->setEnabled(FALSE);
+}
+
 /** 
  * Open a preview window for a given document, no linking to result list
  *
@@ -831,6 +1291,8 @@ void RclMain::startPreview(Rcl::Doc doc)
 	    this, SLOT (fileExit()));
     connect(preview, SIGNAL(wordSelect(QString)),
 	    sSearch, SLOT(addTerm(QString)));
+    // Do the zeitgeist thing
+    zg_send_event(ZGSEND_PREVIEW, doc);
     preview->show();
     preview->makeDocCurrent(doc, 0);
 }
@@ -919,7 +1381,7 @@ void RclMain::onSortCtlChanged()
     if (m_source.isNotNull())
 	m_source->setSortSpec(m_sortspec);
     emit sortDataChanged(m_sortspec);
-    emit applyFiltSortData();
+    initiateQuery();
 }
 
 void RclMain::onSortDataChanged(DocSeqSortSpec spec)
@@ -942,7 +1404,7 @@ void RclMain::onSortDataChanged(DocSeqSortSpec spec)
     prefs.sortDesc = spec.desc;
     prefs.sortActive = !spec.field.empty();
 
-    emit applyFiltSortData();
+    initiateQuery();
 }
 
 void RclMain::on_actionShowResultsAsTable_toggled(bool on)
@@ -1042,9 +1504,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	cmdplusattr = theconfig->getMimeViewerDef("application/x-all", "");
     } else {
         string apptag;
-        map<string,string>::const_iterator it;
-        if ((it = doc.meta.find(Rcl::Doc::keyapptg)) != doc.meta.end())
-            apptag = it->second;
+        doc.getmeta(Rcl::Doc::keyapptg, &apptag);
 	cmdplusattr = theconfig->getMimeViewerDef(doc.mimetype, apptag);
     }
 
@@ -1223,6 +1683,9 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 
     if (!istempfile)
 	historyEnterDoc(g_dynconf, doc.meta[Rcl::Doc::keyudi]);
+    
+    // Do the zeitgeist thing
+    zg_send_event(ZGSEND_OPEN, doc);
 
     // We keep pushing back and never deleting. This can't be good...
     ExecCmd *ecmd = new ExecCmd;
@@ -1303,13 +1766,13 @@ void RclMain::showDocHistory()
 	new DocSequenceHistory(rcldb, g_dynconf, 
 			       string(tr("Document history").toUtf8()));
     src->setDescription((const char *)tr("History data").toUtf8());
-    m_source = RefCntr<DocSequence>(src);
+    DocSource *source = new DocSource(theconfig, RefCntr<DocSequence>(src));
+    m_source = RefCntr<DocSequence>(source);
     m_source->setSortSpec(m_sortspec);
     m_source->setFiltSpec(m_filtspec);
     emit docSourceChanged(m_source);
     emit sortDataChanged(m_sortspec);
-    emit filtDataChanged(m_filtspec);
-    emit applyFiltSortData();
+    initiateQuery();
 }
 
 // Erase all memory of documents viewed
@@ -1336,12 +1799,7 @@ void RclMain::setUIPrefs()
     if (!uiprefs)
 	return;
     LOGDEB(("Recollmain::setUIPrefs\n"));
-    if (prefs.reslistfontfamily.length()) {
-	QFont nfont(prefs.reslistfontfamily, prefs.reslistfontsize);
-	reslist->setFont(nfont);
-    } else {
-	reslist->setFont(this->font());
-    }
+    reslist->setFont();
 }
 
 void RclMain::enableNextPage(bool yesno)
@@ -1372,7 +1830,8 @@ void RclMain::showQueryDetails()
 	return;
     string oq = breakIntoLines(m_source->getDescription(), 100, 50);
     QString str;
-    QString desc = tr("Result count (est.)") + ": " + str.setNum(m_source->getResCnt()) + "<br>";
+    QString desc = tr("Result count (est.)") + ": " + 
+	str.setNum(m_source->getResCnt()) + "<br>";
     desc += tr("Query details") + ": " + QString::fromUtf8(oq.c_str());
     QMessageBox::information(this, tr("Query details"), desc);
 }
@@ -1388,16 +1847,14 @@ void RclMain::catgFilter(int id)
 
     if (id != 0)  {
 	string catg = m_catgbutvec[id];
-	list<string> tps;
-	theconfig->getMimeCatTypes(catg, tps);
-	for (list<string>::const_iterator it = tps.begin();
-	     it != tps.end(); it++) 
-	    m_filtspec.orCrit(DocSeqFiltSpec::DSFS_MIMETYPE, *it);
+	string frag;
+	theconfig->getGuiFilter(catg, frag);
+	m_filtspec.orCrit(DocSeqFiltSpec::DSFS_QLANG, frag);
     }
+    LOGDEB(("RclMain::catgFilter: calling setFiltSpec\n"));
     if (m_source.isNotNull())
 	m_source->setFiltSpec(m_filtspec);
-    emit filtDataChanged(m_filtspec);
-    emit applyFiltSortData();
+    initiateQuery();
 }
 
 void RclMain::toggleFullScreen()
@@ -1412,17 +1869,9 @@ bool RclMain::eventFilter(QObject *, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress)  {
         LOGDEB2(("RclMain::eventFilter: keypress\n"));
-	QKeyEvent *ke = (QKeyEvent *)event;
-        // Shift-Home is the shortcut for the 1st result page action, but it is
-        // filtered by the search entry to mean "select all line". We prefer to
-        // keep it for the action as it's easy to find another combination to
-        // select all (ie: home, then shift-end)
-        if (ke->key() == Qt::Key_Home && 
-	    (ke->modifiers() & Qt::ShiftModifier)) {
-            // Shift-Home -> first page of results
-            reslist->resultPageFirst();
-            return true;
-        } 
+	// We used to map shift-home to reslist "goto first page"
+	// here but we now use shift-pageUp because shift-home is
+	// useful to select all inside the search entry
     } else if (event->type() == QEvent::Show)  {
 	LOGDEB2(("RclMain::eventFilter: Show\n"));
 	// move the focus to the search entry on show
@@ -1430,3 +1879,8 @@ bool RclMain::eventFilter(QObject *, QEvent *event)
     }
     return false;
 }
+
+void RclMain::applyStyleSheet()
+{
+    ::applyStyleSheet(prefs.stylesheetFile);
+}
