@@ -19,6 +19,7 @@
 
 #include <qvariant.h>
 #include <qmainwindow.h>
+#include <QFileSystemWatcher>
 
 #include "sortseq.h"
 #include "preview_w.h"
@@ -31,9 +32,12 @@
 #include "refcntr.h"
 #include "pathut.h"
 
+class IdxSchedW;
 class ExecCmd;
 class Preview;
 class ResTable;
+class CronToolW;
+class RTIToolW;
 
 #include "ui_rclmain.h"
 
@@ -48,8 +52,26 @@ class RclMain : public QMainWindow, public Ui::RclMainBase
     Q_OBJECT
 
 public:
+    enum  IndexerState {IXST_NOTRUNNING, IXST_RUNNINGMINE, IXST_RUNNINGNOTMINE};
     RclMain(QWidget * parent = 0) 
-	: QMainWindow(parent), m_sortspecnochange(false)
+	: QMainWindow(parent),
+	  curPreview(0),
+	  asearchform(0),
+	  uiprefs(0),
+	  indexConfig(0),
+	  indexSched(0),
+	  cronTool(0),
+	  rtiTool(0),
+	  spellform(0),
+	  periodictimer(0),
+	  restable(0),
+	  displayingTable(0),
+          m_idNoStem(0),
+          m_idAllStem(0),
+	  m_idxproc(0),
+	  m_sortspecnochange(false),
+	  m_indexerState(IXST_RUNNINGNOTMINE),
+	  m_queryActive(false)
     {
 	setupUi(this);
 	init();
@@ -58,23 +80,39 @@ public:
     virtual bool eventFilter(QObject *target, QEvent *event);
     QString getQueryDescription();
 
+    /** This is only called from main() to set an URL to be displayed (using
+	recoll as a doc extracter for embedded docs */
+    virtual void setUrlToView(const QString& u) {m_urltoview = u;}
+    /** Same usage: actually display the current urltoview */
+    virtual void viewUrl();
+
 public slots:
     virtual bool close();
     virtual void fileExit();
+    virtual void idxStatus();
     virtual void periodic100();
     virtual void toggleIndexing();
+    virtual void rebuildIndex();
     virtual void startSearch(RefCntr<Rcl::SearchData> sdata);
     virtual void previewClosed(Preview *w);
     virtual void showAdvSearchDialog();
     virtual void showSpellDialog();
     virtual void showAboutDialog();
     virtual void showMissingHelpers();
+    virtual void showActiveTypes();
     virtual void startManual();
     virtual void startManual(const string&);
     virtual void showDocHistory();
     virtual void showExtIdxDialog();
     virtual void showUIPrefs();
     virtual void showIndexConfig();
+    virtual void execIndexConfig();
+    virtual void showCronTool();
+    virtual void execCronTool();
+    virtual void showRTITool();
+    virtual void execRTITool();
+    virtual void showIndexSched();
+    virtual void execIndexSched();
     virtual void setUIPrefs();
     virtual void enableNextPage(bool);
     virtual void enablePrevPage(bool);
@@ -101,14 +139,13 @@ public slots:
     virtual void onSortDataChanged(DocSeqSortSpec);
     virtual void resultCount(int);
     virtual void showQueryDetails();
-    virtual void onResultsChanged();
+    virtual void applyStyleSheet();
 
 signals:
     void docSourceChanged(RefCntr<DocSequence>);
     void stemLangChanged(const QString& lang);
     void sortDataChanged(DocSeqSortSpec);
-    void filtDataChanged(DocSeqFiltSpec);
-    void applyFiltSortData();
+    void resultsReady();
     void searchReset();
 
 protected:
@@ -119,28 +156,42 @@ private:
     AdvSearch      *asearchform;
     UIPrefsDialog  *uiprefs;
     ConfIndexW     *indexConfig;
+    IdxSchedW      *indexSched;
+    CronToolW      *cronTool;
+    RTIToolW       *rtiTool;
     SpellW         *spellform;
     QTimer         *periodictimer;
     ResTable       *restable;
     bool            displayingTable;
-
+    QAction          *m_idNoStem;
+    QAction          *m_idAllStem;
+    QFileSystemWatcher m_watcher;
     vector<ExecCmd*>  m_viewers;
+    ExecCmd          *m_idxproc; // Indexing process
     map<QString, QAction*> m_stemLangToId;
     vector<string>    m_catgbutvec;
-    QAction *         m_idNoStem;
-    QAction *         m_idAllStem;
-    bool              m_idxStatusAck; // Did we act on last status?
     DocSeqFiltSpec    m_filtspec;
     bool              m_sortspecnochange;
     DocSeqSortSpec    m_sortspec;
     RefCntr<DocSequence> m_source;
-    int               m_periodicToggle;
+    IndexerState      m_indexerState;
+    bool              m_queryActive;
+
+    // If set on init, will be displayed either through ext app, or
+    // preview (if no ext app set)
+    QString          m_urltoview;
 
     virtual void init();
     virtual void previewPrevOrNextInTab(Preview *, int sid, int docnum, 
 					bool next);
     virtual void setStemLang(const QString& lang);
     virtual void onSortCtlChanged();
+    virtual void showIndexConfig(bool modal);
+    virtual void showIndexSched(bool modal);
+    virtual void showCronTool(bool modal);
+    virtual void showRTITool(bool modal);
+    virtual void updateIdxForDocs(vector<Rcl::Doc>&);
+    virtual void initiateQuery();
 };
 
 #endif // RCLMAIN_W_H
