@@ -20,9 +20,10 @@
 
 #include "rclconfig.h"
 #include "rcldb.h"
-#include "idxthread.h"
 #include "ptmutex.h"
 
+#include <QString>
+
 // Misc declarations in need of sharing between the UI files
 
 // Open the database if needed. We now force a close/open by default
@@ -41,9 +42,10 @@ extern void forgetTempFile(string &fn);
 
 extern Rcl::Db *rcldb;
 extern int recollNeedsExit;
-extern int startIndexingAfterConfig; // 1st startup
 extern void startManual(const string& helpindex);
 
+extern void applyStyleSheet(const QString&);
+
 #ifdef RCL_USE_ASPELL
 class Aspell;
 extern Aspell *aspell;
