@@ -49,6 +49,7 @@
 #include "plaintorich.h"
 #include "refcntr.h"
 #include "internfile.h"
+#include "indexer.h"
 
 #include "reslist.h"
 #include "moc_reslist.cpp"
@@ -61,6 +62,12 @@
 #define MIN(A,B) ((A) < (B) ? (A) : (B))
 #endif
 
+#ifndef RESLIST_TEXTBROWSER
+#include <QWebFrame>
+#include <QWebElement>
+#include <QWebSettings>
+#endif
+
 class QtGuiResListPager : public ResListPager {
 public:
     QtGuiResListPager(ResList *p, int ps) 
@@ -71,12 +78,14 @@ public:
     virtual string trans(const string& in);
     virtual string detailsLink();
     virtual const string &parFormat();
+    virtual const string &dateFormat();
     virtual string nextUrl();
     virtual string prevUrl();
-    virtual string pageTop();
-    virtual string iconPath(const string& mt);
-    virtual void suggest(const vector<string>uterms, vector<string>&sugg);
+    virtual string headerContent();
+    virtual void suggest(const vector<string>uterms, 
+			 map<string, vector<string> >& sugg);
     virtual string absSep() {return (const char *)(prefs.abssep.toUtf8());}
+    virtual string iconUrl(RclConfig *, Rcl::Doc& doc);
 private:
     ResList *m_parent;
 };
@@ -110,6 +119,7 @@ bool QtGuiResListPager::append(const string& data, int docnum,
     LOGDEB2(("QtGuiReslistPager::appendDoc: blockCount %d, %s\n",
 	    m_parent->document()->blockCount(), data.c_str()));
     logdata(data.c_str());
+#ifdef RESLIST_TEXTBROWSER
     int blkcnt0 = m_parent->document()->blockCount();
     m_parent->moveCursor(QTextCursor::End, QTextCursor::MoveAnchor);
     m_parent->textCursor().insertBlock();
@@ -120,6 +130,12 @@ bool QtGuiResListPager::append(const string& data, int docnum,
     for (int block = blkcnt0; block < blkcnt1; block++) {
 	m_parent->m_pageParaToReldocnums[block] = docnum;
     }
+#else
+    QString sdoc = QString("<div class=\"rclresult\" rcldocnum=\"%1\">").arg(docnum);
+    m_parent->append(sdoc);
+    m_parent->append(QString::fromUtf8(data.c_str()));
+    m_parent->append("</div>");
+#endif
     return true;
 }
 
@@ -140,6 +156,10 @@ const string& QtGuiResListPager::parFormat()
 {
     return prefs.creslistformat;
 }
+const string& QtGuiResListPager::dateFormat()
+{
+    return prefs.creslistdateformat;
+}
 
 string QtGuiResListPager::nextUrl()
 {
@@ -151,19 +171,13 @@ string QtGuiResListPager::prevUrl()
     return "p-1";
 }
 
-string QtGuiResListPager::pageTop() 
+string QtGuiResListPager::headerContent() 
 {
-    return string();
+    return (const char *)prefs.reslistheadertext.toUtf8();
 }
 
-string QtGuiResListPager::iconPath(const string& mtype)
-{
-    string iconpath;
-    theconfig->getMimeIconName(mtype, &iconpath);
-    return iconpath;
-}
-
-void QtGuiResListPager::suggest(const vector<string>uterms, vector<string>&sugg)
+void QtGuiResListPager::suggest(const vector<string>uterms, 
+				map<string, vector<string> >& sugg)
 {
     sugg.clear();
 #ifdef RCL_USE_ASPELL
@@ -179,6 +193,10 @@ void QtGuiResListPager::suggest(const vector<string>uterms, vector<string>&sugg)
          uit != uterms.end(); uit++) {
         list<string> asuggs;
         string reason;
+
+	// If the term is in the index, we don't suggest alternatives. 
+	// Actually, we may want to check the frequencies and propose something
+	// anyway if a possible variation is much more common (as google does)
         if (aspell->check(*rcldb, *uit, reason))
             continue;
         else if (!reason.empty())
@@ -189,19 +207,52 @@ void QtGuiResListPager::suggest(const vector<string>uterms, vector<string>&sugg)
             continue;
         }
         if (!asuggs.empty()) {
-            sugg.push_back(*asuggs.begin());
+            sugg[*uit] = vector<string>(asuggs.begin(), asuggs.end());
+	    if (sugg[*uit].size() > 5)
+		sugg[*uit].resize(5);
+	    // Set up the links as a <href="Sold|new">. 
+	    for (vector<string>::iterator it = sugg[*uit].begin();
+		 it != sugg[*uit].end(); it++) {
+		*it = string("<a href=\"S") + *uit + "|" + *it + "\">" +
+		    *it + "</a>";
+	    }
         }
     }
 #endif
 
 }
+
+string QtGuiResListPager::iconUrl(RclConfig *config, Rcl::Doc& doc)
+{
+    if (doc.ipath.empty()) {
+	vector<Rcl::Doc> docs;
+	docs.push_back(doc);
+	vector<string> paths;
+	ConfIndexer::docsToPaths(docs, paths);
+	if (!paths.empty()) {
+	    string path;
+	    LOGDEB0(("ResList::iconUrl: source path [%s]\n", paths[0].c_str()));
+	    if (thumbPathForUrl(cstr_fileu + paths[0], 128, path)) {
+		LOGDEB0(("ResList::iconUrl: icon path [%s]\n", path.c_str()));
+		return cstr_fileu + path;
+	    } else {
+		LOGDEB0(("ResList::iconUrl: no icon: path [%s]\n", 
+			 path.c_str()));
+	    }
+	} else {
+	    LOGDEB(("ResList::iconUrl: docsToPaths failed\n"));
+	}
+    }
+    return ResListPager::iconUrl(config, doc);
+}
+
 /////// /////// End reslistpager methods
 
 class PlainToRichQtReslist : public PlainToRich {
 public:
     virtual ~PlainToRichQtReslist() {}
     virtual string startMatch() {
-	return string("<span style='color: ")
+	return string("<span class='rclmatch' style='color: ")
 	    + string((const char *)prefs.qtermcolor.toAscii()) + string("'>");
     }
     virtual string endMatch() {return string("</span>");}
@@ -211,26 +262,36 @@ static PlainToRichQtReslist g_hiliter;
 /////////////////////////////////////
 
 ResList::ResList(QWidget* parent, const char* name)
-    : QTextBrowser(parent)
+    : RESLIST_PARENTCLASS(parent)
 {
     if (!name)
 	setObjectName("resList");
     else 
 	setObjectName(name);
+#ifdef RESLIST_TEXTBROWSER
+    LOGDEB(("Reslist: using QTextBrowser\n"));
     setReadOnly(TRUE);
     setUndoRedoEnabled(FALSE);
     setOpenLinks(FALSE);
-    languageChange();
-
     setTabChangesFocus(true);
+    // signals and slots connections
+    connect(this, SIGNAL(anchorClicked(const QUrl &)), 
+	    this, SLOT(linkWasClicked(const QUrl &)));
+#else
+    LOGDEB(("Reslist: using QWebView\n"));
+    // signals and slots connections
+    connect(this, SIGNAL(linkClicked(const QUrl &)), 
+	    this, SLOT(linkWasClicked(const QUrl &)));
+    page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
+    settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
+#endif
+    setFont();
+    languageChange();
 
     (void)new HelpClient(this);
     HelpClient::installMap((const char *)this->objectName().toAscii(), 
 			   "RCL.SEARCH.RESLIST");
 
-    // signals and slots connections
-    connect(this, SIGNAL(anchorClicked(const QUrl &)), 
-	    this, SLOT(linkWasClicked(const QUrl &)));
 #if 0
     // See comments in "highlighted
     connect(this, SIGNAL(highlighted(const QString &)), 
@@ -245,10 +306,6 @@ ResList::ResList(QWidget* parent, const char* name)
     m_listId = 0;
     m_pager = new QtGuiResListPager(this, prefs.respagesize);
     m_pager->setHighLighter(&g_hiliter);
-    if (prefs.reslistfontfamily.length()) {
-	QFont nfont(prefs.reslistfontfamily, prefs.reslistfontsize);
-	setFont(nfont);
-    }
 }
 
 ResList::~ResList()
@@ -272,6 +329,29 @@ ResList::~ResList()
     };
 }
 
+void ResList::setFont()
+{
+#ifdef RESLIST_TEXTBROWSER
+    if (prefs.reslistfontfamily.length()) {
+	QFont nfont(prefs.reslistfontfamily, prefs.reslistfontsize);
+	QTextBrowser::setFont(nfont);
+    } else {
+	QTextBrowser::setFont(QFont());
+    }
+#else
+    QWebSettings *websettings = settings();
+    if (prefs.reslistfontfamily.length()) {
+	websettings->setFontSize(QWebSettings::DefaultFontSize, 
+				 prefs.reslistfontsize);
+	websettings->setFontFamily(QWebSettings::StandardFont, 
+			       prefs.reslistfontfamily);
+    } else {
+	websettings->resetFontSize(QWebSettings::DefaultFontSize);
+	websettings->resetFontFamily(QWebSettings::StandardFont);
+    }
+#endif
+}
+
 int ResList::newListId()
 {
     static int id;
@@ -283,10 +363,11 @@ extern "C" int XFlush(void *);
 void ResList::setDocSource(RefCntr<DocSequence> nsource)
 {
     LOGDEB(("ResList::setDocSource()\n"));
-    m_source = RefCntr<DocSequence>(new DocSource(nsource));
+    m_source = RefCntr<DocSequence>(new DocSource(theconfig, nsource));
 }
 
-// Reapply parameters. Sort params probably changed
+// A query was executed, or the filtering/sorting parameters changed,
+// re-read the results.
 void ResList::readDocSource()
 {
     LOGDEB(("ResList::readDocSource()\n"));
@@ -302,16 +383,6 @@ void ResList::readDocSource()
     emit hasResults(m_source->getResCnt());
 }
 
-void ResList::setSortParams(DocSeqSortSpec)
-{
-    LOGDEB2(("ResList::setSortParams\n"));
-}
-
-void ResList::setFilterParams(const DocSeqFiltSpec&)
-{
-    LOGDEB2(("ResList::setFilterParams\n"));
-}
-
 void ResList::resetList() 
 {
     LOGDEB(("ResList::resetList()\n"));
@@ -327,12 +398,19 @@ void ResList::resetView()
     // slow search, the user will wonder if anything happened. The
     // following helps making sure that the textedit is really
     // blank. Else, there are often icons or text left around
+#ifdef RESLIST_TEXTBROWSER
+    m_pageParaToReldocnums.clear();
     clear();
     QTextBrowser::append(".");
     clear();
 #ifndef __APPLE__
     XFlush(QX11Info::display());
 #endif
+#else
+    m_text = "";
+    setHtml("<html><body></body></html>");
+#endif
+
 }
 
 bool ResList::displayingHistory()
@@ -350,6 +428,7 @@ void ResList::languageChange()
     setWindowTitle(tr("Result list"));
 }
 
+#ifdef RESLIST_TEXTBROWSER    
 // Get document number from text block number
 int ResList::docnumfromparnum(int block)
 {
@@ -367,7 +446,7 @@ int ResList::docnumfromparnum(int block)
     return -1;
 }
 
-// Get paragraph number from document number
+// Get range of paragraph numbers which make up the result for document number
 pair<int,int> ResList::parnumfromdocnum(int docnum)
 {
     LOGDEB(("parnumfromdocnum: docnum %d\n", docnum));
@@ -399,6 +478,7 @@ pair<int,int> ResList::parnumfromdocnum(int docnum)
     LOGDEB(("parnumfromdocnum: not found return -1,-1\n"));
     return pair<int,int>(-1,-1);
 }
+#endif // TEXTBROWSER
 
 // Return doc from current or adjacent result pages. We can get called
 // for a document not in the current page if the user browses through
@@ -434,14 +514,22 @@ bool ResList::getDoc(int docnum, Rcl::Doc &doc)
 
 void ResList::keyPressEvent(QKeyEvent * e)
 {
-    if (e->key() == Qt::Key_PageUp || e->key() == Qt::Key_Backspace) {
-	resPageUpOrBack();
-	return;
-    } else if (e->key() == Qt::Key_PageDown || e->key() == Qt::Key_Space) {
-	resPageDownOrNext();
-	return;
+    if ((e->modifiers() & Qt::ShiftModifier)) {
+	if (e->key() == Qt::Key_PageUp) {
+	    // Shift-PageUp -> first page of results
+	    resultPageFirst();
+	    return;
+	} 
+    } else {
+	if (e->key() == Qt::Key_PageUp || e->key() == Qt::Key_Backspace) {
+	    resPageUpOrBack();
+	    return;
+	} else if (e->key() == Qt::Key_PageDown || e->key() == Qt::Key_Space) {
+	    resPageDownOrNext();
+	    return;
+	}
     }
-    QTextBrowser::keyPressEvent(e);
+    RESLIST_PARENTCLASS::keyPressEvent(e);
 }
 
 void ResList::mouseReleaseEvent(QMouseEvent *e)
@@ -453,7 +541,7 @@ void ResList::mouseReleaseEvent(QMouseEvent *e)
     if (e->modifiers() & Qt::ShiftModifier) {
 	m_lstClckMod |= Qt::ShiftModifier;
     }
-    QTextBrowser::mouseReleaseEvent(e);
+    RESLIST_PARENTCLASS::mouseReleaseEvent(e);
 }
 
 void ResList::highlighted(const QString& )
@@ -468,28 +556,96 @@ void ResList::highlighted(const QString& )
 // fair enough, else we go to next/previous result page.
 void ResList::resPageUpOrBack()
 {
+#ifdef RESLIST_TEXTBROWSER
     int vpos = verticalScrollBar()->value();
     verticalScrollBar()->triggerAction(QAbstractSlider::SliderPageStepSub);
     if (vpos == verticalScrollBar()->value())
 	resultPageBack();
+#else
+    if (scrollIsAtTop()) {
+	resultPageBack();
+    } else {
+	QWebFrame *frame = page()->mainFrame();
+	frame->scroll(0, -int(0.9*geometry().height()));
+    }
+    setupArrows();
+#endif
 }
 
 void ResList::resPageDownOrNext()
 {
+#ifdef RESLIST_TEXTBROWSER
     int vpos = verticalScrollBar()->value();
     verticalScrollBar()->triggerAction(QAbstractSlider::SliderPageStepAdd);
     LOGDEB(("ResList::resPageDownOrNext: vpos before %d, after %d\n",
 	    vpos, verticalScrollBar()->value()));
     if (vpos == verticalScrollBar()->value()) 
 	resultPageNext();
+#else
+    if (scrollIsAtBottom()) {
+	resultPageNext();
+    } else {
+	QWebFrame *frame = page()->mainFrame();
+	frame->scroll(0, int(0.9*geometry().height()));
+    }
+    setupArrows();
+#endif
+}
+
+void ResList::setupArrows()
+{
+    emit prevPageAvailable(m_pager->hasPrev() || !scrollIsAtTop());
+    emit nextPageAvailable(m_pager->hasNext() || !scrollIsAtBottom());
+}
+
+bool ResList::scrollIsAtBottom()
+{
+#ifdef RESLIST_TEXTBROWSER
+    return false;
+#else
+    QWebFrame *frame = page()->mainFrame();
+    bool ret;
+    if (!frame || frame->scrollBarGeometry(Qt::Vertical).isEmpty()) {
+	ret = true;
+    } else {
+	int max = frame->scrollBarMaximum(Qt::Vertical);
+	int cur = frame->scrollBarValue(Qt::Vertical); 
+	ret = (max != 0) && (cur == max);
+	LOGDEB2(("Scrollatbottom: cur %d max %d\n", cur, max));
+    }
+    LOGDEB2(("scrollIsAtBottom: returning %d\n", ret));
+    return ret;
+#endif
+}
+
+bool ResList::scrollIsAtTop()
+{
+#ifdef RESLIST_TEXTBROWSER
+    return false;
+#else
+    QWebFrame *frame = page()->mainFrame();
+    bool ret;
+    if (!frame || frame->scrollBarGeometry(Qt::Vertical).isEmpty()) {
+	ret = true;
+    } else {
+	int cur = frame->scrollBarValue(Qt::Vertical);
+	int min = frame->scrollBarMinimum(Qt::Vertical);
+	LOGDEB(("Scrollattop: cur %d min %d\n", cur, min));
+	ret = (cur == min);
+    }
+#endif
+    LOGDEB2(("scrollIsAtTop: returning %d\n", ret));
+    return ret;
 }
 
 // Show previous page of results. We just set the current number back
 // 2 pages and show next page.
 void ResList::resultPageBack()
 {
-    m_pager->resultPageBack();
-    displayPage();
+    if (m_pager->hasPrev()) {
+	m_pager->resultPageBack();
+	displayPage();
+    }
 }
 
 // Go to the first page
@@ -501,18 +657,13 @@ void ResList::resultPageFirst()
     displayPage();
 }
 
-void ResList::append(const QString &text)
-{
-    LOGDEB2(("QtGuiReslistPager::appendQString  : %s\n", 
-	    (const char*)text.toUtf8()));
-    QTextBrowser::append(text);
-}
-
 // Fill up result list window with next screen of hits
 void ResList::resultPageNext()
 {
-    m_pager->resultPageNext();
-    displayPage();
+    if (m_pager->hasNext()) {
+	m_pager->resultPageNext();
+	displayPage();
+    }
 }
 
 void ResList::resultPageFor(int docnum)
@@ -521,18 +672,35 @@ void ResList::resultPageFor(int docnum)
     displayPage();
 }
 
+void ResList::append(const QString &text)
+{
+    LOGDEB2(("QtGuiReslistPager::appendQString  : %s\n", 
+	    (const char*)text.toUtf8()));
+#ifdef RESLIST_TEXTBROWSER
+    QTextBrowser::append(text);
+#else
+    m_text += text;
+#endif
+}
+
 void ResList::displayPage()
 {
-    m_pageParaToReldocnums.clear();
-    clear();
+    resetView();
+
     m_pager->displayPage(theconfig);
-    LOGDEB0(("ResList::resultPageNext: hasNext %d hasPrev %d\n",
-	    m_pager->hasPrev(), m_pager->hasNext()));
-    emit prevPageAvailable(m_pager->hasPrev());
-    emit nextPageAvailable(m_pager->hasNext());
+
+#ifndef RESLIST_TEXTBROWSER
+    setHtml(m_text);
+#endif
+
+    LOGDEB0(("ResList::displayPg: hasNext %d atBot %d hasPrev %d at Top %d \n",
+	     m_pager->hasPrev(), scrollIsAtBottom(), 
+	     m_pager->hasNext(), scrollIsAtTop()));
+    setupArrows();
+
     // Possibly color paragraph of current preview if any
     previewExposed(m_curPvDoc);
-    ensureCursorVisible();
+
 }
 
 // Color paragraph (if any) of currently visible preview
@@ -541,9 +709,9 @@ void ResList::previewExposed(int docnum)
     LOGDEB(("ResList::previewExposed: doc %d\n", docnum));
 
     // Possibly erase old one to white
-    pair<int,int> blockrange;
     if (m_curPvDoc != -1) {
-	blockrange = parnumfromdocnum(m_curPvDoc);
+#ifdef RESLIST_TEXTBROWSER
+	pair<int,int> blockrange = parnumfromdocnum(m_curPvDoc);
 	if (blockrange.first != -1) {
 	    for (int blockn = blockrange.first;
 		 blockn < blockrange.second; blockn++) {
@@ -554,17 +722,31 @@ void ResList::previewExposed(int docnum)
 		cursor.setBlockFormat(format);
 	    }
 	}
+#else
+	QString sel = 
+	   QString("div[rcldocnum=\"%1\"]").arg(m_curPvDoc - pageFirstDocNum());
+	LOGDEB2(("Searching for element, selector: [%s]\n", 
+		 (const char *)sel.toAscii()));
+	QWebElement elt = page()->mainFrame()->findFirstElement(sel);
+	if (!elt.isNull()) {
+	    LOGDEB2(("Found\n"));
+	    elt.removeAttribute("style");
+	} else {
+	    LOGDEB2(("Not Found\n"));
+	}
+#endif
 	m_curPvDoc = -1;
     }
 
     // Set background for active preview's doc entry
     m_curPvDoc = docnum;
-    blockrange = parnumfromdocnum(docnum);
+
+#ifdef RESLIST_TEXTBROWSER
+    pair<int,int>  blockrange = parnumfromdocnum(docnum);
 
     // Maybe docnum is -1 or not in this window, 
     if (blockrange.first < 0)
 	return;
-
     // Color the new active paragraph
     QColor color("LightBlue");
     for (int blockn = blockrange.first+1;
@@ -577,23 +759,38 @@ void ResList::previewExposed(int docnum)
 	setTextCursor(cursor);
 	ensureCursorVisible();
     }
+#else
+    QString sel = 
+	QString("div[rcldocnum=\"%1\"]").arg(docnum - pageFirstDocNum());
+    LOGDEB2(("Searching for element, selector: [%s]\n", 
+	    (const char *)sel.toAscii()));
+    QWebElement elt = page()->mainFrame()->findFirstElement(sel);
+    if (!elt.isNull()) {
+	LOGDEB2(("Found\n"));
+	elt.setAttribute("style", "background: LightBlue;}");
+    } else {
+	LOGDEB2(("Not Found\n"));
+    }
+#endif
 }
 
 // Double click in res list: add selection to simple search
 void ResList::mouseDoubleClickEvent(QMouseEvent *event)
 {
-    QTextBrowser::mouseDoubleClickEvent(event);
+    RESLIST_PARENTCLASS::mouseDoubleClickEvent(event);
+#ifdef RESLIST_TEXTBROWSER
     if (textCursor().hasSelection())
 	emit(wordSelect(textCursor().selectedText()));
+#else
+    emit(wordSelect(selectedText()));
+#endif
 }
 
 void ResList::linkWasClicked(const QUrl &url)
 {
-    QByteArray s = url.toString().toAscii();
-    const char *ascurl = (const char *)s;
-    LOGDEB(("ResList::linkWasClicked: [%s]\n", ascurl));
+    string ascurl = (const char *)url.toString().toAscii();;
+    LOGDEB(("ResList::linkWasClicked: [%s]\n", ascurl.c_str()));
 
-    int i = atoi(ascurl+1) - 1;
     int what = ascurl[0];
     switch (what) {
     case 'H': 
@@ -602,6 +799,7 @@ void ResList::linkWasClicked(const QUrl &url)
     case 'P': 
     case 'E': 
     {
+	int i = atoi(ascurl.c_str()+1) - 1;
 	Rcl::Doc doc;
 	if (!getDoc(i, doc)) {
 	    LOGERR(("ResList::linkWasClicked: can't get doc for %d\n", i));
@@ -619,8 +817,21 @@ void ResList::linkWasClicked(const QUrl &url)
     case 'p':
 	resultPageBack();
 	break;
+    case 'S':
+    {
+	QString s = url.toString();
+	if (!s.isEmpty())
+	    s = s.right(s.size()-1);
+	int bar = s.indexOf("|");
+	if (bar != -1 && bar < s.size()-1) {
+	    QString o = s.left(bar);
+	    QString n = s.right(s.size() - (bar+1));
+	    emit wordReplace(o, n);
+	}
+    }
+    break;
     default: 
-	LOGERR(("ResList::linkWasClicked: bad link [%s]\n", ascurl));
+	LOGERR(("ResList::linkWasClicked: bad link [%s]\n", ascurl.c_str()));
 	break;// ?? 
     }
 }
@@ -628,20 +839,41 @@ void ResList::linkWasClicked(const QUrl &url)
 void ResList::createPopupMenu(const QPoint& pos)
 {
     LOGDEB(("ResList::createPopupMenu(%d, %d)\n", pos.x(), pos.y()));
+#ifdef RESLIST_TEXTBROWSER
     QTextCursor cursor = cursorForPosition(pos);
     int blocknum = cursor.blockNumber();
     LOGDEB(("ResList::createPopupMenu(): block %d\n", blocknum));
     m_popDoc = docnumfromparnum(blocknum);
+#else
+    QWebHitTestResult htr = page()->mainFrame()->hitTestContent(pos);
+    if (htr.isNull())
+	return;
+    QWebElement el = htr.enclosingBlockElement();
+    while (!el.isNull() && !el.hasAttribute("rcldocnum"))
+	el = el.parent();
+    if (el.isNull())
+	return;
+    QString snum = el.attribute("rcldocnum");
+    m_popDoc = pageFirstDocNum() + snum.toInt();
+#endif
 
     if (m_popDoc < 0) 
 	return;
     QMenu *popup = new QMenu(this);
     popup->addAction(tr("&Preview"), this, SLOT(menuPreview()));
-    popup->addAction(tr("&Open"), this, SLOT(menuEdit()));
+
+    Rcl::Doc doc;
+    bool havedoc = getDoc(m_popDoc, doc);
+    string apptag;
+    if (havedoc)
+	doc.getmeta(Rcl::Doc::keyapptg, &apptag);
+
+    if (havedoc && !theconfig->getMimeViewerDef(doc.mimetype, apptag).empty()) {
+	popup->addAction(tr("&Open"), this, SLOT(menuEdit()));
+    }
     popup->addAction(tr("Copy &File Name"), this, SLOT(menuCopyFN()));
     popup->addAction(tr("Copy &URL"), this, SLOT(menuCopyURL()));
-    Rcl::Doc doc;
-    if (getDoc(m_popDoc, doc) && !doc.ipath.empty()) {
+    if (havedoc && !doc.ipath.empty()) {
 	popup->addAction(tr("&Write to File"), this, SLOT(menuSaveToFile()));
     }
 
@@ -649,7 +881,7 @@ void ResList::createPopupMenu(const QPoint& pos)
     popup->addAction(tr("Preview P&arent document/folder"), 
 		      this, SLOT(menuPreviewParent()));
     popup->addAction(tr("&Open Parent document/folder"), 
-		      this, SLOT(menuOpenParent()));
+		     this, SLOT(menuOpenParent()));
     popup->popup(mapToGlobal(pos));
 }
 
