@@ -40,6 +40,7 @@
 #include <qwhatsthis.h>
 #include <qtextedit.h>
 #include <qlist.h>
+#include <QTimer>
 
 #include "recoll.h"
 #include "guiutils.h"
@@ -49,6 +50,8 @@
 #include "uiprefs_w.h"
 #include "viewaction_w.h"
 #include "debuglog.h"
+#include "editdialog.h"
+#include "rclmain_w.h"
 
 void UIPrefsDialog::init()
 {
@@ -57,6 +60,8 @@ void UIPrefsDialog::init()
     connect(viewActionPB, SIGNAL(clicked()), this, SLOT(showViewAction()));
     connect(reslistFontPB, SIGNAL(clicked()), this, SLOT(showFontDialog()));
     connect(resetFontPB, SIGNAL(clicked()), this, SLOT(resetReslistFont()));
+    connect(stylesheetPB, SIGNAL(clicked()), this, SLOT(showStylesheetDialog()));
+    connect(resetSSPB, SIGNAL(clicked()), this, SLOT(resetStylesheet()));
 
     connect(addExtraDbPB, SIGNAL(clicked()), 
 	    this, SLOT(addExtraDbPB_clicked()));
@@ -68,7 +73,8 @@ void UIPrefsDialog::init()
 	    this, SLOT(actAllExtraDbPB_clicked()));
     connect(unacAllExtraDbPB, SIGNAL(clicked()), 
 	    this, SLOT(unacAllExtraDbPB_clicked()));
-
+    connect(CLEditPara, SIGNAL(clicked()), this, SLOT(editParaFormat()));
+    connect(CLEditHeader, SIGNAL(clicked()), this, SLOT(editHeaderText()));
     connect(buttonOk, SIGNAL(clicked()), this, SLOT(accept()));
     connect(buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
     connect(buildAbsCB, SIGNAL(toggled(bool)), 
@@ -104,6 +110,7 @@ void UIPrefsDialog::setFromPrefs()
     qtermColorLE->setText(prefs.qtermcolor);
     // Abstract snippet separator string
     abssepLE->setText(prefs.abssep);
+    dateformatLE->setText(prefs.reslistdateformat);
 
     // Result list font family and size
     reslistFontFamily = prefs.reslistfontfamily;
@@ -116,7 +123,18 @@ void UIPrefsDialog::setFromPrefs()
 	reslistFontPB->setText(reslistFontFamily + "-" +
 			       s.setNum(reslistFontSize));
     }
-    rlfTE->setPlainText(prefs.reslistformat);
+
+    // Style sheet
+    stylesheetFile = prefs.stylesheetFile;
+    if (stylesheetFile.isEmpty()) {
+	stylesheetPB->setText(tr("Choose"));
+    } else {
+	string nm = path_getsimple((const char *)stylesheetFile.toLocal8Bit());
+	stylesheetPB->setText(QString::fromLocal8Bit(nm.c_str()));
+    }
+
+    paraFormat = prefs.reslistformat;
+    headerText = prefs.reslistheadertext;
 
     // Stemming language combobox
     stemLangCMB->clear();
@@ -140,6 +158,7 @@ void UIPrefsDialog::setFromPrefs()
     stemLangCMB->setCurrentIndex(cur);
 
     autoPhraseCB->setChecked(prefs.ssearchAutoPhrase);
+    autoPThreshSB->setValue(prefs.ssearchAutoPhraseThreshPC);
 
     buildAbsCB->setChecked(prefs.queryBuildAbstract);
     replAbsCB->setEnabled(prefs.queryBuildAbstract);
@@ -181,14 +200,20 @@ void UIPrefsDialog::accept()
 
     prefs.qtermcolor = qtermColorLE->text();
     prefs.abssep = abssepLE->text();
+    prefs.reslistdateformat = dateformatLE->text();
+    prefs.creslistdateformat = (const char*)prefs.reslistdateformat.toUtf8();
 
     prefs.reslistfontfamily = reslistFontFamily;
     prefs.reslistfontsize = reslistFontSize;
-    prefs.reslistformat =  rlfTE->toPlainText();
+    prefs.stylesheetFile = stylesheetFile;
+    QTimer::singleShot(0, m_mainWindow, SLOT(applyStyleSheet()));
+    prefs.reslistformat =  paraFormat;
+    prefs.reslistheadertext =  headerText;
     if (prefs.reslistformat.trimmed().isEmpty()) {
 	prefs.reslistformat = prefs.dfltResListFormat;
-	rlfTE->setPlainText(prefs.reslistformat);
+	paraFormat = prefs.reslistformat;
     }
+
     prefs.creslistformat = (const char*)prefs.reslistformat.toUtf8();
 
     if (stemLangCMB->currentIndex() == 0) {
@@ -199,6 +224,7 @@ void UIPrefsDialog::accept()
 	prefs.queryStemLang = stemLangCMB->currentText();
     }
     prefs.ssearchAutoPhrase = autoPhraseCB->isChecked();
+    prefs.ssearchAutoPhraseThreshPC = autoPThreshSB->value();
     prefs.queryBuildAbstract = buildAbsCB->isChecked();
     prefs.queryReplaceAbstract = buildAbsCB->isChecked() && 
 	replAbsCB->isChecked();
@@ -236,6 +262,23 @@ void UIPrefsDialog::accept()
     QDialog::accept();
 }
 
+void UIPrefsDialog::editParaFormat()
+{
+    EditDialog dialog(this);
+    dialog.plainTextEdit->setPlainText(paraFormat);
+    int result = dialog.exec();
+    if (result == QDialog::Accepted)
+	paraFormat = dialog.plainTextEdit->toPlainText();
+}
+void UIPrefsDialog::editHeaderText()
+{
+    EditDialog dialog(this);
+    dialog.plainTextEdit->setPlainText(headerText);
+    int result = dialog.exec();
+    if (result == QDialog::Accepted)
+	headerText = dialog.plainTextEdit->toPlainText();
+}
+
 void UIPrefsDialog::reject()
 {
     setFromPrefs();
@@ -273,20 +316,35 @@ void UIPrefsDialog::showFontDialog()
     if (ok) {
 	// Check if the default font was set, in which case we
 	// erase the preference
+	QString s;
 	if (font.family().compare(this->font().family()) || 
 	    font.pointSize() != this->font().pointSize()) {
 	    reslistFontFamily = font.family();
 	    reslistFontSize = font.pointSize();
-	    QString s;
 	    reslistFontPB->setText(reslistFontFamily + "-" +
 			       s.setNum(reslistFontSize));
 	} else {
 	    reslistFontFamily = "";
 	    reslistFontSize = 0;
+	    reslistFontPB->setText(this->font().family() + "-" +
+				   s.setNum(this->font().pointSize()));
 	}
     }
 }
 
+void UIPrefsDialog::showStylesheetDialog()
+{
+    stylesheetFile = myGetFileName(false, "Select stylesheet file", true);
+    string nm = path_getsimple((const char *)stylesheetFile.toLocal8Bit());
+    stylesheetPB->setText(QString::fromLocal8Bit(nm.c_str()));
+}
+
+void UIPrefsDialog::resetStylesheet()
+{
+    stylesheetFile = "";
+    stylesheetPB->setText(tr("Choose"));
+}
+
 void UIPrefsDialog::resetReslistFont()
 {
     reslistFontFamily = "";
