@@ -23,14 +23,15 @@
 
 class QDialog;
 class ViewAction;
+class RclMain;
 
 class UIPrefsDialog : public QDialog, public Ui::uiPrefsDialogBase
 {
     Q_OBJECT
 
 public:
-    UIPrefsDialog(QDialog* parent = 0)
-	: QDialog(parent) 
+    UIPrefsDialog(RclMain* parent)
+	: QDialog((QWidget*)parent), m_mainWindow(parent)
 	{
 	    setupUi(this);
 	    init();
@@ -39,20 +40,25 @@ public:
 
     QString reslistFontFamily;
     int reslistFontSize;
+    QString stylesheetFile;
 
     virtual void init();
 
 public slots:
     virtual void showFontDialog();
+    virtual void resetReslistFont();
+    virtual void showStylesheetDialog();
+    virtual void resetStylesheet();
     virtual void showViewAction();
     virtual void showViewAction(const QString& mt);
-    virtual void resetReslistFont();
     virtual void addExtraDbPB_clicked();
     virtual void delExtraDbPB_clicked();
     virtual void togExtraDbPB_clicked();
     virtual void actAllExtraDbPB_clicked();
     virtual void unacAllExtraDbPB_clicked();
     virtual void setStemLang(const QString& lang);
+    virtual void editParaFormat();
+    virtual void editHeaderText();
 
 signals:
     void uiprefsDone();
@@ -61,9 +67,12 @@ protected slots:
     virtual void accept();
     virtual void reject();
 private:
+    // Locally stored data (pending ok/cancel)
+    QString paraFormat;
+    QString headerText;
     void setFromPrefs();
     ViewAction *m_viewAction;
-
+    RclMain *m_mainWindow;
 };
 
 #endif /* _UIPREFS_W_H_INCLUDED_ */
