@@ -62,7 +62,7 @@ bool DocSource::buildStack()
     } else {
 	if (m_fspec.isNotNull()) {
 	    m_seq = 
-		RefCntr<DocSequence>(new DocSeqFiltered(m_seq, m_fspec));
+		RefCntr<DocSequence>(new DocSeqFiltered(m_config, m_seq, m_fspec));
 	} 
     }
     
@@ -81,7 +81,7 @@ bool DocSource::buildStack()
 string DocSource::title()
 {
     if (m_seq.isNull())
-	return "";
+	return string();
     string qual;
     if (m_fspec.isNotNull() && !m_sspec.isNotNull())
 	qual = string(" (") + o_filt_trans + string(")");
