@@ -79,26 +79,29 @@ void output_fields(const vector<string>fields, Rcl::Doc& doc,
 
 static char *thisprog;
 static char usage [] =
-" -P: Show date span for documents in index\n"
-" [-o|-a|-f] <query string>\n"
+" -P: Show the date span for all the documents present in the index\n"
+" [-o|-a|-f] [-q] <query string>\n"
 " Runs a recoll query and displays result lines. \n"
 "  Default: will interpret the argument(s) as a xesam query string\n"
 "    query may be like: \n"
 "    implicit AND, Exclusion, field spec:    t1 -t2 title:t3\n"
 "    OR has priority: t1 OR t2 t3 OR t4 means (t1 OR t2) AND (t3 OR t4)\n"
 "    Phrase: \"t1 t2\" (needs additional quoting on cmd line)\n"
-"  -o Emulate the gui simple search in ANY TERM mode\n"
-"  -a Emulate the gui simple search in ALL TERMS mode\n"
-"  -f Emulate the gui simple search in filename mode\n"
+"  -o Emulate the GUI simple search in ANY TERM mode\n"
+"  -a Emulate the GUI simple search in ALL TERMS mode\n"
+"  -f Emulate the GUI simple search in filename mode\n"
+"  -q is just ignored (compatibility with the recoll GUI command line)\n"
 "Common options:\n"
 "    -c <configdir> : specify config directory, overriding $RECOLL_CONFDIR\n"
 "    -d also dump file contents\n"
-"    -n <cnt> limit the maximum number of results (0->no limit, default 2000)\n"
+"    -n [first-]<cnt> define the result slice. The default value for [first]\n"
+"       is 0. Without the option, the default max count is 2000.\n"
+"       Use n=0 for no limit\n"
 "    -b : basic. Just output urls, no mime types or titles\n"
 "    -Q : no result lines, just the processed query and result count\n"
-"    -m : dump the whole document meta[] array\n"
+"    -m : dump the whole document meta[] array for each result\n"
 "    -A : output the document abstracts\n"
-"    -S fld : sort by field name\n"
+"    -S fld : sort by field <fld>\n"
 "    -D : sort descending\n"
 "    -i <dbdir> : additional index, several can be given\n"
 "    -e use url encoding (%xx) for urls\n"
@@ -151,7 +154,8 @@ int recollq(RclConfig **cfp, int argc, char **argv)
     string sf;
     vector<string> fields;
 
-    int limit = 2000;
+    int firstres = 0;
+    int maxcount = 2000;
     thisprog = argv[0];
     argc--; argv++;
 
@@ -181,9 +185,20 @@ int recollq(RclConfig **cfp, int argc, char **argv)
             case 'l':   op_flags |= OPT_l; break;
             case 'm':   op_flags |= OPT_m; break;
 	    case 'n':	op_flags |= OPT_n; if (argc < 2)  Usage();
-		limit = atoi(*(++argv));
-		if (limit <= 0) limit = INT_MAX;
-		argc--; goto b1;
+	    {
+		string rescnt = *(++argv);
+		string::size_type dash = rescnt.find("-");
+		if (dash != string::npos) {
+		    firstres = atoi(rescnt.substr(0, dash).c_str());
+		    if (dash < rescnt.size()-1) {
+			maxcount = atoi(rescnt.substr(dash+1).c_str());
+		    }
+		} else {
+		    maxcount = atoi(rescnt.c_str());
+		}
+		if (maxcount <= 0) maxcount = INT_MAX;
+	    }
+	    argc--; goto b1;
             case 'o':   op_flags |= OPT_o; break;
             case 'P':   op_flags |= OPT_P; break;
             case 'q':   op_flags |= OPT_q; break;
@@ -307,25 +322,24 @@ int recollq(RclConfig **cfp, int argc, char **argv)
     int cnt = query.getResCnt();
     if (!(op_flags & OPT_b)) {
 	cout << "Recoll query: " << rq->getDescription() << endl;
-	if (cnt <= limit)
-	    cout << cnt << " results" << endl;
-	else
-	    cout << cnt << " results (printing  " << limit << " max):" << endl;
+	if (firstres == 0) {
+	    if (cnt <= maxcount)
+		cout << cnt << " results" << endl;
+	    else
+		cout << cnt << " results (printing  " << maxcount << " max):" 
+		     << endl;
+	} else {
+	    cout << "Printing at most " << cnt - (firstres+maxcount) <<
+		" results from first " << firstres << endl;
+	}
     }
     if (op_flags & OPT_Q)
 	cout << "Query setup took " << chron.millis() << " mS" << endl;
 
-    TempDir tmpdir;
-    if (!tmpdir.ok()) {
-	cerr << "Can't create temporary directory: " << 
-	    tmpdir.getreason() << endl;
-	return(1);
-    }
-
     if (op_flags & OPT_Q)
 	return(0);
 
-    for (int i = 0; i < limit; i++) {
+    for (int i = firstres; i < firstres + maxcount; i++) {
 	Rcl::Doc doc;
 	if (!query.getDoc(i, doc))
 	    break;
@@ -341,12 +355,16 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	if (op_flags & OPT_b) {
 		cout << doc.url << endl;
 	} else {
+	    string titleorfn = doc.meta[Rcl::Doc::keytt];
+	    if (titleorfn.empty())
+		titleorfn = doc.meta[Rcl::Doc::keyfn];
+
 	    char cpc[20];
 	    sprintf(cpc, "%d", doc.pc);
 	    cout 
 		<< doc.mimetype << "\t"
 		<< "[" << doc.url << "]" << "\t" 
-		<< "[" << doc.meta[Rcl::Doc::keytt] << "]" << "\t"
+		<< "[" << titleorfn << "]" << "\t"
 		<< doc.fbytes << "\tbytes" << "\t"
 		<<  endl;
 	    if (op_flags & OPT_m) {
@@ -365,6 +383,12 @@ int recollq(RclConfig **cfp, int argc, char **argv)
             }
         }
         if (op_flags & OPT_d) {
+	    static TempDir tmpdir;
+	    if (!tmpdir.ok()) {
+		cerr << "Can't create temporary directory: " << 
+		    tmpdir.getreason() << endl;
+		return(1);
+	    }
             dump_contents(rclconfig, tmpdir, doc);
         }	
     }
