@@ -27,6 +27,7 @@
 using std::ostringstream;
 using std::endl;
 
+#include "cstr.h"
 #include "reslistpager.h"
 #include "debuglog.h"
 #include "rclconfig.h"
@@ -48,8 +49,9 @@ static PlainToRichHtReslist g_hiliter;
 ResListPager::ResListPager(int pagesize) 
     : m_pagesize(pagesize),
       m_newpagesize(pagesize),
+      m_resultsInCurrentPage(0),
       m_winfirst(-1),
-      m_hasNext(false),
+      m_hasNext(true),
       m_hiliter(&g_hiliter)
 {
 }
@@ -70,12 +72,19 @@ void ResListPager::resultPageNext()
     } else {
 	m_winfirst += m_respage.size();
     }
-    // Get the next page of results.
+    // Get the next page of results. Note that we look ahead by one to
+    // determine if there is actually a next page
     vector<ResListEntry> npage;
-    int pagelen = m_docSource->getSeqSlice(m_winfirst, m_pagesize, npage);
+    int pagelen = m_docSource->getSeqSlice(m_winfirst, m_pagesize + 1, npage);
 
     // If page was truncated, there is no next
-    m_hasNext = (pagelen == m_pagesize);
+    m_hasNext = (pagelen == m_pagesize + 1);
+
+    // Get rid of the possible excess result
+    if (pagelen == m_pagesize + 1) {
+	npage.resize(m_pagesize);
+	pagelen--;
+    }
 
     if (pagelen <= 0) {
 	// No results ? This can only happen on the first page or if the
@@ -93,6 +102,7 @@ void ResListPager::resultPageNext()
 	}
 	return;
     }
+    m_resultsInCurrentPage = pagelen;
     m_respage = npage;
 }
 
@@ -137,15 +147,22 @@ void ResListPager::displayDoc(RclConfig *config,
     }
 
     // Determine icon to display if any
-    string iconpath = iconPath(config, doc.mimetype);
+    string iconurl = iconUrl(config, doc);
 
     // Printable url: either utf-8 if transcoding succeeds, or url-encoded
     string url;
     printableUrl(config->getDefCharset(), doc.url, url);
 
     // Make title out of file name if none yet
-    if (doc.meta[Rcl::Doc::keytt].empty()) {
-	doc.meta[Rcl::Doc::keytt] = path_getsimple(url);
+    string titleOrFilename;
+    string utf8fn;
+    doc.getmeta(Rcl::Doc::keytt, &titleOrFilename);
+    doc.getmeta(Rcl::Doc::keyfn, &utf8fn);
+    if (utf8fn.empty()) {
+	utf8fn = path_getsimple(url);	
+    }
+    if (titleOrFilename.empty()) {
+	titleOrFilename = utf8fn;
     }
 
     // Result number
@@ -160,7 +177,7 @@ void ResListPager::displayDoc(RclConfig *config,
 	time_t mtime = doc.dmtime.empty() ?
 	    atol(doc.fmtime.c_str()) : atol(doc.dmtime.c_str());
 	struct tm *tm = localtime(&mtime);
-	strftime(datebuf, 99, "&nbsp;%Y-%m-%d&nbsp;%H:%M:%S&nbsp;%z", tm);
+	strftime(datebuf, 99, dateFormat().c_str(), tm);
     }
 
     // Size information. We print both doc and file if they differ a lot
@@ -205,9 +222,7 @@ void ResListPager::displayDoc(RclConfig *config,
     }
 
     string apptag;
-    map<string,string>::const_iterator it;
-    if ((it = doc.meta.find(Rcl::Doc::keyapptg)) != doc.meta.end())
-	apptag = it->second;
+    doc.getmeta(Rcl::Doc::keyapptg, &apptag);
 
     if (!config->getMimeViewerDef(doc.mimetype, apptag).empty()) {
 	linksbuf << "<a href=\"E" << docnumforlinks << "\">"  
@@ -226,7 +241,7 @@ void ResListPager::displayDoc(RclConfig *config,
     map<string,string> subs;
     subs["A"] = !richabst.empty() ? richabst : "";
     subs["D"] = datebuf;
-    subs["I"] = iconpath;
+    subs["I"] = iconurl;
     subs["i"] = doc.ipath;
     subs["K"] = !doc.meta[Rcl::Doc::keykw].empty() ? 
 	string("[") + escapeHtml(doc.meta[Rcl::Doc::keykw]) + "]" : "";
@@ -235,7 +250,8 @@ void ResListPager::displayDoc(RclConfig *config,
     subs["M"] = doc.mimetype;
     subs["R"] = doc.meta[Rcl::Doc::keyrr];
     subs["S"] = sizebuf;
-    subs["T"] = escapeHtml(doc.meta[Rcl::Doc::keytt]);
+    subs["T"] = escapeHtml(titleOrFilename);
+    subs["t"] = escapeHtml(doc.meta[Rcl::Doc::keytt]);
     subs["U"] = url;
 
     // Let %(xx) access all metadata.
@@ -280,6 +296,7 @@ void ResListPager::displayPage(RclConfig *config)
     chunk << "<html><head>" << endl
 	  << "<meta http-equiv=\"content-type\""
 	  << " content=\"text/html; charset=utf-8\">" << endl
+	  << headerContent()
 	  << "</head><body>" << endl
 	  << pageTop()
 	  << "<p><font size=+1><b>"
@@ -291,17 +308,24 @@ void ResListPager::displayPage(RclConfig *config)
         vector<string>uterms;
         m_docSource->getUTerms(uterms);
         if (!uterms.empty()) {
-            vector<string> spellings;
+            map<string, vector<string> > spellings;
             suggest(uterms, spellings);
             if (!spellings.empty()) {
                 chunk << 
-                 trans("<p><i>Alternate spellings (accents suppressed): </i>");
-                for (vector<string>::iterator it = spellings.begin();
-                     it != spellings.end(); it++) {
-                    chunk << *it;
-                    chunk << " ";
-                }
-                chunk << "</p>";
+                 trans("<p><i>Alternate spellings (accents suppressed): </i>")
+		      << "<br /><blockquote>";
+
+		for (map<string, vector<string> >::const_iterator it0 =
+			 spellings.begin(); it0 != spellings.end(); it0++) {
+		    chunk << "<b>" << it0->first << "</b> : ";
+		    for (vector<string>::const_iterator it = 
+			     it0->second.begin();
+			 it != it0->second.end(); it++) {
+			chunk << *it << " ";
+		    }
+		    chunk << "<br />";
+		}
+                chunk << "</blockquote></p>";
             }
         }
     } else {
@@ -380,12 +404,12 @@ string ResListPager::prevUrl()
     return "p-1";
 }
 
-string ResListPager::iconPath(RclConfig *config, const string& mtype)
+string ResListPager::iconUrl(RclConfig *config, Rcl::Doc& doc)
 {
-    string iconpath;
-    config->getMimeIconName(mtype, &iconpath);
-    iconpath = string("file://") + iconpath;
-    return iconpath;
+    string iconurl;
+    config->getMimeIconName(doc.mimetype, &iconurl);
+    iconurl = cstr_fileu + iconurl;
+    return iconurl;
 }
 
 bool ResListPager::append(const string& data)
@@ -415,3 +439,9 @@ const string &ResListPager::parFormat()
     return cstr_format;
 }
 
+const string &ResListPager::dateFormat()
+{
+    static const string cstr_format("&nbsp;%Y-%m-%d&nbsp;%H:%M:%S&nbsp;%z");
+    return cstr_format;
+}
+
