@@ -34,6 +34,7 @@ using namespace std;
 #include "xapian.h"
 
 #include "rclconfig.h"
+#include "debuglog.h"
 #include "rcldb.h"
 #include "rcldb_p.h"
 #include "stemdb.h"
@@ -41,7 +42,6 @@ using namespace std;
 #include "transcode.h"
 #include "unacpp.h"
 #include "conftree.h"
-#include "debuglog.h"
 #include "pathut.h"
 #include "smallut.h"
 #include "utf8iter.h"
@@ -52,6 +52,7 @@ using namespace std;
 #include "rclversion.h"
 #include "cancelcheck.h"
 #include "ptmutex.h"
+#include "termproc.h"
 
 #ifndef MAX
 #define MAX(A,B) (A>B?A:B)
@@ -94,7 +95,6 @@ static const string cstr_syntAbs("?!#@");
 // Only ONE field name inside the index data record differs from the
 // Rcl::Doc ones: caption<->title, for a remnant of compatibility with
 // omega
-static const string cstr_keycap("caption");
 
 // Static/Default table for field->prefix/weight translation. 
 // This is logically const after initialization. Can't use a
@@ -125,7 +125,7 @@ static void initFldToTraits()
     fldToTraits["ext"] = FieldTraits("XE");
     fldToTraits[Doc::keyfn] = FieldTraits("XSFN");
 
-    fldToTraits[cstr_keycap] = FieldTraits("S");
+    fldToTraits[cstr_caption] = FieldTraits("S");
     fldToTraits[Doc::keytt] = FieldTraits("S");
     fldToTraits["subject"] = FieldTraits("S");
 
@@ -141,6 +141,7 @@ static void initFldToTraits()
     fldToTraits["xapyear"] = FieldTraits("Y");
     fldToTraits["xapyearmon"] = FieldTraits("M");
     fldToTraits["xapdate"] = FieldTraits("D");
+    fldToTraits[Doc::keytp] = FieldTraits("T");
 }
 
 // Compute the unique term used to link documents to their origin. 
@@ -198,7 +199,7 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
     parms.get(Doc::keyfmt, doc.fmtime);
     parms.get(Doc::keydmt, doc.dmtime);
     parms.get(Doc::keyoc, doc.origcharset);
-    parms.get(cstr_keycap, doc.meta[Doc::keytt]);
+    parms.get(cstr_caption, doc.meta[Doc::keytt]);
     parms.get(Doc::keykw, doc.meta[Doc::keykw]);
     parms.get(Doc::keyabs, doc.meta[Doc::keyabs]);
     // Possibly remove synthetic abstract indicator (if it's there, we
@@ -209,6 +210,7 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
 	doc.syntabs = true;
     }
     parms.get(Doc::keyipt, doc.ipath);
+    parms.get(Doc::keypcs, doc.pcbytes);
     parms.get(Doc::keyfs, doc.fbytes);
     parms.get(Doc::keyds, doc.dbytes);
     parms.get(Doc::keysig, doc.sig);
@@ -570,6 +572,12 @@ Db::Db(RclConfig *cfp)
 	m_config->getConfParam("maxfsoccuppc", &m_maxFsOccupPc);
 	m_config->getConfParam("idxflushmb", &m_flushMb);
     }
+#ifdef IDX_THREADS
+    if (m_ndb && !m_ndb->m_wqueue.start(DbUpdWorker, this)) {
+	LOGERR(("Db::Db: Worker start failed\n"));
+	return;
+    }
+#endif // IDX_THREADS
 }
 
 Db::~Db()
@@ -859,9 +867,8 @@ bool Db::fieldToTraits(const string& fld, const FieldTraits **ftpp)
 // The splitter breaks text into words and adds postings to the Xapian
 // document. We use a single object to split all of the document
 // fields and position jumps to separate fields
-class TextSplitDb : public TextSplit {
+class TextSplitDb : public TextSplitP {
  public:
-    Xapian::WritableDatabase db;
     Xapian::Document &doc;   // Xapian document 
     // Base for document section. Gets large increment when we change
     // sections, to avoid cross-section proximity matches.
@@ -874,17 +881,17 @@ class TextSplitDb : public TextSplit {
     // to compute the first position of the next section.
     Xapian::termpos curpos;
 
-    StopList &stops;
-    TextSplitDb(Xapian::WritableDatabase idb, 
-		Xapian::Document &d, StopList &_stops) 
-	: db(idb), doc(d), basepos(1), curpos(0), stops(_stops), wdfinc(1)
+    TextSplitDb(Xapian::Document &d, TermProc *prc)
+	: TextSplitP(prc), 
+	  doc(d), basepos(1), curpos(0), wdfinc(1)
     {}
     // Reimplement text_to_words to add start and end special terms
     virtual bool text_to_words(const string &in);
-    bool takeword(const std::string &term, int pos, int, int);
     void setprefix(const string& pref) {prefix = pref;}
     void setwdfinc(int i) {wdfinc = i;}
 
+    friend class TermProcIdx;
+
 private:
     // If prefix is set, we also add a posting for the prefixed terms
     // (ie: for titles, add postings for both "term" and "Sterm")
@@ -893,11 +900,12 @@ private:
     int wdfinc;
 };
 
-
+// Reimplement text_to_words to insert the begin and end anchor terms.
 bool TextSplitDb::text_to_words(const string &in) 
 {
-    LOGDEB2(("TextSplitDb::text_to_words\n"));
+    bool ret = false;
     string ermsg;
+
     try {
 	// Index the possibly prefixed start term.
 	doc.add_posting(prefix + start_of_field_term, basepos, wdfinc);
@@ -905,14 +913,12 @@ bool TextSplitDb::text_to_words(const string &in)
     } XCATCHERROR(ermsg);
     if (!ermsg.empty()) {
 	LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
-	basepos += curpos + 100;
-	return false;
+	goto out;
     }
 
-    if (!TextSplit::text_to_words(in)) {
+    if (!TextSplitP::text_to_words(in)) {
 	LOGDEB(("TextSplitDb: TextSplit::text_to_words failed\n"));
-	basepos += curpos + 100;
-	return false;
+	goto out;
     }
 
     try {
@@ -922,54 +928,51 @@ bool TextSplitDb::text_to_words(const string &in)
     } XCATCHERROR(ermsg);
     if (!ermsg.empty()) {
 	LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
-	basepos += curpos + 100;
-	return false;
+	goto out;
     }
+
+    ret = true;
+
+out:
     basepos += curpos + 100;
     return true;
 }
 
-// Get one term from the doc, remove accents and lowercase, then add posting
-bool TextSplitDb::takeword(const std::string &_term, int pos, int, int)
-{
-    LOGDEB2(("TextSplitDb::takeword: [%s]\n", _term.c_str()));
+class TermProcIdx : public TermProc {
+public:
+    TermProcIdx() : TermProc(0), m_ts(0) {}
+    void setTSD(TextSplitDb *ts) {m_ts = ts;}
 
-    string term;
-    if (!unacmaybefold(_term, term, "UTF-8", true)) {
-	LOGINFO(("Db::splitter::takeword: unac failed for [%s]\n", 
-                 _term.c_str()));
-	term.clear();
-	// We don't generate a fatal error because of a bad term
-	return true;
-    }
-
-    if (stops.isStop(term)) {
-	LOGDEB1(("Db: takeword [%s] in stop list\n", term.c_str()));
-	return true;
-    }
-
-    // Compute absolute position (pos is relative to current segment),
-    // and remember relative.
-    curpos = pos;
-    pos += basepos;
-    string ermsg;
-    try {
-	// Index without prefix, using the field-specific weighting
-	doc.add_posting(term, pos, wdfinc);
+    bool takeword(const std::string &term, int pos, int, int)
+    {
+	// Compute absolute position (pos is relative to current segment),
+	// and remember relative.
+	m_ts->curpos = pos;
+	pos += m_ts->basepos;
+	string ermsg;
+	try {
+	    // Index without prefix, using the field-specific weighting
+	    LOGDEB1(("Emitting term at %d : [%s]\n", pos, term.c_str()));
+	    m_ts->doc.add_posting(term, pos, m_ts->wdfinc);
 #ifdef TESTING_XAPIAN_SPELL
-	if (Db::isSpellingCandidate(term)) {
-	    db.add_spelling(term);
-	}
+	    if (Db::isSpellingCandidate(term)) {
+		m_ts->db.add_spelling(term);
+	    }
 #endif
-	// Index the prefixed term.
-	if (!prefix.empty()) {
-	    doc.add_posting(prefix + term, pos, wdfinc);
-	}
-	return true;
-    } XCATCHERROR(ermsg);
-    LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
-    return false;
-}
+	    // Index the prefixed term.
+	    if (!m_ts->prefix.empty()) {
+		m_ts->doc.add_posting(m_ts->prefix + term, pos, m_ts->wdfinc);
+	    }
+	    return true;
+	} XCATCHERROR(ermsg);
+	LOGERR(("Db: xapian add_posting error %s\n", ermsg.c_str()));
+	return false;
+    }
+
+private:
+    TextSplitDb *m_ts;
+};
+
 
 #ifdef TESTING_XAPIAN_SPELL
 string Db::getSpellingSuggestion(const string& word)
@@ -1005,12 +1008,64 @@ static const string cstr_nc("\n\r\x0c");
 
 #define RECORD_APPEND(R, NM, VAL) {R += NM + "=" + VAL + "\n";}
 
+#ifdef IDX_THREADS
+void *DbUpdWorker(void* vdbp)
+{
+    Db *dbp = (Db *)vdbp;
+    WorkQueue<DbUpdTask*> *tqp = &(dbp->m_ndb->m_wqueue);
+    DbUpdTask *tsk;
+
+    for (;;) {
+	if (!tqp->take(&tsk)) {
+	    tqp->workerExit();
+	    return (void*)1;
+	}
+	LOGDEB(("DbUpdWorker: got task, ql %d\n", int(tqp->size())));
+
+	const char *fnc = tsk->udi.c_str();
+	string ermsg;
+
+	// Add db entry or update existing entry:
+	try {
+	    Xapian::docid did = 
+		dbp->m_ndb->xwdb.replace_document(tsk->uniterm, 
+						  tsk->doc);
+	    if (did < dbp->updated.size()) {
+		dbp->updated[did] = true;
+		LOGINFO(("Db::add: docid %d updated [%s]\n", did, fnc));
+	    } else {
+		LOGINFO(("Db::add: docid %d added [%s]\n", did, fnc));
+	    }
+	} XCATCHERROR(ermsg);
+
+	if (!ermsg.empty()) {
+	    LOGERR(("Db::add: replace_document failed: %s\n", ermsg.c_str()));
+	    ermsg.erase();
+	    // FIXME: is this ever actually needed?
+	    try {
+		dbp->m_ndb->xwdb.add_document(tsk->doc);
+		LOGDEB(("Db::add: %s added (failed re-seek for duplicate)\n", 
+			fnc));
+	    } XCATCHERROR(ermsg);
+	    if (!ermsg.empty()) {
+		LOGERR(("Db::add: add_document failed: %s\n", ermsg.c_str()));
+		tqp->workerExit();
+		return (void*)0;
+	    }
+	}
+	dbp->maybeflush(tsk->txtlen);
+
+	delete tsk;
+    }
+}
+#endif // IDX_THREADS
+
 // Add document in internal form to the database: index the terms in
 // the title abstract and body and add special terms for file name,
 // date, mime type etc. , create the document data record (more
 // metadata), and update database
 bool Db::addOrUpdate(const string &udi, const string &parent_udi,
-		     const Doc &idoc)
+		     Doc &doc)
 {
     LOGDEB(("Db::add: udi [%s] parent [%s]\n", 
 	     udi.c_str(), parent_udi.c_str()));
@@ -1030,10 +1085,17 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	m_occtxtsz = m_curtxtsz;
     }
 
-    Doc doc = idoc;
-
     Xapian::Document newdocument;
-    TextSplitDb splitter(m_ndb->xwdb, newdocument, m_stops);
+
+    // The term processing pipeline:
+    TermProcIdx tpidx;
+    TermProc *nxt = &tpidx;
+    TermProcStop tpstop(nxt, m_stops);nxt = &tpstop;
+//    TermProcCommongrams tpcommon(nxt, m_stops); nxt = &tpcommon;
+    TermProcPrep tpprep(nxt); nxt = &tpprep;
+
+    TextSplitDb splitter(newdocument, nxt);
+    tpidx.setTSD(&splitter);
 
     // Split and index file name as document term(s)
     LOGDEB2(("Db::add: split file name [%s]\n", fn.c_str()));
@@ -1193,26 +1255,33 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     }
     RECORD_APPEND(record, Doc::keyoc, doc.origcharset);
 
-    if (!doc.fbytes.empty())
+    if (doc.fbytes.empty())
+	doc.fbytes = doc.pcbytes;
+
+    if (!doc.fbytes.empty()) {
 	RECORD_APPEND(record, Doc::keyfs, doc.fbytes);
+	leftzeropad(doc.fbytes, 12);
+	newdocument.add_value(VALUE_SIZE, doc.fbytes);
+    }
+
+    if (!doc.pcbytes.empty())
+	RECORD_APPEND(record, Doc::keypcs, doc.pcbytes);
+    char sizebuf[30]; 
+    sprintf(sizebuf, "%u", (unsigned int)doc.text.length());
+    RECORD_APPEND(record, Doc::keyds, sizebuf);
+
     // Note that we add the signature both as a value and in the data record
     if (!doc.sig.empty())
 	RECORD_APPEND(record, Doc::keysig, doc.sig);
     newdocument.add_value(VALUE_SIG, doc.sig);
 
-    char sizebuf[30]; 
-    sprintf(sizebuf, "%u", (unsigned int)doc.text.length());
-    RECORD_APPEND(record, Doc::keyds, sizebuf);
-
     if (!doc.ipath.empty())
 	RECORD_APPEND(record, Doc::keyipt, doc.ipath);
 
-    if (doc.meta[Doc::keytt].empty())
-	doc.meta[Doc::keytt] = doc.utf8fn;
     doc.meta[Doc::keytt] = 
 	neutchars(truncate_to_word(doc.meta[Doc::keytt], 150), cstr_nc);
     if (!doc.meta[Doc::keytt].empty())
-	RECORD_APPEND(record, cstr_keycap, doc.meta[Doc::keytt]);
+	RECORD_APPEND(record, cstr_caption, doc.meta[Doc::keytt]);
 
     trimstring(doc.meta[Doc::keykw], " \t\r\n");
     doc.meta[Doc::keykw] = 
@@ -1264,6 +1333,13 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     LOGDEB0(("Rcl::Db::add: new doc record:\n%s\n", record.c_str()));
     newdocument.set_data(record);
 
+#ifdef IDX_THREADS
+    DbUpdTask *tp = new DbUpdTask(udi, uniterm, newdocument, doc.text.length());
+    if (!m_ndb->m_wqueue.put(tp)) {
+	LOGERR(("Db::addOrUpdate:Cant queue task\n"));
+	return false;
+    }
+#else
     const char *fnc = udi.c_str();
     string ermsg;
 
@@ -1296,6 +1372,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 
     // Test if we're over the flush threshold (limit memory usage):
     maybeflush(doc.text.length());
+#endif // IDX_THREADS
     return true;
 }
 
@@ -1363,19 +1440,21 @@ bool Db::needUpdate(const string &udi, const string& sig)
 	    // Up to date. 
 
 	    // Set the uptodate flag for doc / pseudo doc
-	    updated[*docid] = true;
+	    if (m_mode 	!= DbRO) {
+		updated[*docid] = true;
 
-	    // Set the existence flag for all the subdocs (if any)
-	    vector<Xapian::docid> docids;
-	    if (!m_ndb->subDocs(udi, docids)) {
-		LOGERR(("Rcl::Db::needUpdate: can't get subdocs list\n"));
-		return true;
-	    }
-	    for (vector<Xapian::docid>::iterator it = docids.begin();
-		 it != docids.end(); it++) {
-		if (*it < updated.size()) {
-		    LOGDEB2(("Db::needUpdate: set flag for docid %d\n", *it));
-		    updated[*it] = true;
+		// Set the existence flag for all the subdocs (if any)
+		vector<Xapian::docid> docids;
+		if (!m_ndb->subDocs(udi, docids)) {
+		    LOGERR(("Rcl::Db::needUpdate: can't get subdocs list\n"));
+		    return true;
+		}
+		for (vector<Xapian::docid>::iterator it = docids.begin();
+		     it != docids.end(); it++) {
+		    if (*it < updated.size()) {
+			LOGDEB2(("Db::needUpdate: set flag for docid %d\n", *it));
+			updated[*it] = true;
+		    }
 		}
 	    }
 	    return false;
@@ -1446,6 +1525,10 @@ bool Db::purge()
     if (m_ndb->m_isopen == false || m_ndb->m_iswritable == false) 
 	return false;
 
+#ifdef IDX_THREADS
+    m_ndb->m_wqueue.waitIdle();
+#endif // IDX_THREADS
+
     // For xapian versions up to 1.0.1, deleting a non-existant
     // document would trigger an exception that would discard any
     // pending update. This could lose both previous added documents
@@ -1511,6 +1594,11 @@ bool Db::purgeFile(const string &udi, bool *existed)
     LOGDEB(("Db:purgeFile: [%s]\n", udi.c_str()));
     if (m_ndb == 0 || !m_ndb->m_iswritable)
 	return false;
+
+#ifdef IDX_THREADS
+    m_ndb->m_wqueue.waitIdle();
+#endif // IDX_THREADS
+
     Xapian::WritableDatabase db = m_ndb->xwdb;
     string uniterm = make_uniterm(udi);
     string ermsg;
@@ -1559,7 +1647,7 @@ bool Db::filenameWildExp(const string& fnexp, list<string>& names)
     // each end: match any substring
     if (pattern[0] == '"' && pattern[pattern.size()-1] == '"') {
 	pattern = pattern.substr(1, pattern.size() -2);
-    } else if (pattern.find_first_of("*?[") == string::npos && 
+    } else if (pattern.find_first_of(cstr_minwilds) == string::npos && 
 	       !unaciscapital(pattern)) {
 	pattern = "*" + pattern + "*";
     } // else let it be
