@@ -21,6 +21,7 @@
 #include <list>
 #include <vector>
 
+#include "cstr.h"
 #include "refcntr.h"
 #include "rcldoc.h"
 #include "stoplist.h"
@@ -56,6 +57,19 @@ class RclConfig;
 namespace Rcl {
 #endif
 
+// Omega compatible values. We leave a hole for future omega values. Not sure 
+// it makes any sense to keep any level of omega compat given that the index
+// is incompatible anyway.
+enum value_slot {
+    // Omega-compatible values:
+    VALUE_LASTMOD = 0,	// 4 byte big endian value - seconds since 1970.
+    VALUE_MD5 = 1,	// 16 byte MD5 checksum of original document.
+    VALUE_SIZE = 2,     // sortable_serialise(<file size in bytes>)
+
+    // Recoll only:
+    VALUE_SIG = 10      // Doc sig as chosen by app (ex: mtime+size
+};
+
 class SearchData;
 class TermIter;
 class Query;
@@ -82,6 +96,9 @@ public:
     double       dbavgdoclen;
 };
 
+#ifdef IDX_THREADS
+extern  void *DbUpdWorker(void*);
+#endif // IDX_THREADS
 /**
  * Wrapper class for the native database.
  */
@@ -90,6 +107,9 @@ class Db {
     // A place for things we don't want visible here.
     class Native;
     friend class Native;
+#ifdef IDX_THREADS
+    friend void *DbUpdWorker(void*);
+#endif // IDX_THREADS
 
     /* General stuff (valid for query or update) ****************************/
     Db(RclConfig *cfp);
@@ -146,7 +166,7 @@ class Db {
       * possible depending on the document type. parent_udi is only
       * use for subdocs, else set it to empty */
     bool addOrUpdate(const string &udi, const string &parent_udi, 
-		     const Doc &doc);
+		     Doc &doc);
 
     /** Delete document(s) for given UDI, including subdocs */
     bool purgeFile(const string &udi, bool *existed = 0);
@@ -187,7 +207,7 @@ class Db {
     enum MatchType {ET_WILD, ET_REGEXP, ET_STEM};
     bool termMatch(MatchType typ, const string &lang, const string &s, 
 		   TermMatchResult& result, int max = -1, 
-		   const string& field = "",
+		   const string& field = cstr_null,
                    string *prefix = 0
         );
     /** Return min and max years for doc mod times in db */
