@@ -54,18 +54,19 @@ class Doc {
     string utf8fn; 
 
     // Internal path for multi-doc files. Ascii
-    // Set by DbIndexer::processone    
+    // Set by FsIndexer::processone    
     string ipath;
 
     // Mime type. Set by FileInterner::internfile
     string mimetype;     
 
     // File modification time as decimal ascii unix time
-    // Set by DbIndexer::processone
+    // Set by FsIndexer::processone
     string fmtime;
 
     // Data reference date (same format). Ie: mail date
     // Possibly set by mimetype-specific handler
+    // Filter::metaData["modificationdate"]
     string dmtime;
 
     // Charset we transcoded the 'text' field from (in case we want back)
@@ -86,15 +87,20 @@ class Doc {
     // as an indicative prefix at the beginning of the abstract (ugly hack)
     bool   syntabs;      
     
-    // File size. Index: Set by caller prior to Db::Add. Query: set by
-    // rcldb from index doc data. Historically this always has
-    // represented the whole file size (as from stat()), but there
-    // would be a need for a 3rd value for multidoc files (file
-    // size/doc size/ doc text size)
-    string fbytes;       
+    // File size. This is the size of the compressed file or of the
+    // external containing archive.
+    // Index: Set by caller prior to Db::Add. 
+    // Query: not set currently (not stored)
+    string pcbytes;       
 
-    // Doc text size. Index: from text.length(). Query: set by rcldb from
-    // index doc data.
+    // Document size, ie, size of the .odt or .xls.
+    // Index: Set in internfile from the filter stack
+    // Query: set from data record
+    string fbytes;
+
+    // Doc text size. 
+    // Index: from text.length(). 
+    // Query: set by rcldb from index data record
     string dbytes;
 
     // Doc signature. Used for up to date checks. 
@@ -125,6 +131,7 @@ class Doc {
 	origcharset.erase();
 	meta.clear();
 	syntabs = false;
+	pcbytes.erase();
 	fbytes.erase();
 	dbytes.erase();
 	sig.erase();
@@ -134,6 +141,19 @@ class Doc {
 	xdocid = 0;
     }
 
+    /** Get value for named field. If value pointer is 0, just test existence */
+    bool getmeta(const string& nm, string *value = 0) const
+    {
+	map<string,string>::const_iterator it = meta.find(nm);
+	if (it != meta.end()) {
+	    if (value)
+		*value = it->second;
+	    return true;
+	} else {
+	    return false;
+	}
+    }
+
     void dump(bool dotext=false) const;
 
     // The official names for recoll native fields when used in a text
@@ -149,9 +169,10 @@ class Doc {
     static const string keydmt; // document mtime
     static const string keymt;  // mtime dmtime if set else fmtime
     static const string keyoc;  // original charset
-    static const string keyfs;  // file size
-    static const string keyds;  // document size
-    static const string keysz;  // dbytes if set else fbytes
+    static const string keypcs;  // document outer container size
+    static const string keyfs;  // document size
+    static const string keyds;  // document text size
+    static const string keysz;  // dbytes if set else fbytes else pcbytes
     static const string keysig; // sig
     static const string keyrr;  // relevancy rating
     static const string keycc;  // Collapse count
