@@ -24,32 +24,31 @@
 
 #include "xapian.h"
 
+#include "cstr.h"
+#include "rclconfig.h"
+#include "debuglog.h"
 #include "rcldb.h"
 #include "rcldb_p.h"
 #include "rclquery.h"
 #include "rclquery_p.h"
-#include "debuglog.h"
 #include "conftree.h"
 #include "smallut.h"
 #include "searchdata.h"
-#include "rclconfig.h"
 #include "unacpp.h"
 
 #ifndef NO_NAMESPACES
 namespace Rcl {
 #endif
 
-static const string cstr_keycap("caption");
-static const string cstr_keydmtime("dmtime");
 
 // Field names inside the index data record may differ from the rcldoc ones
 // (esp.: caption / title)
 static const string& docfToDatf(const string& df)
 {
     if (!df.compare(Doc::keytt)) {
-	return cstr_keycap;
+	return cstr_caption;
     } else if (!df.compare(Doc::keymt)) {
-	return cstr_keydmtime;
+	return cstr_dmtime;
     } else {
 	return df;
     }
@@ -65,7 +64,8 @@ public:
 	: m_fld(docfToDatf(f) + "=") 
     {
 	m_ismtime = !m_fld.compare("dmtime=");
-	m_issize = !m_fld.compare("fbytes=") || !m_fld.compare("dbytes=");
+	m_issize = !m_fld.compare("fbytes=") || !m_fld.compare("dbytes=") ||
+	    !m_fld.compare("pcbytes=");
     }
 
     virtual std::string operator()(const Xapian::Document& xdoc) const 
