@@ -1,7 +1,4 @@
-#ifndef _rclquery_h_included_
-#define _rclquery_h_included_
-/* @(#$Id: rclquery.h,v 1.6 2008-09-29 11:33:55 dockes Exp $  (C) 2008 J.F.Dockes */
-/*
+/* Copyright (C) 2008 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -17,6 +14,8 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+#ifndef _rclquery_h_included_
+#define _rclquery_h_included_
 #include <string>
 #include <list>
 #include <vector>
@@ -96,6 +95,8 @@ private:
     string m_sortField;
     bool   m_sortAscending;
     bool   m_collapseDuplicates;     
+    int    m_resCnt;
+
     /* Copyconst and assignement private and forbidden */
     Query(const Query &) {}
     Query & operator=(const Query &) {return *this;};
