@@ -25,6 +25,7 @@
 
 #include "xapian.h"
 
+#include "cstr.h"
 #include "rcldb.h"
 #include "searchdata.h"
 #include "debuglog.h"
@@ -34,6 +35,7 @@
 #include "utf8iter.h"
 #include "stoplist.h"
 #include "rclconfig.h"
+#include "termproc.h"
 
 #ifndef NO_NAMESPACES
 using namespace std;
@@ -137,6 +139,11 @@ date_range_filter(int y1, int m1, int d1, int y2, int m2, int d2)
 }
 
 // Expand categories and mime type wild card exps
+// Actually, using getAllMimeTypes() here is a bit problematic because
+// there maybe other types in the index, not indexed by content, but
+// which could be searched by file name. It would probably be
+// preferable to do a termMatch() on field "mtype", which would
+// retrieve all values from the index.
 bool SearchData::expandFileTypes(RclConfig *cfg, vector<string>& tps)
 {
     if (!cfg) {
@@ -167,6 +174,8 @@ bool SearchData::expandFileTypes(RclConfig *cfg, vector<string>& tps)
 
 bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 {
+    LOGDEB2(("SearchData::toNativeQuery: stemlang [%s]\n", 
+	    m_stemlang.c_str()));
     Xapian::Query xq;
     m_reason.erase();
 
@@ -246,6 +255,39 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
         }
     }
 
+
+    if (m_minSize != size_t(-1) || m_maxSize != size_t(-1)) {
+        Xapian::Query sq;
+	char min[50], max[50];
+	sprintf(min, "%lld", (long long)m_minSize);
+	sprintf(max, "%lld", (long long)m_maxSize);
+	if (m_minSize == size_t(-1)) {
+	    string value(max);
+	    leftzeropad(value, 12);
+	    sq = Xapian::Query(Xapian::Query::OP_VALUE_LE, VALUE_SIZE, value);
+	} else if (m_maxSize == size_t(-1)) {
+	    string value(min);
+	    leftzeropad(value, 12);
+	    sq = Xapian::Query(Xapian::Query::OP_VALUE_GE, VALUE_SIZE, value);
+	} else {
+	    string minvalue(min);
+	    leftzeropad(minvalue, 12);
+	    string maxvalue(max);
+	    leftzeropad(maxvalue, 12);
+	    sq = Xapian::Query(Xapian::Query::OP_VALUE_RANGE, VALUE_SIZE, 
+			       minvalue, maxvalue);
+	}
+	    
+        // If no probabilistic query is provided then promote the
+        // filter to be THE query instead of filtering an empty query.
+        if (xq.empty()) {
+            LOGINFO(("Db::toNativeQuery: proba query is empty\n"));
+            xq = sq;
+        } else {
+            xq = Xapian::Query(Xapian::Query::OP_FILTER, xq, sq);
+        }
+    }
+
     // Add the file type filtering clause if any
     if (!m_filetypes.empty()) {
 	expandFileTypes(db.getConf(), m_filetypes);
@@ -282,7 +324,8 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 	vector<string> vpath;
 	stringToTokens(m_topdir, vpath, "/");
 	vector<string> pvpath;
-	pvpath.push_back(pathelt_prefix);
+	if (m_topdir[0] == '/')
+	    pvpath.push_back(pathelt_prefix);
 	for (vector<string>::const_iterator it = vpath.begin(); 
 	     it != vpath.end(); it++){
 	    pvpath.push_back(pathelt_prefix + *it);
@@ -308,8 +351,11 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
     return true;
 }
 
-
-bool SearchData::maybeAddAutoPhrase()
+// This is called by the GUI simple search if the option is set: add
+// (OR) phrase to a query (if it is simple enough) so that results
+// where the search terms are close and in order will come up on top.
+// We remove very common terms from the query to avoid performance issues.
+bool SearchData::maybeAddAutoPhrase(Rcl::Db& db, double freqThreshold)
 {
     LOGDEB0(("SearchData::maybeAddAutoPhrase()\n"));
     if (!m_query.size()) {
@@ -318,13 +364,13 @@ bool SearchData::maybeAddAutoPhrase()
     }
 
     string field;
-    string words;
+    list<string> words;
     // Walk the clause list. If we find any non simple clause or different
     // field names, bail out.
     for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++) {
 	SClType tp = (*it)->m_tp;
 	if (tp != SCLT_AND && tp != SCLT_OR) {
-	    LOGDEB2(("SearchData::maybeAddAutoPhrase: complex clause\n"));
+	    LOGDEB2(("SearchData::maybeAddAutoPhrase: rejected clause\n"));
 	    return false;
 	}
 	SearchDataClauseSimple *clp = 
@@ -337,23 +383,62 @@ bool SearchData::maybeAddAutoPhrase()
 	    field = clp->getfield();
 	} else {
 	    if (clp->getfield().compare(field)) {
-		LOGDEB2(("SearchData::maybeAddAutoPhrase: different fields\n"));
+		LOGDEB2(("SearchData::maybeAddAutoPhrase: diff. fields\n"));
 		return false;
 	    }
 	}
-	if (!words.empty())
-	    words += " ";
-	words +=  clp->gettext();
+
+	// If there are wildcards or quotes in there, bail out
+	if (clp->gettext().find_first_of("\"*[?") != string::npos) { 
+	    LOGDEB2(("SearchData::maybeAddAutoPhrase: wildcards\n"));
+	    return false;
+	}
+        // Do a simple word-split here, don't bother with the full-blown
+	// textsplit. The autophrase thing is just "best effort", it's
+	// normal that it won't work in strange cases.
+	vector<string> wl;
+	stringToStrings(clp->gettext(), wl);
+	words.insert(words.end(), wl.begin(), wl.end());
     }
 
-    if (words.find_first_of("\"*[]?") != string::npos && // has wildcards
-	TextSplit::countWords(words) <= 1) { // Just one word.
-	LOGDEB2(("SearchData::maybeAddAutoPhrase: wildcards or single word\n"));
+
+    // Trim the word list by eliminating very frequent terms
+    // (increasing the slack as we do it):
+    int slack = 0;
+    int doccnt = db.docCnt();
+    if (!doccnt)
+	doccnt = 1;
+    string swords;
+    for (list<string>::iterator it = words.begin(); 
+	 it != words.end(); it++) {
+	double freq = double(db.termDocCnt(*it)) / doccnt;
+	if (freq < freqThreshold) {
+	    if (!swords.empty())
+		swords.append(1, ' ');
+	    swords += *it;
+	} else {
+	    LOGDEB0(("Autophrase: [%s] too frequent (%.2f %%)\n", 
+		    it->c_str(), 100 * freq));
+	    slack++;
+	}
+    }
+    
+    // We can't make a phrase with a single word :)
+    int nwords = TextSplit::countWords(swords);
+    if (nwords <= 1) {
+	LOGDEB2(("SearchData::maybeAddAutoPhrase: ended with 1 word\n"));
 	return false;
     }
 
+    // Increase the slack: we want to be a little more laxist than for
+    // an actual user-entered phrase
+    slack += 1 + nwords / 3;
+    
     SearchDataClauseDist *nclp = 
-	new SearchDataClauseDist(SCLT_PHRASE, words, 0, field);
+	new SearchDataClauseDist(SCLT_PHRASE, swords, slack, field);
+
+    // If the toplevel conjunction is an OR, just OR the phrase, else 
+    // deepen the tree.
     if (m_tp == SCLT_OR) {
 	addClause(nclp);
     } else {
@@ -362,6 +447,7 @@ bool SearchData::maybeAddAutoPhrase()
 	// phrase.
 	SearchData *sd = new SearchData(m_tp);
 	sd->m_query = m_query;
+	sd->m_stemlang = m_stemlang;
 	m_tp = SCLT_OR;
 	m_query.clear();
 	SearchDataClauseSub *oq = 
@@ -399,6 +485,8 @@ void SearchData::erase() {
     m_description.erase();
     m_reason.erase();
     m_haveDates = false;
+    m_minSize = size_t(-1);
+    m_maxSize = size_t(-1);
 }
 
 // Am I a file name only search ? This is to turn off term highlighting
@@ -433,36 +521,24 @@ void SearchData::getUTerms(vector<string>& terms) const
 // phrases. This is for parts of the user entry which would appear as
 // a single word because there is no white space inside, but are
 // actually multiple terms to rcldb (ie term1,term2)
-class TextSplitQ : public TextSplit {
+class TextSplitQ : public TextSplitP {
  public:
-    TextSplitQ(Flags flags, const StopList &_stops) 
-	: TextSplit(flags), stops(_stops), alltermcount(0), lastpos(0)
+    TextSplitQ(Flags flags, const StopList &_stops, TermProc *prc)
+	: TextSplitP(prc, flags), 
+	  curnostemexp(false), stops(_stops), alltermcount(0), lastpos(0)
     {}
-    bool takeword(const std::string &interm, int pos, int, int) {
-	alltermcount++;
-        lastpos = pos
-	LOGDEB1(("TextSplitQ::takeword: %s\n", interm.c_str()));
 
+    bool takeword(const std::string &term, int pos, int bs, int be) 
+    {
 	// Check if the first letter is a majuscule in which
-	// case we do not want to do stem expansion. 
-	bool nostemexp = unaciscapital(interm);
-	string noaclowterm;
-	if (!unacmaybefold(interm, noaclowterm, "UTF-8", true)) {
-	    LOGINFO(("SearchData::splitter::takeword: unac failed for [%s]\n", 
-                     interm.c_str()));
-	    return true;
-	}
+	// case we do not want to do stem expansion. Need to do this
+	// before unac of course...
+	curnostemexp = unaciscapital(term);
 
-	if (stops.isStop(noaclowterm)) {
-	    LOGDEB1(("TextSplitQ::takeword [%s] in stop list\n", 
-                     noaclowterm.c_str()));
-	    return true;
-	}
-	terms.push_back(noaclowterm);
-	nostemexps.push_back(nostemexp);
-	return true;
+	return TextSplitP::takeword(term, pos, bs, be);
     }
 
+    bool           curnostemexp;
     vector<string> terms;
     vector<bool>   nostemexps;
     const StopList &stops;
@@ -472,6 +548,40 @@ class TextSplitQ : public TextSplit {
     int lastpos;
 };
 
+class TermProcQ : public TermProc {
+public:
+    TermProcQ() : TermProc(0), m_ts(0) {}
+    void setTSQ(TextSplitQ *ts) {m_ts = ts;}
+    
+    bool takeword(const std::string &term, int pos, int bs, int be) 
+    {
+	m_ts->alltermcount++;
+	if (m_ts->lastpos < pos)
+	    m_ts->lastpos = pos;
+	bool noexpand = be ? m_ts->curnostemexp : true;
+	LOGDEB(("TermProcQ::takeword: pushing [%s] pos %d noexp %d\n", 
+		term.c_str(), pos, noexpand));
+	if (m_terms[pos].size() < term.size()) {
+	    m_terms[pos] = term;
+	    m_nste[pos] = noexpand;
+	}
+	return true;
+    }
+    bool flush()
+    {
+	for (map<int, string>::const_iterator it = m_terms.begin();
+	     it != m_terms.end(); it++) {
+	    m_ts->terms.push_back(it->second);
+	    m_ts->nostemexps.push_back(m_nste[it->first]);
+	}
+	return true;
+    }
+private:
+    TextSplitQ *m_ts;
+    map<int, string> m_terms;
+    map<int, bool> m_nste;
+};
+
 // A class used to translate a user compound string (*not* a query
 // language string) as may be entered in any_terms/all_terms search
 // entry fields, ex: [term1 "a phrase" term3] into a xapian query
@@ -525,7 +635,7 @@ private:
     vector<vector<string> > m_groups; 
 };
 
-#if 0
+#if 1
 static void listVector(const string& what, const vector<string>&l)
 {
     string a;
@@ -534,6 +644,14 @@ static void listVector(const string& what, const vector<string>&l)
     }
     LOGDEB(("%s: %s\n", what.c_str(), a.c_str()));
 }
+static void listList(const string& what, const list<string>& l)
+{
+    string a;
+    for (list<string>::const_iterator it = l.begin(); it != l.end(); it++) {
+        a = a + *it + " ";
+    }
+    LOGDEB(("%s: %s\n", what.c_str(), a.c_str()));
+}
 #endif
 
 /** Expand stem and wildcards
@@ -553,19 +671,21 @@ void StringToXapianQ::expandTerm(bool nostemexp,
                                  list<string>& exp,
                                  string &sterm, const string& prefix)
 {
-    LOGDEB2(("expandTerm: field [%s] term [%s] stemlang [%s] nostemexp %d\n", 
-             m_field.c_str(), term.c_str(), m_stemlang.c_str(), nostemexp));
+    LOGDEB2(("expandTerm: field [%s] term [%s] stemlang [%s] nostemexp %d\n",
+	     m_field.c_str(), term.c_str(), m_stemlang.c_str(), nostemexp));
     sterm.erase();
     exp.clear();
     if (term.empty()) {
 	return;
     }
 
-    bool haswild = term.find_first_of("*?[") != string::npos;
+    bool haswild = term.find_first_of(cstr_minwilds) != string::npos;
 
     // No stemming if there are wildcards or prevented globally.
-    if (haswild || m_stemlang.empty())
+    if (haswild || m_stemlang.empty()) {
+	LOGDEB2(("expandTerm: found wildcards or stemlang empty: no exp\n"));
 	nostemexp = true;
+    }
 
     if (nostemexp && !haswild) {
 	sterm = term;
@@ -628,6 +748,8 @@ void multiply_groups(vector<vector<string> >::const_iterator vvit,
 void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
 					list<Xapian::Query> &pqueries)
 {
+    LOGDEB2(("StringToXapianQ::processSimpleSpan: [%s] nostemexp %d\n",
+	     span.c_str(), int(nostemexp)));
     list<string> exp;  
     string sterm; // dumb version of user term
 
@@ -689,15 +811,17 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
     vector<bool>::iterator nxit = splitData->nostemexps.begin();
     for (vector<string>::iterator it = splitData->terms.begin();
 	 it != splitData->terms.end(); it++, nxit++) {
+	LOGDEB0(("ProcessPhrase: processing [%s]\n", it->c_str()));
 	// Adjust when we do stem expansion. Not inside phrases, and
 	// some versions of xapian will accept only one OR clause
 	// inside NEAR, all others must be leafs.
 	bool nostemexp = *nxit || (op == Xapian::Query::OP_PHRASE) || hadmultiple;
 
 	string sterm;
-	list<string>exp;
+	list<string> exp;
 	expandTerm(nostemexp, *it, exp, sterm, prefix);
-
+	LOGDEB0(("ProcessPhrase: exp size %d\n", exp.size()));
+	listList("", exp);
 	// groups is used for highlighting, we don't want prefixes in there.
 	vector<string> noprefs;
 	for (list<string>::const_iterator it = exp.begin(); 
@@ -720,7 +844,7 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
 
     // Generate an appropriate PHRASE/NEAR query with adjusted slack
     // For phrases, give a relevance boost like we do for original terms
-    LOGDEB2(("PHRASE/NEAR: alltermcount %d lastpos %d\n", 
+    LOGDEB2(("PHRASE/NEAR:  alltermcount %d lastpos %d\n", 
              splitData->alltermcount, splitData->lastpos));
     Xapian::Query xq(op, orqueries.begin(), orqueries.end(),
 		     splitData->lastpos + 1 + slack);
@@ -776,7 +900,7 @@ bool StringToXapianQ::processUserString(const string &iq,
 					bool useNear
 					)
 {
-    LOGDEB(("StringToXapianQ:: query string: [%s]\n", iq.c_str()));
+    LOGDEB(("StringToXapianQ:: query string: [%s], slack %d, near %d\n", iq.c_str(), slack, useNear));
     ermsg.erase();
     m_uterms.clear();
     m_terms.clear();
@@ -811,34 +935,35 @@ bool StringToXapianQ::processUserString(const string &iq,
 	    // We used to do  word split, searching for 
 	    // "term0 term1 term2" instead, which may have worse 
 	    // performance, but will succeed.
-	    // We now adjust the phrase/near slack by the term count
-	    // difference (this is mainly better for cjk where this is a very
-	    // common occurrence because of the ngrams thing.
-	    TextSplitQ splitterS(TextSplit::Flags(TextSplit::TXTS_ONLYSPANS | 
-                                                  TextSplit::TXTS_KEEPWILD), 
-                                 stops);
-	    splitterS.text_to_words(*it);
-	    TextSplitQ splitterW(TextSplit::Flags(TextSplit::TXTS_NOSPANS | 
-                                                  TextSplit::TXTS_KEEPWILD),
-                                 stops);
-	    splitterW.text_to_words(*it);
-	    TextSplitQ *splitter = &splitterS;
-	    if (splitterS.terms.size() > 1 && 
-		splitterS.terms.size() != splitterW.terms.size()) {
-		slack += splitterW.terms.size() - splitterS.terms.size();
-		// used to: splitData = &splitDataW;
-	    }
+	    // We now adjust the phrase/near slack by comparing the term count
+	    // and the last position
 
-	    LOGDEB0(("strToXapianQ: termcount: %d\n", splitter->terms.size()));
-	    switch (splitter->terms.size() + terminc) {
+	    // The term processing pipeline:
+	    TermProcQ tpq;
+	    TermProc *nxt = &tpq;
+            TermProcStop tpstop(nxt, stops); nxt = &tpstop;
+            //TermProcCommongrams tpcommon(nxt, stops); nxt = &tpcommon;
+            //tpcommon.onlygrams(true);
+	    TermProcPrep tpprep(nxt); nxt = &tpprep;
+
+	    TextSplitQ splitter(TextSplit::Flags(TextSplit::TXTS_ONLYSPANS | 
+						  TextSplit::TXTS_KEEPWILD), 
+                                 stops, nxt);
+	    tpq.setTSQ(&splitter);
+	    splitter.text_to_words(*it);
+
+	    slack += splitter.lastpos - splitter.terms.size() + 1;
+
+	    LOGDEB0(("strToXapianQ: termcount: %d\n", splitter.terms.size()));
+	    switch (splitter.terms.size() + terminc) {
 	    case 0: 
 		continue;// ??
 	    case 1: 
-		processSimpleSpan(splitter->terms.front(), 
-                                  splitter->nostemexps.front(), pqueries);
+		processSimpleSpan(splitter.terms.front(), 
+                                  splitter.nostemexps.front(), pqueries);
 		break;
 	    default:
-		processPhraseOrNear(splitter, pqueries, useNear, slack, mods);
+		processPhraseOrNear(&splitter, pqueries, useNear, slack, mods);
 	    }
 	}
     } catch (const Xapian::Error &e) {
@@ -857,14 +982,14 @@ bool StringToXapianQ::processUserString(const string &iq,
     return true;
 }
 
-static const string cstr_null;
-
 // Translate a simple OR, AND, or EXCL search clause. 
 bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p, 
 					   const string& stemlang)
 {
     const string& l_stemlang = (m_modifiers&SDCM_NOSTEMMING)? cstr_null:
 	stemlang;
+    LOGDEB2(("SearchDataClauseSimple::toNativeQuery: stemlang [%s]\n",
+	     stemlang.c_str()));
 
     m_terms.clear();
     m_groups.clear();
@@ -964,10 +1089,10 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
     // stringToXapianQueries() to lowercase and simplify the phrase
     // terms etc. This will result into a single (complex)
     // Xapian::Query.
-    if (m_text.find_first_of("\"") != string::npos) {
+    if (m_text.find('\"') != string::npos) {
 	m_text = neutchars(m_text, "\"");
     }
-    string s = string("\"") + m_text + string("\"");
+    string s = cstr_dquote + m_text + cstr_dquote;
     bool useNear = (m_tp == SCLT_NEAR);
     StringToXapianQ tr(db, m_field, l_stemlang, doBoostUserTerm);
     if (!tr.processUserString(s, m_reason, pqueries, db.getStopList(),
