@@ -30,6 +30,7 @@
 #include "rcldb.h"
 #include "refcntr.h"
 #include "smallut.h"
+#include "cstr.h"
 
 class RclConfig;
 
@@ -74,7 +75,8 @@ class SearchData {
 public:
     SearchData(SClType tp) 
         : m_tp(tp), m_topdirexcl(false), m_topdirweight(1.0), 
-	  m_haveDates(false), m_haveWildCards(false) 
+	  m_haveDates(false), m_maxSize(size_t(-1)),
+	  m_minSize(size_t(-1)), m_haveWildCards(false) 
     {
 	if (m_tp != SCLT_OR && m_tp != SCLT_AND) 
 	    m_tp = SCLT_OR;
@@ -97,11 +99,13 @@ public:
     bool addClause(SearchDataClause *cl);
 
     /** If this is a simple query (one field only, no distance clauses),
-	add phrase made of query terms to query, so that docs containing the
-	user terms in order will have higher relevance. This must be called 
-	before toNativeQuery().
-    */
-    bool maybeAddAutoPhrase();
+     * add phrase made of query terms to query, so that docs containing the
+     * user terms in order will have higher relevance. This must be called 
+     * before toNativeQuery().
+     * @param threshold: don't use terms more frequent than the value 
+     *     (proportion of docs where they occur) 	
+     */
+    bool maybeAddAutoPhrase(Rcl::Db &db, double threshold);
 
     /** Set/get top subdirectory for filtering results */
     void setTopdir(const string& t, bool excl = false, float w = 1.0) 
@@ -111,6 +115,9 @@ public:
 	m_topdirweight = w;
     }
 
+    void setMinSize(size_t size) {m_minSize = size;}
+    void setMaxSize(size_t size) {m_maxSize = size;}
+
     /** Set date span for filtering results */
     void setDateSpan(DateInterval *dip) {m_dates = *dip; m_haveDates = true;}
 
@@ -151,6 +158,8 @@ private:
     float                     m_topdirweight; // affect weight instead of filter
     bool                      m_haveDates;
     DateInterval              m_dates; // Restrict to date interval
+    size_t                    m_maxSize;
+    size_t                    m_minSize;
     // Printable expanded version of the complete query, retrieved/set
     // from rcldb after the Xapian::setQuery() call
     string m_description; 
@@ -215,7 +224,7 @@ public:
     SearchDataClauseSimple(SClType tp, const string& txt, 
 			   const string& fld = string())
 	: SearchDataClause(tp), m_text(txt), m_field(fld), m_slack(0) {
-	m_haveWildCards = (txt.find_first_of("*?[") != string::npos);
+	m_haveWildCards = (txt.find_first_of(cstr_minwilds) != string::npos);
     }
 
     virtual ~SearchDataClauseSimple() {}
