@@ -34,6 +34,7 @@
 #include <iostream>
 #include <map>
 
+#include "cstr.h"
 #include "circache.h"
 #include "conftree.h"
 #include "debuglog.h"
@@ -356,27 +357,27 @@ public:
         string s(bf, CIRCACHE_FIRSTBLOCK_SIZE);
         ConfSimple conf(s, 1);
         string value;
-        if (!conf.get("maxsize", value, "")) {
+        if (!conf.get("maxsize", value, cstr_null)) {
             m_reason << "readfirstblock: conf get maxsize failed";
             return false;
         }
         m_maxsize = atol(value.c_str());
-        if (!conf.get("oheadoffs", value, "")) {
+        if (!conf.get("oheadoffs", value, cstr_null)) {
             m_reason << "readfirstblock: conf get oheadoffs failed";
             return false;
         }
         m_oheadoffs = atol(value.c_str());
-        if (!conf.get("nheadoffs", value, "")) {
+        if (!conf.get("nheadoffs", value, cstr_null)) {
             m_reason << "readfirstblock: conf get nheadoffs failed";
             return false;
         }
         m_nheadoffs = atol(value.c_str());
-        if (!conf.get("npadsize", value, "")) {
+        if (!conf.get("npadsize", value, cstr_null)) {
             m_reason << "readfirstblock: conf get npadsize failed";
             return false;
         }
         m_npadsize = atol(value.c_str());
-        if (!conf.get("unient", value, "")) {
+        if (!conf.get("unient", value, cstr_null)) {
             m_uniquentries = false;
         } else {
             m_uniquentries = stringToBool(value);
@@ -478,7 +479,7 @@ public:
                 string b(bf, d.dicsize);
                 ConfSimple conf(b, 1);
             
-                if (!conf.get("udi", udi, "")) {
+                if (!conf.get("udi", udi, cstr_null)) {
                     m_reason << "scan: no udi in dic";
                     return CCScanHook::Error;
                 }
@@ -1100,7 +1101,7 @@ bool CirCache::getCurrent(string& udi, string& dic, string& data)
         return false;
 
     ConfSimple conf(dic, 1);
-    conf.get("udi", udi, "");
+    conf.get("udi", udi, cstr_null);
     return true;
 }
 
