@@ -34,10 +34,6 @@
  * 
  * It is assumed that the dictionary are small (they are routinely read/parsed)
  *
- * A problem with this approach is that repetitively storing the same
- * object will evict all others. This could be somewhat optimized by reusing 
- * the last entry if it has the same udi as the one written, but not done 
- * currently.
  */
 
 #include <sys/types.h>
@@ -58,7 +54,12 @@ public:
 
     virtual string getReason();
 
-    enum CreateFlags {CC_CRNONE=0, CC_CRUNIQUE=1, CC_CRTRUNCATE = 2};
+    enum CreateFlags {CC_CRNONE=0, 
+		      // Unique entries: erase older instances when same udi
+		      // is stored.
+		      CC_CRUNIQUE=1,
+		      // Truncate file (restart from scratch).
+		      CC_CRTRUNCATE = 2};
     virtual bool create(off_t maxsize, int flags);
 
     enum OpMode {CC_OPREAD, CC_OPWRITE};
