@@ -23,6 +23,7 @@
 #include <unistd.h> // for access(2)
 #include <ctype.h>
 #include <fnmatch.h>
+#include <sys/stat.h>
 
 #include <fstream>
 #include <sstream>
@@ -145,13 +146,13 @@ void ConfSimple::parseinput(istream &input)
 
 
 ConfSimple::ConfSimple(int readonly, bool tildexp)
-    : dotildexpand(tildexp), m_holdWrites(false)
+    : dotildexpand(tildexp), m_fmtime(0), m_holdWrites(false)
 {
     status = readonly ? STATUS_RO : STATUS_RW;
 }
 
 ConfSimple::ConfSimple(const string& d, int readonly, bool tildexp)
-    : dotildexpand(tildexp), m_holdWrites(false)
+    : dotildexpand(tildexp), m_fmtime(0), m_holdWrites(false)
 {
     status = readonly ? STATUS_RO : STATUS_RW;
 
@@ -160,7 +161,7 @@ ConfSimple::ConfSimple(const string& d, int readonly, bool tildexp)
 }
 
 ConfSimple::ConfSimple(const char *fname, int readonly, bool tildexp)
-    : dotildexpand(tildexp), m_filename(fname), m_holdWrites(false)
+    : dotildexpand(tildexp), m_filename(fname), m_fmtime(0), m_holdWrites(false)
 {
     status = readonly ? STATUS_RO : STATUS_RW;
 
@@ -193,6 +194,7 @@ ConfSimple::ConfSimple(const char *fname, int readonly, bool tildexp)
     }	    
 
     parseinput(input);
+    i_changed(true);
 }
 
 ConfSimple::StatusCode ConfSimple::getStatus() const
@@ -204,6 +206,26 @@ ConfSimple::StatusCode ConfSimple::getStatus() const
     }
 }
 
+bool ConfSimple::sourceChanged()
+{
+    return i_changed(false);
+}
+
+bool ConfSimple::i_changed(bool upd)
+{
+    if (!m_filename.empty()) {
+	struct stat st;
+	if (stat(m_filename.c_str(), &st) == 0) {
+	    if (m_fmtime != st.st_mtime) {
+		if (upd)
+		    m_fmtime = st.st_mtime;
+		return true;
+	    }
+	}
+    }
+    return false;
+}
+
 int ConfSimple::get(const string &nm, string &value, const string &sk) const
 {
     if (!ok())
@@ -585,56 +607,12 @@ int ConfTree::get(const std::string &name, string &value, const string &sk)
 
 #include "conftree.h"
 #include "smallut.h"
+#include "readfile.h"
 
 using namespace std;
 
 static char *thisprog;
 
-static void caterrno(string *reason)
-{
-#define ERRBUFSZ 200    
-    char errbuf[ERRBUFSZ];
-  if (reason) {
-#ifdef sun
-    // Note: sun strerror is noted mt-safe ??
-    *reason += string("file_to_string: open failed: ") + strerror(errno);
-#else
-    strerror_r(errno, errbuf, ERRBUFSZ);
-    *reason += string("file_to_string: open failed: ") + errbuf;
-#endif
-  }
-}
-static bool file_to_string(const string &fn, string &data, string *reason)
-{
-    bool ret = false;
-    int fd = open(fn.c_str(), O_RDONLY);
-    if (fd < 0) {
-        caterrno(reason);
-	return false;
-    }
-    char buf[4096];
-    for (;;) {
-	int n = read(fd, buf, 4096);
-	if (n < 0) {
-	    caterrno(reason);
-	    goto out;
-	}
-	if (n == 0)
-	    break;
-	try {
-	    data.append(buf, n);
-	} catch (...) {
-	    caterrno(reason);
-	    goto out;
-	}
-    }
-    ret = true;
- out:
-    if (fd >= 0)
-	close(fd);
-    return ret;
-}
-
 bool complex_updates(const string& fn)
 {
     int fd;
