@@ -105,7 +105,9 @@ public:
     virtual int eraseKey(const string &) = 0;
     virtual void listall()  {};
     virtual list<string> getSubKeys() = 0;
+    virtual list<string> getSubKeys(bool) = 0;
     virtual bool holdWrites(bool) = 0;
+    virtual bool sourceChanged() = 0;
 };
 
 /** 
@@ -139,6 +141,9 @@ public:
 
     virtual ~ConfSimple() {};
 
+    /** Origin file changed. Only makes sense if we read the data from a file */
+    virtual bool sourceChanged();
+
     /** 
      * Decide if we actually rewrite the backing-store after modifying the
      * tree.
@@ -164,7 +169,8 @@ public:
      * Set value for named parameter in specified subsection (or global)
      * @return 0 for error, 1 else
      */
-    virtual int set(const string &nm, const string &val, const string &sk = string());
+    virtual int set(const string &nm, const string &val, 
+		    const string &sk = string());
 
     /**
      * Remove name and value from config
@@ -205,7 +211,13 @@ public:
     /**
      * Return all subkeys 
      */
+    virtual list<string> getSubKeys(bool) {return getSubKeys();}
     virtual list<string> getSubKeys();
+    /** Test for subkey existence */
+    virtual bool hasSubKey(const string& sk)
+    {
+	return m_submaps.find(sk) != m_submaps.end();
+    }
 
     virtual string getFilename() {return m_filename;}
 
@@ -244,6 +256,7 @@ protected:
 private:
     // Set if we're working with a file
     string                            m_filename; 
+    time_t                            m_fmtime;
     // Configuration data submaps (one per subkey, the main data has a
     // null subkey)
     map<string, map<string, string> > m_submaps;
@@ -259,6 +272,7 @@ private:
     // Internal version of set: no RW checking
     virtual int i_set(const string &nm, const string &val, 
 		      const string &sk, bool init = false);
+    bool i_changed(bool upd);
 };
 
 /**
@@ -358,6 +372,16 @@ public:
 	return *this;
     }
 
+    virtual bool sourceChanged()
+    {
+	typename list<T*>::const_iterator it;
+	for (it = m_confs.begin();it != m_confs.end();it++) {
+	    if ((*it)->sourceChanged())
+		return true;
+	}
+	return false;
+    }
+
     virtual int get(const string &name, string &value, const string &sk) const
     {
 	typename list<T*>::const_iterator it;
@@ -422,20 +446,36 @@ public:
     }
 
     virtual list<string> getNames(const string &sk, const char *pattern = 0)
+    {
+	return getNames1(sk, pattern, false);
+    }
+    virtual list<string> getNamesShallow(const string &sk, const char *patt = 0)
+    {
+	return getNames1(sk, patt, true);
+    }
+
+    virtual list<string> getNames1(const string &sk, const char *pattern,
+				   bool shallow)
     {
 	list<string> nms;
 	typename list<T*>::iterator it;
+	bool skfound = false;
 	for (it = m_confs.begin();it != m_confs.end(); it++) {
-	    list<string> lst;
-	    lst = (*it)->getNames(sk, pattern);
-	    nms.insert(nms.end(), lst.begin(), lst.end());
+	    if ((*it)->hasSubKey(sk)) {
+		skfound = true;
+		list<string> lst = (*it)->getNames(sk, pattern);
+		nms.insert(nms.end(), lst.begin(), lst.end());
+	    }
+	    if (shallow && skfound)
+		break;
 	}
 	nms.sort();
 	nms.unique();
 	return nms;
     }
 
-    virtual list<string> getSubKeys() 
+    virtual list<string> getSubKeys(){return getSubKeys(false);}
+    virtual list<string> getSubKeys(bool shallow)
     {
 	list<string> sks;
 	typename list<T*>::iterator it;
@@ -443,6 +483,8 @@ public:
 	    list<string> lst;
 	    lst = (*it)->getSubKeys();
 	    sks.insert(sks.end(), lst.begin(), lst.end());
+	    if (shallow)
+		break;
 	}
 	sks.sort();
 	sks.unique();
