@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: debuglog.cpp,v 1.6 2008-12-16 14:20:10 dockes Exp $ (C) 2006 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2006 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -338,7 +335,11 @@ DebugLog *getdbl()
     }
     DebugLog *dbl;
     if (!(dbl = (DebugLog *)pthread_getspecific(dbl_key))) {
-	dbl = new DebugLog;
+	if ((dbl = new DebugLog) == 0) {
+	    fprintf(stderr, "debuglog: new DebugLog returned 0! ");
+	    abort();
+	}
+
 	dbl->setwriter(theWriter);
 	initfiles();
 	status = pthread_setspecific(dbl_key, dbl);
