@@ -58,6 +58,7 @@ using std::stack;
 #include "pathut.h"
 #include "transcode.h"
 #include "wipedir.h"
+#include "md5.h"
 
 bool fsocc(const string &path, int *pc, long *blocks)
 {
@@ -388,6 +389,52 @@ bool path_isdir(const string& path)
     return false;
 }
 
+// Allowed punctuation in the path part of an URI according to RFC2396
+// -_.!~*'():@&=+$,
+/*
+21 !
+    22 "
+    23 #
+24 $
+    25 %
+26 &
+27 '
+28 (
+29 )
+2A *
+2B +
+2C , 
+2D -
+2E .
+2F /
+30 0
+...
+39 9
+3A :
+    3B ;
+    3C <
+3D =
+    3E >
+    3F ?
+40 @
+41 A
+...
+5A Z
+    5B [
+    5C \
+    5D ]
+    5E ^
+5F _
+    60 `
+61 a
+...
+7A z
+    7B {
+    7C |
+    7D }
+7E ~
+    7F DEL
+*/
 string url_encode(const string& url, string::size_type offs)
 {
     string out = url.substr(0, offs);
@@ -396,24 +443,23 @@ string url_encode(const string& url, string::size_type offs)
 	int c;
 	const char *h = "0123456789ABCDEF";
 	c = cp[i];
-	if(c <= 0x1f || 
+	if (c <= 0x20 || 
 	   c >= 0x7f || 
-	   c == '<' ||
-	   c == '>' ||
-	   c == ' ' ||
-	   c == '\t'||
 	   c == '"' ||
 	   c == '#' ||
 	   c == '%' ||
-	   c == '{' ||
-	   c == '}' ||
-	   c == '|' ||
-	   c == '\\' ||
-	   c == '^' ||
-	   c == '~'||
+	   c == ';' ||
+	   c == '<' ||
+	   c == '>' ||
+	   c == '?' ||
 	   c == '[' ||
+	   c == '\\' ||
 	   c == ']' ||
-	   c == '`') {
+	   c == '^' ||
+	   c == '`' ||
+	   c == '{' ||
+	   c == '|' ||
+	   c == '}' ) {
 	    out += '%';
 	    out += h[(c >> 4) & 0xf];
 	    out += h[c & 0xf];
@@ -444,7 +490,9 @@ string url_gpath(const string& url)
     return path_canon(url.substr(colon+1));
 }
 
-// Convert to file path if url is like file://
+// Convert to file path if url is like file:
+// Note: this only works with our internal pseudo-urls which are not
+// encoded/escaped
 string fileurltolocalpath(string url)
 {
     if (url.find("file://") == 0)
@@ -501,11 +549,26 @@ pid_t Pidfile::read_pid()
 int Pidfile::flopen()
 {
     const char *path = m_path.c_str();
-    int operation = LOCK_EX | LOCK_NB;
     if ((m_fd = ::open(path, O_RDWR|O_CREAT, 0644)) == -1) {
 	m_reason = "Open failed";
 	return -1;
     }
+
+#ifdef sun
+    struct flock lockdata;
+    lockdata.l_start = 0;
+    lockdata.l_len = 0;
+    lockdata.l_type = F_WRLCK;
+    lockdata.l_whence = SEEK_SET;
+    if (fcntl(m_fd, F_SETLK,  &lockdata) != 0) {
+	int serrno = errno;
+	(void)::close(m_fd);
+	errno = serrno;
+	m_reason = "fcntl lock failed";
+	return -1;
+    }
+#else
+    int operation = LOCK_EX | LOCK_NB;
     if (flock(m_fd, operation) == -1) {
 	int serrno = errno;
 	(void)::close(m_fd);
@@ -513,6 +576,8 @@ int Pidfile::flopen()
 	m_reason = "flock failed";
 	return -1;
     }
+#endif // ! sun
+
     if (ftruncate(m_fd, 0) != 0) {
 	/* can't happen [tm] */
 	int serrno = errno;
@@ -559,6 +624,48 @@ int Pidfile::remove()
     return unlink(m_path.c_str());
 }
 
+// Freedesktop standard paths for thumbnails
+
+// Place for 256x256 files
+static const string thmbdirlarge = ".thumbnails/large";
+// 128x128
+static const string thmbdirnormal = ".thumbnails/normal";
+
+static void thumbname(const string& url, string& name)
+{
+    string digest;
+    string l_url = url_encode(url);
+    MD5String(l_url, digest);
+    MD5HexPrint(digest, name);
+    name += ".png";
+}
+
+bool thumbPathForUrl(const string& url, int size, string& path)
+{
+    string name;
+    thumbname(url, name);
+    if (size <= 128) {
+	path = path_cat(path_home(), thmbdirnormal);
+	path = path_cat(path, name);
+	if (access(path.c_str(), R_OK) == 0) {
+	    return true;
+	}
+    } 
+    path = path_cat(path_home(), thmbdirlarge);
+    path = path_cat(path, name);
+    if (access(path.c_str(), R_OK) == 0) {
+	return true;
+    }
+
+    // File does not exist. Path corresponds to the large version at this point,
+    // fix it if needed.
+    if (size <= 128) {
+	path = path_cat(path_home(), thmbdirnormal);
+	path = path_cat(path, name);
+    }
+    return false;
+}
+
 #else // TEST_PATHUT
 #include <stdlib.h>
 #include <iostream>
@@ -645,7 +752,7 @@ int main(int argc, const char **argv)
   printf("pc %d, megabytes %ld\n", pc, blocks);
 #endif
 
-#if 1
+#if 0
   Pidfile pidfile("/tmp/pathutpidfile");
   pid_t pid;
   if ((pid = pidfile.open()) != 0) {
@@ -659,6 +766,35 @@ int main(int argc, const char **argv)
   pidfile.remove();
 #endif
 
+#if 1
+  if (argc != 2) {
+      fprintf(stderr, "Usage: thumbpath <filepath> <size>\n");
+      exit(1);
+  }
+
+  string input = *argv++;
+  int size = atoi(*argv++);
+
+  if (input.empty())  {
+      fprintf(stderr, "Usage: thumbpath <filepath> <size>\n");
+      exit(1);
+  }
+
+  // Make absolute path if needed
+  if (input[0] != '/') {
+      input = path_absolute(input);
+  }
+  input = string("file://") + path_canon(input);
+  string path;
+  if (thumbPathForUrl(input, size, path)) {
+      cout << "Thumbnail for [" << input << "] [" << path << "]" << endl;
+  } else {
+      cout << "No thumbnail for [" << input << "] path [" << path << "]" <<endl;
+  }
+  
+  exit(0);
+#endif
+
     return 0;
 }
 
